@@ -11,6 +11,9 @@ int main(int argc, char *argv[])
     // If this is a secondary instance
     if( app.isSecondary() ) {
         app.sendMessage( app.arguments().join(' ').toUtf8() );
+        qDebug() << "App already running.";
+        qDebug() << "Primary instance PID: " << app.primaryPid();
+        qDebug() << "Primary instance user: " << app.primaryUser();
         return 0;
     } else {
         QObject::connect(
