@@ -33,8 +33,8 @@ my $no = '[no]';
 my $todo = 'TODO';
 
 our $default_language = 'fr';
-our @misc_desktop_files = qw(misc/qelectrotech.desktop misc/x-qet-element.desktop misc/x-qet-project.desktop misc/x-qet-titleblock.desktop);
-our @misc_xml_files     = qw(misc/qelectrotech.xml     misc/x-qet-element.xml     misc/x-qet-project.xml     misc/x-qet-titleblock.xml);
+our @misc_desktop_files = qw(misc/qelectrotech.desktop);
+our @misc_xml_files     = qw(misc/qelectrotech.xml);
 our @readme_files       = qw(CREDIT README INSTALL ELEMENTS.LICENSE build-aux/linux/fedora/README.elements);
 our @ordered_languages  = qw(fr en es pt cs pl ca de it ar sl hr el nl be ru ro da pt_br hu sr tr nb ja mn);
 our %languages = (
