@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2021 The QElectroTech Team
+	Copyright 2006-2023 The QElectroTech Team
 	This file is part of QElectroTech.
 
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -17,7 +17,7 @@
 */
 #include "elementscollectionwidget.h"
 
-#include "../editor/qetelementeditor.h"
+#include "../editor/ui/qetelementeditor.h"
 #include "../elementscategoryeditor.h"
 #include "../newelementwizard.h"
 #include "../qetapp.h"
@@ -38,6 +38,9 @@
 #include <QUrl>
 #include <QVBoxLayout>
 #include <QtGlobal>
+#include <QProgressBar>
+#include <QStatusBar>
+#include <QLineEdit>
 
 /**
 	@brief ElementsCollectionWidget::ElementsCollectionWidget
@@ -582,7 +585,7 @@ void ElementsCollectionWidget::resetShowThisDir()
 
 /**
 	@brief ElementsCollectionWidget::dirProperties
-	Open an informative dialog about the curent index
+	Open an informative dialog about the current index
 */
 void ElementsCollectionWidget::dirProperties()
 {
@@ -616,7 +619,10 @@ void ElementsCollectionWidget::dirProperties()
 */
 void ElementsCollectionWidget::reload()
 {
+	m_loading_timer.reset(new QElapsedTimer());
 	qInfo()<<"Elements collection reload";
+	m_loading_timer->start();
+
 	m_progress_bar->show();
 	// Force to repaint now,
 	// else progress bar will be not displayed immediately
@@ -676,7 +682,13 @@ void ElementsCollectionWidget::loadingFinished()
 	m_progress_bar->hide();
 	m_tree_view->setEnabled(true);
 
-	qInfo()<<"Elements collection finished to be loaded";
+	if (m_loading_timer) {
+		qInfo()<<"Elements collection finished to be loaded in" << m_loading_timer->elapsed()/1000.0 << "seconds";
+		m_loading_timer.reset();
+	}
+	else {
+		qInfo()<<"Elements collection finished to be loaded";
+	}
 }
 
 /**
