@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2021 The QElectroTech Team
+	Copyright 2006-2023 The QElectroTech Team
 	This file is part of QElectroTech.
 
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -140,7 +140,7 @@ bool ElementsLocation::operator!=(const ElementsLocation &other) const
 	@return The base name of the element or directory.
 	Unlike ElementsLocation::fileName,
 	this method don't return the extension name.
-	For exemple if this location represent an element they return myElement.
+	For example if this location represent an element they return myElement.
 	@see fileName()
 */
 QString ElementsLocation::baseName() const
@@ -773,8 +773,27 @@ bool ElementsLocation::setXml(const QDomDocument &xml_document) const
 #else
 #if TODO_LIST
 #pragma message("@TODO remove code for QT 6 or later")
+#		pragma message("@TODO ad Core5Compat to Cmake")
 #endif
-		qDebug()<<"Help code for QT 6 or later";
+			qDebug() << "Help code for QT 6 or later";
+
+			QString			   path_ = collectionPath(false);
+			QRegularExpression rx("^(.*)/(.*\\.elmt)$");
+
+			if (rx.exactMatch(path_))
+			{
+				return project()
+					->embeddedElementCollection()
+					->addElementDefinition(
+						rx.cap(1),
+						rx.cap(2),
+						xml_document.documentElement());
+			}
+			else
+			{
+				qDebug() << "ElementsLocation::setXml :"
+							" rx don't match";
+			}
 #endif
 		}
 	}
