@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2021 The QElectroTech Team
+	Copyright 2006-2023 The QElectroTech Team
 	This file is part of QElectroTech.
 
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -93,7 +93,7 @@ QVector<QPointF> QetGraphicsHandlerUtility::pointsForArc(const QRectF &rect,
 	@brief QetGraphicsHandlerUtility::rectForPosAtIndex
 	Return a rectangle after modification
 	of the point 'pos' at index 'index' of original rectangle 'old_rect'.
-	@param old_rect - the rectangle befor modification
+	@param old_rect - the rectangle before modification
 	@param pos - the new position of a key point
 	@param index - the index of the key point to modifie
 	@see QetGraphicsHandlerUtility::pointsForRect to know
@@ -126,7 +126,7 @@ QRectF QetGraphicsHandlerUtility::rectForPosAtIndex(const QRectF &old_rect,
 	Return a rectangle after modification of the point 'pos'
 	at index 'index' of original rectangle 'old_rect'.
 	the opposite edge is modified inversely (like a mirror)
-	@param old_rect : the rectangle befor modification
+	@param old_rect : the rectangle before modification
 	@param pos : the new position of a key point
 	@param index : the index of the key point to modifie
 	@see QetGraphicsHandlerUtility::pointsForRect to know
