@@ -1,5 +1,5 @@
 ﻿/*
-	Copyright 2006-2021 The QElectroTech Team
+	Copyright 2006-2023 The QElectroTech Team
 	This file is part of QElectroTech.
 
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -35,7 +35,7 @@ SearchAndReplaceWorker::SearchAndReplaceWorker()
 /**
 	@brief SearchAndReplaceWorker::replaceDiagram
 	Replace all properties of each diagram in diagram_list,
-	by the current titleblock propertie of this worker
+	by the current titleblock properties of this worker
 	@param diagram_list : list of diagram to be changed,
 	all diagrams must belong to the same project;
 */
@@ -123,7 +123,8 @@ void SearchAndReplaceWorker::replaceElement(QList<Element *> list)
 			//We apply change only for master, slave, and terminal element.
 		if (elmt->linkType() == Element::Master ||
 			elmt->linkType() == Element::Simple ||
-			elmt->linkType() == Element::Terminale)
+			elmt->linkType() == Element::Terminale ||
+			elmt->linkType() == Element::Thumbnail)
 		{
 			DiagramContext old_context;
 			DiagramContext new_context =  old_context = elmt->elementInformations();
