@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2021 The QElectroTech Team
+	Copyright 2006-2023 The QElectroTech Team
 	This file is part of QElectroTech.
 	
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -245,6 +245,12 @@ class BorderTitleBlock : public QObject
 			since it does not know of its parent project.
 		*/
 		void needTitleBlockTemplate(const QString &);
+
+		/**
+		 * @brief infoChanged
+		 * Signal emitted when the informations changed.
+		 */
+		void informationChanged();
 	
 	// attributes
 	private:
