@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2021 The QElectroTech Team
+	Copyright 2006-2023 The QElectroTech Team
 	This file is part of QElectroTech.
 
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -263,7 +263,7 @@ ConductorProperties::~ConductorProperties()
 
 /**
 	@brief ConductorProperties::toXml
-	Export conductor propertie, in the XML element 'e'
+	Export conductor properties to the XML element 'e'
 	@param e the xml element
 */
 void ConductorProperties::toXml(QDomElement &e) const
@@ -308,7 +308,7 @@ void ConductorProperties::toXml(QDomElement &e) const
 
 /**
 	@brief ConductorProperties::fromXml
-	Import conductor propertie, from the attribute of the xml element 'e'
+	Import conductor properties from the attribute of the xml element 'e'
 	@param e the xml document
 */
 void ConductorProperties::fromXml(QDomElement &e)
@@ -368,14 +368,6 @@ void ConductorProperties::fromXml(QDomElement &e)
 						"vertical-alignment",
 						"AlignRight"
 						).toStdString().data()));
-
-	//Keep retrocompatible with version older than 0,4
-	//If the propertie @type is simple (removed since QET 0,4), we set text no visible.
-	//@TODO remove this code for qet 0.6 or later
-#if TODO_LIST
-#pragma message("@TODO remove this code for qet 0.6 or later")
-#endif
-	if (e.attribute("type") == "simple") m_show_text = false;
 }
 
 /**
