@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2021 The QElectroTech Team
+	Copyright 2006-2023 The QElectroTech Team
 	This file is part of QElectroTech.
 	
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -17,7 +17,7 @@
 */
 #include <QScrollArea>
 #include "configdialog.h"
-#include "configpages.h"
+#include "ui/configpage/configpages.h"
 #include "qetapp.h"
 
 #include "machine_info.h"
@@ -27,7 +27,6 @@
 	@param parent QWidget parent
 */
 ConfigDialog::ConfigDialog(QWidget *parent) : QDialog(parent) {
-	Machine_info *mymachineinfo= new Machine_info(this);
 	//ScrollArea for low screens
 	QScrollArea *scroll = new QScrollArea(this);
 	scroll->setHorizontalScrollBarPolicy(Qt::ScrollBarAsNeeded);
@@ -36,7 +35,7 @@ ConfigDialog::ConfigDialog(QWidget *parent) : QDialog(parent) {
 	// liste des pages
 	pages_list = new QListWidget();
 	pages_list -> setViewMode(QListView::IconMode);
-	if(mymachineinfo->i_max_screen_height()<1000){
+	if(MachineInfo::instance()->i_max_screen_height()<1000){
 		pages_list -> setIconSize(QSize(64, 64));
 	} else {
 		pages_list -> setIconSize(QSize(128, 128));
@@ -80,8 +79,8 @@ ConfigDialog::ConfigDialog(QWidget *parent) : QDialog(parent) {
 	connect(pages_list, SIGNAL(currentRowChanged(int)),
 		pages_widget, SLOT(setCurrentIndex(int)));
 
-	setMaximumSize(mymachineinfo->i_max_screen_width(),
-		       mymachineinfo->i_max_screen_height());
+	setMaximumSize(MachineInfo::instance()->i_max_screen_width(),
+				   MachineInfo::instance()->i_max_screen_height());
 	resize(1400,1000);
 
 #ifdef Q_OS_MACOS
