@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2021 The QElectroTech Team
+	Copyright 2006-2023 The QElectroTech Team
 	This file is part of QElectroTech.
 
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -17,6 +17,7 @@
 */
 #include "elementquerywidget.h"
 
+#include "../../properties/elementdata.h"
 #include "../../qetapp.h"
 #include "../../qetinformation.h"
 #include "ui_elementquerywidget.h"
@@ -45,6 +46,7 @@ ElementQueryWidget::ElementQueryWidget(QWidget *parent) :
 	m_button_group.addButton(ui->m_button_cb, 3);
 	m_button_group.addButton(ui->m_coil_cb, 4);
 	m_button_group.addButton(ui->m_protection_cb, 5);
+	m_button_group.addButton(ui->m_thumbnail_cb, 6);
 #if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)	// ### Qt 6: remove
 	connect(&m_button_group, static_cast<void (QButtonGroup::*)(int)>(&QButtonGroup::buttonClicked), [this](int id)
 #else
@@ -74,7 +76,7 @@ ElementQueryWidget::ElementQueryWidget(QWidget *parent) :
 		else
 		{
 			int checked = 0;
-			for (int i=1 ; i<6 ; ++i) {
+			for (int i=1 ; i<7 ; ++i) {
 				if (m_button_group.button(i)->isChecked()) {++checked;}
 			}
 
@@ -83,7 +85,7 @@ ElementQueryWidget::ElementQueryWidget(QWidget *parent) :
 				case 0 :
 					check_box->setCheckState(Qt::Unchecked);
 					break;
-				case 5:
+				case 6:
 					check_box->setCheckState(Qt::Checked);
 					break;
 				default:
@@ -157,40 +159,45 @@ void ElementQueryWidget::setQuery(const QString &query)
 			//Element type filter
 		if (where.contains("element_sub_type") || where.contains("element_type"))
 		{
-			int c=0;
-			ui->m_simple_cb->setChecked    (where.contains("Simple")     ? true : false);
-			if (ui->m_simple_cb->isChecked()) {
-				++c;
-				where.remove("element_type = 'Simple' ");
-			}
-			ui->m_terminal_cb->setChecked  (where.contains("Terminale")  ? true : false);
-			if (ui->m_terminal_cb->isChecked()) {
-				++c;
-				where.remove("element_type = 'Terminale'");
-			}
-			ui->m_coil_cb->setChecked      (where.contains("coil")       ? true : false);
-			if (ui->m_coil_cb->isChecked()) {
-				++c;
-				where.remove("element_sub_type = 'coil' ");
-			}
-			ui->m_button_cb->setChecked    (where.contains("commutator") ? true : false);
-			if (ui->m_button_cb->isChecked()) {
-				++c;
-				where.remove("element_sub_type = 'commutator' ");
-			}
-			ui->m_protection_cb->setChecked(where.contains("protection") ? true : false);
-			if (ui->m_protection_cb) {
-				++c;
-				where.remove("element_sub_type = 'protection'");
-			}
+			QRegularExpression rx("^(\\( .+?\\))");
+			auto rxm = rx.match(where);
+			if (rxm.hasMatch())
+			{
+				auto str_type = rxm.captured(1);
+				where.remove(str_type);
 
-			if (c == 5) {
-				ui->m_all_cb->setCheckState(Qt::Checked);
-			} else if (c > 0) {
-				ui->m_all_cb->setCheckState(Qt::PartiallyChecked);
-			}
+				int c=0;
+				ui->m_simple_cb->setChecked    (str_type.contains(ElementData::typeToString(ElementData::Simple)) ? true : false);
+				if (ui->m_simple_cb->isChecked()) {
+					++c;
+				}
+				ui->m_terminal_cb->setChecked  (str_type.contains(ElementData::typeToString(ElementData::Terminale)) ? true : false);
+				if (ui->m_terminal_cb->isChecked()) {
+					++c;
+				}
+				ui->m_coil_cb->setChecked      (str_type.contains(ElementData::masterTypeToString(ElementData::Coil)) ? true : false);
+				if (ui->m_coil_cb->isChecked()) {
+					++c;
+				}
+				ui->m_button_cb->setChecked    (str_type.contains(ElementData::masterTypeToString(ElementData::Commutator)) ? true : false);
+				if (ui->m_button_cb->isChecked()) {
+					++c;
+				}
+				ui->m_protection_cb->setChecked(str_type.contains(ElementData::masterTypeToString(ElementData::Protection)) ? true : false);
+				if (ui->m_protection_cb) {
+					++c;
+				}
+				ui->m_thumbnail_cb->setChecked  (str_type.contains(ElementData::typeToString(ElementData::Thumbnail)) ? true : false);
+				if (ui->m_thumbnail_cb->isChecked()) {
+					++c;
+				}
 
-			where.remove("OR");
+				if (c == 6) {
+					ui->m_all_cb->setCheckState(Qt::Checked);
+				} else if (c > 0) {
+					ui->m_all_cb->setCheckState(Qt::PartiallyChecked);
+				}
+			}
 		}
 		else // There is not "element_sub_type" or "element_type" that mean every element are selected
 		{
@@ -206,20 +213,16 @@ void ElementQueryWidget::setQuery(const QString &query)
 			strl.append(item->data(Qt::UserRole).toString());
 		}
 
-		QString beginning_rx;
-		beginning_rx.append(QString("^(").append(strl.join("|")));
-		beginning_rx.append(")");
-
-		QRegularExpression rx_is_not_null(beginning_rx + " IS NOT NULL$");
-		QRegularExpression rx_is_null (beginning_rx + " IS NULL$");
-		QRegularExpression rx_like (beginning_rx + QString(" LIKE'%(.+)%'$"));
-		QRegularExpression rx_not_like (beginning_rx + QString(" NOT LIKE'%(.+)%'$"));
-		QRegularExpression rx_equal (beginning_rx + QString("='(.+)'$"));
-		QRegularExpression rx_not_equal (beginning_rx + QString("!='(.+)'$"));
+		QString join_str = strl.join("|");
 
+		QRegularExpression rx_is_not_null(QStringLiteral("^(%1) != ''$").arg(join_str));
+		QRegularExpression rx_is_null    (QStringLiteral("^\\((%1) IS NULL OR (%1) = ''\\)").arg(join_str));
+		QRegularExpression rx_like       (QStringLiteral("^(%1) LIKE'%(.+)%'$").arg(join_str));
+		QRegularExpression rx_not_like   (QStringLiteral("^(%1) NOT LIKE'%(.+)%'$").arg(join_str));
+		QRegularExpression rx_equal      (QStringLiteral("^(%1)='(.+)'$").arg(join_str));
+		QRegularExpression rx_not_equal  (QStringLiteral("^(%1)!='(.+)'$").arg(join_str));
 
 		QStringList split_where;
-
 			//Remove the white space at begin and end of each string
 		for (auto str : where.split("AND "))
 		{
@@ -285,7 +288,7 @@ QString ElementQueryWidget::queryStr() const
 	if (ui->m_edit_sql_query_cb->isChecked()) {
 		return ui->m_sql_query->text();
 	}
-		//Made a string list with the colomns (keys) choosen by the user
+		//Made a string list with the columns (keys) chosen by the user
 	QStringList keys = selectedKeys();
 
 	QString select ="SELECT ";
@@ -310,22 +313,22 @@ QString ElementQueryWidget::queryStr() const
 			case 0: //No filter
 				break;
 			case 1: //Not empty
-				filter_ += QString(" AND ") += key += " IS NOT NULL";
+				filter_ += QStringLiteral(" AND ") += key += " != ''";
 				break;
 			case 2: //empty
-				filter_ += QString(" AND ") += key += " IS NULL";
+				filter_ += QStringLiteral(" AND (%1 IS NULL OR %1 = '')").arg(key);
 				break;
 			case 3: // contain
-				filter_ += QString(" AND ") += key += QString(" LIKE'%") += f.second += "%'";
+				filter_ += QStringLiteral(" AND ") += key += QStringLiteral(" LIKE'%") += f.second += "%'";
 				break;
 			case 4: // not contain
-				filter_ += QString(" AND ") += key += QString(" NOT LIKE'%") += f.second += "%'";
+				filter_ += QStringLiteral(" AND ") += key += QStringLiteral(" NOT LIKE'%") += f.second += "%'";
 				break;
 			case 5: // is equal
-				filter_ += QString(" AND ") += key += QString("='") += f.second += "'";
+				filter_ += QStringLiteral(" AND ") += key += QStringLiteral("='") += f.second += "'";
 				break;
 			case 6: // is not equal
-				filter_ += QString(" AND ") += key += QString("!='") += f.second += "'";
+				filter_ += QStringLiteral(" AND ") += key += QStringLiteral("!='") += f.second += "'";
 				break;
 		}
 	}
@@ -337,27 +340,32 @@ QString ElementQueryWidget::queryStr() const
 	bool b = false;
 	if (ui->m_terminal_cb->isChecked()) {
 		if (b) where +=" OR";
-		where += " element_type = 'Terminale'";
+		where +=  QStringLiteral(" element_type = '") += ElementData::typeToString(ElementData::Terminale) += "'";
+		b = true;
+	}
+	if (ui->m_thumbnail_cb->isChecked()) {
+		if (b) where +=" OR";
+		where +=  QStringLiteral(" element_type = '") += ElementData::typeToString(ElementData::Thumbnail) += "'";
 		b = true;
 	}
 	if (ui->m_simple_cb->isChecked()) {
 		if (b) where +=" OR";
-		where += " element_type = 'Simple'";
+		where +=  QStringLiteral(" element_type = '") += ElementData::typeToString(ElementData::Simple) += "'";
 		b = true;
 	}
 	if (ui->m_button_cb->isChecked())     {
 		if (b) where +=" OR";
-		where += " element_sub_type = 'commutator'";
+		where +=  QStringLiteral(" element_sub_type = '") += ElementData::masterTypeToString(ElementData::Commutator) += "'";
 		b = true;
 	}
 	if (ui->m_coil_cb->isChecked()) {
 		if (b) where +=" OR";
-		where += " element_sub_type = 'coil'";
+		where +=  QStringLiteral(" element_sub_type = '") += ElementData::masterTypeToString(ElementData::Coil) += "'";
 		b = true;
 	}
 	if (ui->m_protection_cb->isChecked()) {
 		if (b) where +=" OR";
-		where += " element_sub_type = 'protection'";
+		where +=  QStringLiteral(" element_sub_type = '") += ElementData::masterTypeToString(ElementData::Protection) += "'";
 	}
 	where.append(")");
 
@@ -397,7 +405,7 @@ void ElementQueryWidget::setGroupBy(QString text, bool set)
 /**
 	@brief ElementQueryWidget::setCount
 	Add the query instruction COUNT.
-	Unlike setGroupBy, you have to write the entire sentance.
+	Unlike setGroupBy, you have to write the entire sentence.
 	ex : text = "COUNT(*) AS designation_qty".
 	the query will contain what you write.
 	@param text : the count instruction
@@ -429,7 +437,7 @@ void ElementQueryWidget::updateQueryLine()
 */
 QStringList ElementQueryWidget::selectedKeys() const
 {
-		//Made a string list with the colomns (keys) choosen by the user
+		//Made a string list with the columns (keys) chosen by the user
 	QStringList keys;
 	int row = 0;
 	while (auto *item = ui->m_choosen_list->item(row))
