@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2021 The QElectroTech Team
+	Copyright 2006-2023 The QElectroTech Team
 	This file is part of QElectroTech.
 	
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -283,6 +283,7 @@ class Diagram : public QGraphicsScene
 		void findElementRequired(const ElementsLocation &);
 
 		void diagramActivated();
+		void diagramInformationChanged();
 };
 Q_DECLARE_METATYPE(Diagram *)
 
@@ -340,7 +341,7 @@ inline bool Diagram::displayGrid() {
 
 /**
 	@brief Diagram::setUseBorder
-	Set whether the diagram border (including rows/colums headers and the title
+	Set whether the diagram border (including rows/columns headers and the title
 	block) should be rendered along with the diagram. When set to false, the size
 	of the smallest rectangle containing all items is considered as the diagram
 	size.
@@ -361,7 +362,7 @@ inline bool Diagram::useBorder() {
 
 /**
 	@brief Diagram::setBorderOptions
-	Set the rendering options for the diagram border (including rows/colums
+	Set the rendering options for the diagram border (including rows/columns
 	headers and the title block)
 	@param bo Enabled options ORed together
 	@see BorderOptions
@@ -374,7 +375,7 @@ inline void Diagram::setBorderOptions(Diagram::BorderOptions bo) {
 
 /**
 	@brief Diagram::borderOptions
-	@return The rendering optios for the diagram border
+	@return The rendering options for the diagram border
 	@see setBorderOptions
 */
 inline Diagram::BorderOptions Diagram::borderOptions() {
