@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2021 The QElectroTech Team
+	Copyright 2006-2023 The QElectroTech Team
 	This file is part of QElectroTech.
 
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -39,7 +39,7 @@
  * designation                    -> exhaustive comment used to explain what the element does.
  * description                    -> exhaustive description used to explain what the element does.
  * plant                          -> the plant assigned to the element
- * comment                        -> a little comment wich can be displayed in the folio
+ * comment                        -> a little comment which can be displayed in the folio
  * manufacturer                   -> the manufacturer of the element
  * manufacturer_reference         -> the manufacturer reference of the element
  * quantity                       -> quantity of the element
@@ -81,13 +81,14 @@ class DiagramContext
 		void fromXml(const pugi::xml_node &dom_element, const QString &tag_name = "property");
 		void toSettings(QSettings &, const QString &) const;
 		void fromSettings(QSettings &, const QString &);
-		
-		static QString validKeyRegExp();
+
+		static bool isKeyAcceptable(const QString &);
 	
 	private:
 		static bool stringLongerThan(const QString &, const QString &);
-		bool keyIsAcceptable(const QString &) const;
-			/// Diagram context data (key/value pairs)
+		static QString validKeyRegExp();
+
+		/// Diagram context data (key/value pairs)
 		QHash<QString, QVariant> m_content;
 		QHash<QString, bool> m_content_show;
 };
