@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2021 The QElectroTech Team
+	Copyright 2006-2023 The QElectroTech Team
 	This file is part of QElectroTech.
 
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -90,54 +90,6 @@ void ElementEditionCommand::setElementView(ElementView *view) {
 	m_view = view;
 }
 
-/*** DeletePartsCommand ***/
-/**
-	Constructeur
-	@param scene ElementScene concernee
-	@param parts Liste des parties supprimees
-	@param parent QUndoCommand parent
-*/
-DeletePartsCommand::DeletePartsCommand(
-	ElementScene *scene,
-	const QList<QGraphicsItem *>& parts,
-	QUndoCommand *parent
-) :
-	ElementEditionCommand(QObject::tr("suppression", "undo caption"), scene, nullptr, parent),
-	deleted_parts(parts)
-{
-	foreach(QGraphicsItem *qgi, deleted_parts) {
-		m_scene -> qgiManager().manage(qgi);
-	}
-}
-
-/// Destructeur : detruit egalement les parties supprimees
-DeletePartsCommand::~DeletePartsCommand()
-{
-	foreach(QGraphicsItem *qgi, deleted_parts) {
-		m_scene -> qgiManager().release(qgi);
-	}
-}
-
-/// Restaure les parties supprimees
-void DeletePartsCommand::undo()
-{
-	m_scene -> blockSignals(true);
-	foreach(QGraphicsItem *qgi, deleted_parts) {
-		m_scene -> addItem(qgi);
-	}
-	m_scene -> blockSignals(false);
-}
-
-/// Supprime les parties
-void DeletePartsCommand::redo()
-{
-	m_scene -> blockSignals(true);
-	foreach(QGraphicsItem *qgi, deleted_parts) {
-		m_scene -> removeItem(qgi);
-	}
-	m_scene -> blockSignals(false);
-}
-
 /*** CutPartsCommand ***/
 /**
 	Constructeur
@@ -150,7 +102,7 @@ CutPartsCommand::CutPartsCommand(
 	const QList<QGraphicsItem *>& parts,
 	QUndoCommand *parent
 ) :
-	DeletePartsCommand(scene, parts, parent)
+	DeletePartsCommand(scene, parts.toVector(), parent)
 {
 	setText(QString(QObject::tr("couper des parties", "undo caption")));
 }
@@ -203,58 +155,6 @@ void MovePartsCommand::redo()
 	foreach(QGraphicsItem *qgi, moved_parts) qgi -> moveBy(movement.x(), movement.y());
 }
 
-/*** AddPartCommand ***/
-/**
-	Constructeur
-	@param name Nom de la partie ajoutee
-	@param scene ElementScene concernee
-	@param p partie ajoutee
-	@param parent QUndoCommand parent
-*/
-AddPartCommand::AddPartCommand(
-	const QString &name,
-	ElementScene *scene,
-	QGraphicsItem *p,
-	QUndoCommand *parent
-) :
-	ElementEditionCommand(QString(QObject::tr("ajout %1", "undo caption")).arg(name), scene, nullptr, parent),
-	part(p),
-	first_redo(true)
-{
-	m_scene -> qgiManager().manage(part);
-}
-
-/// Destructeur
-AddPartCommand::~AddPartCommand()
-{
-	m_scene -> qgiManager().release(part);
-}
-
-/// Annule l'ajout
-void AddPartCommand::undo()
-{
-	m_scene -> removeItem(part);
-}
-
-/// Refait l'ajout
-void AddPartCommand::redo()
-{
-	// le premier appel a redo, lors de la construction de l'objet, ne doit pas se faire
-	if (first_redo) {
-		if (!part -> zValue()) {
-			// the added part has no specific zValue already defined, we put it
-			// above existing items (but still under terminals)
-			QList<QGraphicsItem *> existing_items = m_scene -> zItems(ElementScene::SortByZValue | ElementScene::SelectedOrNot);
-			qreal z = existing_items.count() ? existing_items.last() -> zValue() + 1 : 1;
-			part -> setZValue(z);
-		}
-		m_scene -> clearSelection();
-		first_redo = false;
-		return;
-	}
-	m_scene -> addItem(part);
-}
-
 /**
 	Constructeur
 	@param element_scene Element edite
@@ -282,13 +182,17 @@ ChangeNamesCommand::~ChangeNamesCommand()
 /// Annule le changement
 void ChangeNamesCommand::undo()
 {
-	m_scene -> setNames(names_before);
+	auto data = m_scene->elementData();
+	data.m_names_list = names_before;
+	m_scene->setElementData(data);
 }
 
 /// Refait le changement
 void ChangeNamesCommand::redo()
 {
-	m_scene -> setNames(names_after);
+	auto data = m_scene->elementData();
+	data.m_names_list = names_after;
+	m_scene->setElementData(data);
 }
 
 /**
@@ -453,13 +357,17 @@ ChangeInformationsCommand::~ChangeInformationsCommand()
 /// Annule le changement d'autorisation pour les connexions internes
 void ChangeInformationsCommand::undo()
 {
-	m_scene -> setInformations(old_informations_);
+	auto data = m_scene->elementData();
+	data.m_drawing_information = old_informations_;
+	m_scene->setElementData(data);
 }
 
 /// Refait le changement d'autorisation pour les connexions internes
 void ChangeInformationsCommand::redo()
 {
-	m_scene -> setInformations(new_informations_);
+	auto data = m_scene->elementData();
+	data.m_drawing_information = new_informations_;
+	m_scene->setElementData(data);
 }
 
 /**
@@ -572,45 +480,96 @@ void ScalePartsCommand::adjustText()
 		setText(QObject::tr("redimensionnement de %1 primitives", "undo caption -- %1 always > 1").arg(scaled_primitives_.count()));
 	}
 }
+
 /**
-	@brief ChangePropertiesCommand::ChangePropertiesCommand
-	Change the properties of the drawed element
-	@param scene : scene to belong the property
-	@param type : new type of element.
-	@param info
-	@param elmt_info : new info about type.
-	@param parent : parent undo
+ * @brief changeElementDataCommand::changeElementDataCommand
+ * Change the properties of the drawn element
+ * @param scene : scene belonging to the property
+ * @param old_data : old data
+ * @param new_data : new data
+ * @param parent : parent undo command
+ */
+changeElementDataCommand::changeElementDataCommand(ElementScene *scene,
+												   ElementData old_data,
+												   ElementData new_data,
+												   QUndoCommand *parent) :
+	ElementEditionCommand(scene, nullptr, parent),
+	m_old(old_data),
+	m_new(new_data)
+{
+	setText(QObject::tr("Modifier les propriétées de l'élément"));
+}
+
+void changeElementDataCommand::undo() {
+	m_scene->setElementData(m_old);
+	QUndoCommand::undo();
+}
+
+void changeElementDataCommand::redo() {
+	m_scene->setElementData(m_new);
+	QUndoCommand::redo();
+}
+
+RotateElementsCommand::RotateElementsCommand(ElementScene *scene, QUndoCommand *parent) :
+ElementEditionCommand(QObject::tr("Pivoter la selection", "undo caption"), scene, nullptr, parent)
+{
+	m_items = scene->selectedItems();
+}
+
+/**
+	@brief RotateElementsCommand::undo
 */
-ChangePropertiesCommand::ChangePropertiesCommand(
-		ElementScene *scene,
-		const QString& type,
-		const DiagramContext& info,
-		const DiagramContext& elmt_info,
-		QUndoCommand *parent) :
-	ElementEditionCommand(scene, nullptr, parent)
+void RotateElementsCommand::undo()
 {
-	m_type << scene->m_elmt_type << type;
-	m_kind_info << scene->m_elmt_kindInfo << info;
-	m_elmt_info << scene->m_elmt_information << elmt_info;
-	setText(QObject::tr("Modifier les propriétés"));
+	for (QGraphicsItem *item : m_items)
+	{
+		if (item->type() == PartTerminal::Type) {
+			PartTerminal* term = qgraphicsitem_cast<PartTerminal*>(item);
+			term->setRotation(term->rotation()-90);
+		}
+		else if (item->type() == PartRectangle::Type) {
+			PartRectangle* rect = qgraphicsitem_cast<PartRectangle*>(item);
+			rect->setRotation(rect->rotation()-90);
+		}
+		else if (item->type() == PartLine::Type) {
+			PartLine* line = qgraphicsitem_cast<PartLine*>(item);
+			line->setRotation(line->rotation()-15);
+		}
+		else if (item->type() == PartPolygon::Type) {
+			PartPolygon* poly = qgraphicsitem_cast<PartPolygon*>(item);
+			poly->setRotation(poly->rotation()-15);
+		}
+		else {
+			item->setRotation(item->rotation()-15);
+		}
+	}
 }
-
-ChangePropertiesCommand::~ChangePropertiesCommand()
-{}
-
-void ChangePropertiesCommand::undo()
+/**
+	@brief RotateElementsCommand::redo
+*/
+void RotateElementsCommand::redo()
 {
-	m_scene->m_elmt_type = m_type.first();
-	m_scene->m_elmt_kindInfo = m_kind_info.first();
-	m_scene->setElementInfo(m_elmt_info.first());
+	for (QGraphicsItem *item : m_items)
+	{
+		if (item->type() == PartTerminal::Type) {
+			PartTerminal* term = qgraphicsitem_cast<PartTerminal*>(item);
+			term->setRotation(term->rotation()+90);
+		}
+		else if (item->type() == PartRectangle::Type) {
+			PartRectangle* rect = qgraphicsitem_cast<PartRectangle*>(item);
+			rect->setRotation(rect->rotation()+90);
+		}
+		else if (item->type() == PartLine::Type) {
+			PartLine* line = qgraphicsitem_cast<PartLine*>(item);
+			line->setRotation(line->rotation()+15);
+		}
+		else if (item->type() == PartPolygon::Type) {
+			PartPolygon* poly = qgraphicsitem_cast<PartPolygon*>(item);
+			poly->setRotation(poly->rotation()+15);
+		}
+		else {
+			item->setRotation(item->rotation()+15);
+		}
+	}
+
 }
-
-void ChangePropertiesCommand::redo()
-{
-	m_scene->m_elmt_type = m_type.last();
-	m_scene->m_elmt_kindInfo = m_kind_info.last();
-	m_scene->setElementInfo(m_elmt_info.last());
-}
-
-
-
