@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2021 The QElectroTech Team
+	Copyright 2006-2023 The QElectroTech Team
 	This file is part of QElectroTech.
 	
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -22,6 +22,20 @@
 #include "elementcontent.h"
 #include "elementscene.h"
 #include "elementview.h"
+#include "graphicspart/abstractpartellipse.h"
+#include "graphicspart/customelementgraphicpart.h"
+#include "graphicspart/customelementpart.h"
+#include "graphicspart/partarc.h"
+#include "graphicspart/partdynamictextfield.h"
+#include "graphicspart/partellipse.h"
+#include "graphicspart/partline.h"
+#include "graphicspart/partpolygon.h"
+#include "graphicspart/partrectangle.h"
+#include "graphicspart/partterminal.h"
+#include "graphicspart/parttext.h"
+#include "../QPropertyUndoCommand/qpropertyundocommand.h"
+#include "UndoCommand/deletepartscommand.h"
+
 
 /**
 	@brief The ElementEditionCommand class
@@ -58,29 +72,6 @@ class ElementEditionCommand : public QUndoCommand
 		ElementView *m_view;
 };
 
-/**
-	This command deletes one or several primitives/parts when editing an
-	electrical element.
-*/
-class DeletePartsCommand : public ElementEditionCommand {
-	// constructors, destructor
-	public:
-	DeletePartsCommand(ElementScene *, const QList<QGraphicsItem *>&, QUndoCommand * = nullptr);
-	~DeletePartsCommand() override;
-	private:
-	DeletePartsCommand(const DeletePartsCommand &);
-	
-	// methods
-	public:
-	void undo() override;
-	void redo() override;
-	
-	// attributes
-	private:
-	/// Deleted primitives
-	QList<QGraphicsItem *> deleted_parts;
-};
-
 /**
 	This command cut primitives when editing an electrical element.
 */
@@ -119,30 +110,6 @@ class MovePartsCommand : public ElementEditionCommand {
 	bool first_redo;
 };
 
-/**
-	This command adds a primitive when editing an electrical element.
-*/
-class AddPartCommand : public ElementEditionCommand {
-	// constructors, destructor
-	public:
-	AddPartCommand(const QString &, ElementScene *, QGraphicsItem *, QUndoCommand * = nullptr);
-	~AddPartCommand() override;
-	private:
-	AddPartCommand(const AddPartCommand &);
-	
-	// methods
-	public:
-	void undo() override;
-	void redo() override;
-	
-	// attributes
-	private:
-	/// Added primitive
-	QGraphicsItem *part;
-	/// Prevent the first call to redo()
-	bool first_redo;
-};
-
 /**
 	This command changes the translated names of an electrical element.
 */
@@ -262,23 +229,40 @@ class ScalePartsCommand : public ElementEditionCommand {
 	bool first_redo;
 };
 
-class ChangePropertiesCommand : public ElementEditionCommand {
+class changeElementDataCommand : public ElementEditionCommand
+{
 	public:
-	ChangePropertiesCommand (
-			ElementScene *scene,
-			const QString& type,
-			const DiagramContext& info,
-			const DiagramContext& elmt_info,
-			QUndoCommand *parent=nullptr);
-	~ChangePropertiesCommand () override;
+		changeElementDataCommand(ElementScene *scene,
+								 ElementData old_data,
+								 ElementData new_data,
+								 QUndoCommand *parent = nullptr);
+		~changeElementDataCommand() override {}
 
-	void undo() override;
-	void redo() override;
+		void undo() override;
+		void redo() override;
 
 	private:
-	QList <QString> m_type;
-	QList <DiagramContext> m_kind_info;
-	QList < DiagramContext> m_elmt_info;
+		ElementData m_old,
+					m_new;
+};
+
+/**
+    @brief The RotateSelectionInESCommand class
+    Rotate the selected items in the element editor
+*/
+
+class RotateElementsCommand : public ElementEditionCommand
+{
+
+public:
+    RotateElementsCommand(ElementScene *scene, QUndoCommand *parent=nullptr);
+    void undo() override;
+    void redo() override;
+
+private:
+    ElementScene *m_scene =nullptr;
+    QList<QGraphicsItem*> m_items;
+
 };
 
 #endif
