@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2021 The QElectroTech Team
+	Copyright 2006-2023 The QElectroTech Team
 	This file is part of QElectroTech.
 
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -33,7 +33,7 @@
 #include "graphicspart/partrectangle.h"
 #include "graphicspart/partterminal.h"
 #include "graphicspart/parttext.h"
-#include "qetelementeditor.h"
+#include "ui/qetelementeditor.h"
 #include "ui/elementpropertieseditorwidget.h"
 
 #include <QKeyEvent>
@@ -51,7 +51,6 @@
 */
 ElementScene::ElementScene(QETElementEditor *editor, QObject *parent) :
 	QGraphicsScene(parent),
-	m_elmt_type("simple"),
 	m_qgi_manager(this),
 	m_element_editor(editor)
 {
@@ -71,7 +70,25 @@ ElementScene::ElementScene(QETElementEditor *editor, QObject *parent) :
 	connect(&m_undo_stack, SIGNAL(indexChanged(int)),
 		this, SLOT(managePrimitivesGroups()));
 	connect(this, SIGNAL(selectionChanged()),
-		this, SLOT(managePrimitivesGroups()));
+			this, SLOT(managePrimitivesGroups()));
+}
+
+/**
+ * @brief ElementScene::elementData
+ * @return the elementdata using by the scene
+ */
+ElementData ElementScene::elementData() {
+	return m_element_data;
+}
+
+void ElementScene::setElementData(ElementData data)
+{
+	bool emit_ = m_element_data.m_informations != data.m_informations;
+
+	m_element_data = data;
+
+	if (emit_)
+		emit elementInfoChanged();
 }
 
 /**
@@ -102,7 +119,6 @@ void ElementScene::mouseMoveEvent(QGraphicsSceneMouseEvent *e)
 			if (m_event_interface->isFinish()) {
 				delete m_event_interface;
 				m_event_interface = nullptr;
-				emit(partsAdded());
 			}
 			return;
 		}
@@ -134,7 +150,6 @@ void ElementScene::mousePressEvent(QGraphicsSceneMouseEvent *e)
 			if (m_event_interface->isFinish()) {
 				delete m_event_interface;
 				m_event_interface = nullptr;
-				emit(partsAdded());
 			}
 			return;
 		}
@@ -154,7 +169,6 @@ void ElementScene::mouseReleaseEvent(QGraphicsSceneMouseEvent *e)
 			if (m_event_interface->isFinish()) {
 				delete m_event_interface;
 				m_event_interface = nullptr;
-				emit(partsAdded());
 			}
 			return;
 		}
@@ -182,7 +196,6 @@ void ElementScene::mouseDoubleClickEvent(QGraphicsSceneMouseEvent *event)
 			if (m_event_interface->isFinish()) {
 				delete m_event_interface;
 				m_event_interface = nullptr;
-				emit(partsAdded());
 			}
 			return;
 		}
@@ -206,7 +219,6 @@ void ElementScene::keyPressEvent(QKeyEvent *event)
 			{
 				delete m_event_interface;
 				m_event_interface = nullptr;
-				emit(partsAdded());
 			}
 			return;
 		}
@@ -320,8 +332,8 @@ void ElementScene::setEventInterface(ESEventInterface *event_interface)
 	if (m_event_interface)
 	{
 		delete m_event_interface;
-		//We must to re-init because previous interface
-		//Reset his own init when deleted
+		//We must re-init because previous interface
+		//Reset its own init when deleted
 		event_interface->init();
 	}
 	m_event_interface = event_interface;
@@ -437,7 +449,7 @@ const QDomDocument ElementScene::toXml(bool all_parts)
 				  -(qRound(size.y() - (ymargin/2)))));
 
 	root.setAttribute("version", QET::version);
-	root.setAttribute("link_type", m_elmt_type);
+	root.setAttribute("link_type", m_element_data.typeToString(m_element_data.m_type));
 
 	//Uuid used to compare two elements
 	QDomElement uuid = xml_document.createElement("uuid");
@@ -445,29 +457,31 @@ const QDomDocument ElementScene::toXml(bool all_parts)
 	root.appendChild(uuid);
 
 	//names of element
-	root.appendChild(m_names_list.toXml(xml_document));
+	root.appendChild(m_element_data.m_names_list.toXml(xml_document));
 
-	if (m_elmt_type == "slave" || m_elmt_type == "master")
+	auto type_ = m_element_data.m_type;
+	if (type_ == ElementData::Slave  ||
+		type_ == ElementData::Master ||
+		type_ == ElementData::Terminale ||
+		type_ == ElementData::Thumbnail)
 	{
-		QDomElement kindInfo = xml_document.createElement("kindInformations");
-		m_elmt_kindInfo.toXml(kindInfo, "kindInformation");
-		root.appendChild(kindInfo);
+		root.appendChild(m_element_data.kindInfoToXml(xml_document));
 	}
 
-	if(
-			m_elmt_type == "simple"
-			|| m_elmt_type == "master"
-			|| m_elmt_type == "terminal")
+	if(type_ == ElementData::Simple ||
+	   type_ == ElementData::Master ||
+	   type_ == ElementData::Terminale||
+		type_ == ElementData::Thumbnail)
 	{
 		QDomElement element_info = xml_document.createElement("elementInformations");
-		m_elmt_information.toXml(element_info, "elementInformation");
+		m_element_data.m_informations.toXml(element_info, "elementInformation");
 		root.appendChild(element_info);
 	}
 
 	//complementary information about the element
 	QDomElement informations_element = xml_document.createElement("informations");
 	root.appendChild(informations_element);
-	informations_element.appendChild(xml_document.createTextNode(informations()));
+	informations_element.appendChild(xml_document.createTextNode(m_element_data.m_drawing_information));
 
 	QDomElement description = xml_document.createElement("description");
 
@@ -545,9 +559,16 @@ void ElementScene::fromXml(
 {
 	bool state = true;
 
-	//Consider the informations of the element
-	if (consider_informations) {
-		state = applyInformations(xml_document);
+		//Consider the informations of the element
+	if (consider_informations)
+	{
+			// Root must be an element definition
+		QDomElement root = xml_document.documentElement();
+
+		if (root.tagName() == "definition" &&
+			root.attribute("type") == "element") {
+			m_element_data.fromXml(root);
+		}
 	}
 
 	if (state)
@@ -700,16 +721,45 @@ QETElementEditor* ElementScene::editor() const
 }
 
 /**
-	@brief ElementScene::setElementInfo
-	@param dc
-*/
-void ElementScene::setElementInfo(const DiagramContext& dc)
+ * @brief ElementScene::addItems
+ * Add items to the scene and emit partsAdded.
+ * Prefer always use this method instead of QGraphicsScene::addItem
+ * even if you want to add one item, for gain the signal emission
+ * @param items
+ */
+void ElementScene::addItems(QVector<QGraphicsItem *> items)
 {
-	if(m_elmt_information != dc)
-	{
-		m_elmt_information = dc;
-		emit elementInfoChanged();
+	for (const auto &item : items) {
+		addItem(item);
 	}
+
+	emit partsAdded();
+}
+
+/**
+ * @brief ElementScene::removeItems
+ * Remove items from the scene and emit partsRemoved.
+ * Prefer always use this method instead of QGraphicsScene::removeItem
+ * even if you want to remove one item, for gain the signal emission
+ * @param items
+ */
+void ElementScene::removeItems(QVector<QGraphicsItem *> items)
+{
+	const int previous_selected_count{selectedItems().size()};
+
+		//block signal to avoid multiple emit of selection changed,
+		//we emit this signal only once at the end of this function.
+	blockSignals(true);
+	for (const auto &item : items) {
+		removeItem(item);
+	}
+	blockSignals(false);
+
+	if (previous_selected_count != selectedItems().size()) {
+		emit selectionChanged();
+	}
+
+	emit partsRemoved();
 }
 
 /**
@@ -722,11 +772,11 @@ void ElementScene::slot_select(const ElementContent &content)
 {
 	blockSignals(true);
 
-	/* Befor clear selection,
-	 * we must to remove the handlers items in @content,
+	/* Before clearing selection,
+	 * we must remove the handlers items in @content,
 	 * because if in @content there are a selected item,
 	 * but also its handlers items, When item is deselected,
-	 * the item delete its handlers items,
+	 * the item deletes its handlers items,
 	 * then handlers in content doesn't exist anymore and cause segfault
 	 */
 	QList<QGraphicsItem*> items_list;
@@ -783,18 +833,15 @@ void ElementScene::slot_invertSelection()
 */
 void ElementScene::slot_delete()
 {
-	// check that there is something selected
-	// verifie qu'il y a qqc de selectionne
-	QList<QGraphicsItem *> selected_items = selectedItems();
-	if (selected_items.isEmpty()) return;
+	const auto selected_items{selectedItems().toVector()};
+	if (selected_items.isEmpty()) {
+		return;
+	}
 
-	// erase everything that is selected
-	// efface tout ce qui est selectionne
 	m_undo_stack.push(new DeletePartsCommand(this, selected_items));
 
-	// removing items does not trigger QGraphicsScene::selectionChanged()
-	emit(partsRemoved());
-	emit(selectionChanged());
+		// removing items does not trigger QGraphicsScene::selectionChanged()
+	emit selectionChanged();
 }
 
 /**
@@ -833,7 +880,7 @@ void ElementScene::slot_editAuthorInformations()
 	// ajoute un QTextEdit au dialogue
 	QTextEdit *text_field = new QTextEdit();
 	text_field -> setAcceptRichText(false);
-	text_field -> setPlainText(informations());
+	text_field -> setPlainText(m_element_data.m_drawing_information);
 	text_field -> setReadOnly(is_read_only);
 	dialog_layout -> addWidget(text_field);
 
@@ -851,10 +898,10 @@ void ElementScene::slot_editAuthorInformations()
 	if (dialog_author.exec() == QDialog::Accepted && !is_read_only)
 	{
 		QString new_infos = text_field -> toPlainText().remove(QChar(13)); // CR-less text
-		if (new_infos != informations())
+		if (new_infos != m_element_data.m_drawing_information)
 		{
 			undoStack().push(new ChangeInformationsCommand(
-								 this, informations(), new_infos));
+								 this, m_element_data.m_drawing_information, new_infos));
 		}
 	}
 }
@@ -865,20 +912,15 @@ void ElementScene::slot_editAuthorInformations()
 */
 void  ElementScene::slot_editProperties()
 {
-	QString type = m_elmt_type;
-	DiagramContext kind_info = m_elmt_kindInfo;
-	DiagramContext elmt_info = m_elmt_information;
-
-	ElementPropertiesEditorWidget epew(type, kind_info, elmt_info);
+	ElementPropertiesEditorWidget epew(m_element_data);
 	epew.exec();
 
-	if (type != m_elmt_type ||
-		kind_info != m_elmt_kindInfo ||
-		elmt_info != m_elmt_information)
-		undoStack().push(new ChangePropertiesCommand(this,
-								 type,
-								 kind_info,
-								 elmt_info));
+	if (m_element_data != epew.editedData())
+	{
+		undoStack().push(new changeElementDataCommand(this,
+													  m_element_data,
+													  epew.editedData()));
+	}
 }
 
 /**
@@ -898,15 +940,15 @@ void ElementScene::slot_editNames()
 	dialog_.setInformationText(tr("Vous pouvez spécifier le nom de l'élément dans plusieurs langues."));
 
 	NameListWidget *nlw_ = dialog_.namelistWidget();
-	nlw_->setNames(m_names_list);
+	nlw_->setNames(m_element_data.m_names_list);
 	nlw_->setReadOnly(is_read_only);
 
 	if (dialog_.exec() == QDialog::Accepted && !is_read_only && !nlw_->isEmpty())
 	{
 		NamesList new_names = nlw_->names();
-		if (new_names != m_names_list) {
+		if (new_names != m_element_data. m_names_list) {
 			undoStack().push(new ChangeNamesCommand(this,
-								m_names_list,
+								m_element_data.m_names_list,
 								new_names));
 		}
 	}
@@ -1087,62 +1129,6 @@ QRectF ElementScene::elementContentBoundingRect(
 	return(bounding_rect);
 }
 
-/**
-	@brief ElementScene::applyInformations
-	Applies the information (dimensions, hostpot, orientations,
-	internal connections, names and additional information)
-	contained in an XML document.
-	\~French Applique les informations (dimensions, hostpot, orientations,
-	connexions internes, noms et informations complementaires)
-	contenu dans un document XML.
-	\~ @param xml_document : Document XML a analyser
-	\~ @return
-	true if reading and applying the information went well, false otherwise.
-	\~French true si la lecture et l'application
-	des informations s'est bien passee, false sinon.
-*/
-bool ElementScene::applyInformations(const QDomDocument &xml_document)
-{
-	// Root must be an element definition
-	QDomElement root = xml_document.documentElement();
-
-	if (
-			root.tagName() != "definition"
-			||
-			root.attribute("type") != "element")
-		return(false);
-
-	//Extract info about element type
-	m_elmt_type = root.attribute("link_type", "simple");
-	m_elmt_kindInfo.fromXml(
-				root.firstChildElement("kindInformations"),
-				"kindInformation");
-	//Extract info of element
-	m_elmt_information.fromXml(
-				root.firstChildElement("elementInformations"),
-				"elementInformation");
-
-	//Extract names of xml definition
-	m_names_list.fromXml(root);
-
-	//extract additional informations
-	setInformations(QString());
-	for (QDomNode node = root.firstChild() ;
-		 !node.isNull() ;
-		 node = node.nextSibling())
-	{
-		QDomElement elmt = node.toElement();
-		if (elmt.isNull()) continue;
-		if (elmt.tagName() == "informations")
-		{
-			setInformations(elmt.text());
-			break;
-		}
-	}
-
-	return(true);
-}
-
 /**
 	@brief ElementScene::loadContent
 	Create and load the content describe in the xml document.
@@ -1378,24 +1364,28 @@ void ElementScene::managePrimitivesGroups()
 		m_decorator -> hide();
 	}
 
+	if (m_single_selected_item) {
+		m_single_selected_item->removeHandler();
+		m_single_selected_item.clear();
+	}
+
 		// should we hide the decorator?
-	QList<QGraphicsItem *> selected_items = zItems(
-				ElementScene::Selected
-				| ElementScene::IncludeTerminals);
+	const auto selected_items{zItems(ElementScene::Selected | ElementScene::IncludeTerminals)};
 	if (selected_items.size() <= 1)
 	{
-		m_decorator -> hide();
+		m_decorator->hide();
+
+		if (!selected_items.isEmpty())
+		{
+			if (CustomElementGraphicPart *item_ = dynamic_cast<CustomElementGraphicPart *>(selected_items.first()))
+			{
+				item_->addHandler();
+				m_single_selected_item = item_;
+			}
+		}
 	}
 	else
 	{
-		for(QGraphicsItem *qgi : selected_items)
-		{
-			/* We recall set selected,
-			 * then every primitive will remove there handler
-			 * because there are several item selected
-			 */
-			qgi->setSelected(true);
-		}
 		m_decorator -> setZValue(1000000);
 		m_decorator -> setPos(0, 0);
 		m_decorator -> setItems(selected_items);
