@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2021 The QElectroTech Team
+	Copyright 2006-2023 The QElectroTech Team
 	This file is part of QElectroTech.
 	
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -21,6 +21,7 @@
 #include "../diagramcontext.h"
 #include "../qgimanager.h"
 #include "elementcontent.h"
+#include "../properties/elementdata.h"
 
 #include <QtWidgets>
 #include <QtXml>
@@ -31,11 +32,15 @@ class ElementPrimitiveDecorator;
 class QETElementEditor;
 class ESEventInterface;
 class QKeyEvent;
+class CustomElementGraphicPart;
 /**
 	@brief The ElementScene class
-	This class is the canvas allowing the visual edition of an electrial element.
+	This class is the canvas allowing the visual edition of an electrical element.
 	It displays the various primitives composing the drawing of the element,
 	the border due to its fixed size and its hotspot.
+
+	For add and remove item prefer use custom method addItems and removeItems instead of
+	addItem and removeItem, because these methods emit signal partAdded and partRemoved.
 */
 class ElementScene : public QGraphicsScene
 {
@@ -65,11 +70,7 @@ class ElementScene : public QGraphicsScene
 	
 		// attributes
 	private:
-		NamesList m_names_list; /// List of localized names
-		QString m_informations; /// Extra informations
-		QString m_elmt_type; /// element type
-		DiagramContext m_elmt_kindInfo,
-			       m_elmt_information; /// element kind info
+		ElementData m_element_data; ///ElementData. Actually in transition with old data storage
 		QGIManager m_qgi_manager;
 		QUndoStack m_undo_stack;
 
@@ -87,24 +88,25 @@ class ElementScene : public QGraphicsScene
 
 		int m_x_grid,
 		    m_y_grid;
+
+		QPointer<CustomElementGraphicPart> m_single_selected_item;
 	
 		// methods
 	public:
+		ElementData elementData();
+		void setElementData(ElementData data);
+
 		void setEventInterface (ESEventInterface *event_interface);
 		void clearEventInterface();
+
 		void setBehavior (ElementScene::Behavior);
 		ElementScene::Behavior behavior() const;
+
 		QPointF snapToGrid(QPointF point);
-		void setNames(const NamesList &);
-		NamesList names() const;
-		QString informations() const;
-		void setInformations(const QString &);
-		QString elementType () const {return m_elmt_type;}
-		DiagramContext elementKindInfo () const {return m_elmt_kindInfo;}
-		DiagramContext elementInformation() const {return m_elmt_information;}
 		virtual int xGrid() const;
 		virtual int yGrid() const;
 		virtual void setGrid(int, int);
+
 		virtual const QDomDocument toXml(bool = true);
 		virtual QRectF boundingRectFromXml(const QDomDocument &);
 		virtual void fromXml(const QDomDocument &,
@@ -128,7 +130,8 @@ class ElementScene : public QGraphicsScene
 		void cut();
 		void copy();
 		QETElementEditor* editor() const;
-		void setElementInfo(const DiagramContext& dc);
+		void addItems(QVector<QGraphicsItem *> items);
+		void removeItems(QVector<QGraphicsItem *> items);
 	
 	protected:
 		void mouseMoveEvent         (QGraphicsSceneMouseEvent *) override;
@@ -137,12 +140,10 @@ class ElementScene : public QGraphicsScene
 		void mouseDoubleClickEvent (QGraphicsSceneMouseEvent *event) override;
 		void keyPressEvent         (QKeyEvent *event) override;
 		void contextMenuEvent(QGraphicsSceneContextMenuEvent *event) override;
-
 		void drawForeground(QPainter *, const QRectF &) override;
 	
 	private:
 		QRectF elementContentBoundingRect(const ElementContent &) const;
-		bool applyInformations(const QDomDocument &);
 		ElementContent loadContent(const QDomDocument &);
 		ElementContent addContent(const ElementContent &);
 		ElementContent addContentAtPos(const ElementContent &, const QPointF &);
@@ -180,39 +181,4 @@ class ElementScene : public QGraphicsScene
 
 Q_DECLARE_OPERATORS_FOR_FLAGS(ElementScene::ItemOptions)
 
-
-/**
-	@brief ElementScene::setNames
-	@param nameslist New set of naes for the currently edited element
-*/
-inline void ElementScene::setNames(const NamesList &nameslist) {
-	m_names_list = nameslist;
-}
-
-/**
-	@brief ElementScene::names
-	@return the list of names of the currently edited element
-*/
-inline NamesList ElementScene::names() const
-{
-	return(m_names_list);
-}
-
-/**
-	@brief ElementScene::informations
-	@return extra informations of the currently edited element
-*/
-inline QString ElementScene::informations() const
-{
-	return(m_informations);
-}
-
-/**
-	@brief ElementScene::setInformations
-	@param infos new extra information for the currently edited element
-*/
-inline void ElementScene::setInformations(const QString &infos) {
-	m_informations = infos;
-}
-
 #endif
