@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2021 The QElectroTech Team
+	Copyright 2006-2023 The QElectroTech Team
 	This file is part of QElectroTech.
 
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -19,7 +19,7 @@
 
 #include "../qetapp.h"
 #include "UndoCommand/pastepartscommand.h"
-#include "qetelementeditor.h"
+#include "ui/qetelementeditor.h"
 /**
 	Constructeur
 	@param scene ElementScene visualisee par cette ElementView
