@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2021 The QElectroTech Team
+	Copyright 2006-2023 The QElectroTech Team
 	This file is part of QElectroTech.
 
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -17,10 +17,10 @@
 */
 #include "eseventaddline.h"
 
-#include "../editorcommands.h"
+#include "../UndoCommand/addpartcommand.h"
 #include "../elementscene.h"
 #include "../graphicspart/partline.h"
-#include "../qetelementeditor.h"
+#include "../ui/qetelementeditor.h"
 
 #include <QGraphicsSceneMouseEvent>
 #include <QObject>
