@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2021 The QElectroTech Team
+	Copyright 2006-2023 The QElectroTech Team
 	This file is part of QElectroTech.
 
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -17,7 +17,7 @@
 */
 #include "eseventaddterminal.h"
 
-#include "../editorcommands.h"
+#include "../UndoCommand/addpartcommand.h"
 #include "../elementscene.h"
 #include "../graphicspart/partterminal.h"
 
@@ -88,6 +88,7 @@ bool ESEventAddTerminal::mouseReleaseEvent(QGraphicsSceneMouseEvent *event) {
 */
 bool ESEventAddTerminal::keyPressEvent(QKeyEvent *event) {
 	if (event -> key() == Qt::Key_Space) {
+	
 		switch (m_terminal->orientation()) {
 			case Qet::North :
 				m_terminal -> setOrientation(Qet::East);
