@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2021 The QElectroTech Team
+	Copyright 2006-2023 The QElectroTech Team
 	This file is part of QElectroTech.
 
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -18,7 +18,8 @@
 #include "eseventinterface.h"
 
 #include "../elementscene.h"
-#include "../qetelementeditor.h"
+#include "../ui/qetelementeditor.h"
+#include "../elementview.h"
 
 #include <QGraphicsSceneMouseEvent>
 
@@ -40,7 +41,7 @@ ESEventInterface::ESEventInterface(ElementScene *scene) :
 void ESEventInterface::init()
 {
 	m_scene->setBehavior(ElementScene::Behavior::AddPart);
-	m_editor->slot_setNoDragToView();
+	m_editor->elementView()->setDragMode(QGraphicsView::NoDrag);
 }
 
 /**
@@ -53,37 +54,37 @@ ESEventInterface::~ESEventInterface()
 	delete m_help_verti;
 
 	m_scene->setBehavior(ElementScene::Behavior::Normal);
-	m_editor->slot_setRubberBandToView();
+	m_editor->elementView()->setDragMode(QGraphicsView::RubberBandDrag);
 }
 
 bool ESEventInterface::mouseDoubleClickEvent(QGraphicsSceneMouseEvent *event) {
-	Q_UNUSED (event);
+	Q_UNUSED (event)
 	return false;
 }
 
 bool ESEventInterface::mousePressEvent(QGraphicsSceneMouseEvent *event) {
-	Q_UNUSED (event);
+	Q_UNUSED (event)
 	return false;
 }
 
 bool ESEventInterface::mouseMoveEvent(QGraphicsSceneMouseEvent *event) {
-	Q_UNUSED (event);
+	Q_UNUSED (event)
 	return false;
 }
 
 bool ESEventInterface::mouseReleaseEvent(QGraphicsSceneMouseEvent *event) {
-	Q_UNUSED (event);
+	Q_UNUSED (event)
 	return false;
 }
 
 bool ESEventInterface::wheelEvent(QGraphicsSceneWheelEvent *event) {
-	Q_UNUSED (event);
+	Q_UNUSED (event)
 	return false;
 }
 
 /**
 	@brief ESEventInterface::keyPressEvent
-	By default, press escape key abort the curent action
+	By default, press escape key abort the current action
 	@param event
 	@return
 */
@@ -97,7 +98,7 @@ bool ESEventInterface::keyPressEvent(QKeyEvent *event) {
 }
 
 bool ESEventInterface::KeyReleaseEvent(QKeyEvent *event) {
-	Q_UNUSED (event);
+	Q_UNUSED (event)
 	return false;
 }
 
