@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2021 The QElectroTech Team
+	Copyright 2006-2023 The QElectroTech Team
 	This file is part of QElectroTech.
 	
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -298,6 +298,9 @@ class CustomElementGraphicPart : public QGraphicsObject, public CustomElementPar
 			return QObject::property(name);}
 
 		virtual QPainterPath shadowShape ()const = 0;
+
+		virtual void addHandler() {}
+		virtual void removeHandler() {}
 		virtual void setHandlerColor(QPointF /*pos*/,
 					     const QColor &/*color*/) {}
 		virtual void resetAllHandlerColor() {}
@@ -309,8 +312,6 @@ class CustomElementGraphicPart : public QGraphicsObject, public CustomElementPar
 		void applyStylesToQPainter(QPainter &) const;
 		void drawShadowShape (QPainter *painter);
 
-		QVariant itemChange(GraphicsItemChange change,
-				    const QVariant &value) override;
 		void hoverEnterEvent(QGraphicsSceneHoverEvent *event) override;
 		void hoverLeaveEvent(QGraphicsSceneHoverEvent *event) override;
 
@@ -328,6 +329,7 @@ class CustomElementGraphicPart : public QGraphicsObject, public CustomElementPar
 		Color _color;
 		bool _antialiased;
 		QPointF m_origin_pos;
+		bool m_first_move;
 };
 
 typedef CustomElementGraphicPart CEGP;
