@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2021 The QElectroTech Team
+	Copyright 2006-2023 The QElectroTech Team
 	This file is part of QElectroTech.
 	
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -17,7 +17,8 @@
 */
 #include "customelementpart.h"
 
-#include "../qetelementeditor.h"
+#include "../ui/qetelementeditor.h"
+#include "../elementscene.h"
 
 /// @return le QETElementEditor auquel cet editeur appartient
 QETElementEditor *CustomElementPart::elementEditor() const
