@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2021 The QElectroTech Team
+	Copyright 2006-2023 The QElectroTech Team
 	This file is part of QElectroTech.
 
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -105,6 +105,7 @@ const QDomElement PartDynamicTextField::toXml(QDomDocument &dom_doc) const
 	root_element.setAttribute("uuid", m_uuid.toString());
 	root_element.setAttribute("frame", m_frame? "true" : "false");
 	root_element.setAttribute("text_width", QString::number(m_text_width));
+	root_element.setAttribute("keep_visual_rotation", m_keep_visual_rotation ? "true" : "false");
 
 	QMetaEnum me = DynamicElementTextItem::textFromMetaEnum();
 	root_element.setAttribute("text_from", me.valueToKey(m_text_from));
@@ -168,6 +169,7 @@ void PartDynamicTextField::fromXml(const QDomElement &dom_elmt) {
 	);
 	setZValue(dom_elmt.attribute("z", QString::number(zValue())).toDouble());
 	QGraphicsTextItem::setRotation(dom_elmt.attribute("rotation", QString::number(0)).toDouble());
+	setKeepVisualRotation(dom_elmt.attribute("keep_visual_rotation", "true") == "true"? true : false);
 
 	if (dom_elmt.hasAttribute("font")) {
 		QFont font_;
@@ -318,7 +320,7 @@ void PartDynamicTextField::setText(const QString &text) {
 void PartDynamicTextField::setInfoName(const QString &info_name) {
 	m_info_name = info_name;
 	if(m_text_from == DynamicElementTextItem::ElementInfo && elementScene())
-		setPlainText(elementScene() -> elementInformation().value(m_info_name).toString());
+		setPlainText(elementScene()->elementData().m_informations.value(m_info_name).toString());
 	emit infoNameChanged(m_info_name);
 }
 
@@ -338,7 +340,7 @@ QString PartDynamicTextField::infoName() const{
 void PartDynamicTextField::setCompositeText(const QString &text) {
 	m_composite_text = text;
 	if(m_text_from == DynamicElementTextItem::CompositeText && elementScene())
-		setPlainText(autonum::AssignVariables::replaceVariable(m_composite_text, elementScene() -> elementInformation()));
+		setPlainText(autonum::AssignVariables::replaceVariable(m_composite_text, elementScene()->elementData().m_informations));
 	emit compositeTextChanged(m_composite_text);
 }
 
@@ -430,6 +432,20 @@ void PartDynamicTextField::setFont(const QFont &font) {
 	emit fontChanged(font);
 }
 
+void PartDynamicTextField::setKeepVisualRotation(const bool &keep)
+{
+	if (keep == this->m_keep_visual_rotation) {
+		return;
+	}
+
+	m_keep_visual_rotation = keep;
+	emit keepVisualRotationChanged(keep);
+}
+
+bool PartDynamicTextField::keepVisualRotation() const {
+	return m_keep_visual_rotation;
+}
+
 /**
 	@brief PartDynamicTextField::mouseMoveEvent
 	@param event
@@ -551,10 +567,10 @@ void PartDynamicTextField::elementInfoChanged()
 		return;
 
 	if(m_text_from == DynamicElementTextItem::ElementInfo)
-		setPlainText(elementScene() -> elementInformation().value(m_info_name).toString());
+		setPlainText(elementScene()->elementData().m_informations.value(m_info_name).toString());
 	else if (m_text_from == DynamicElementTextItem::CompositeText && elementScene())
 		setPlainText(autonum::AssignVariables::replaceVariable(
-			m_composite_text, elementScene() -> elementInformation()));
+			m_composite_text, elementScene()->elementData().m_informations));
 }
 
 void PartDynamicTextField::prepareAlignment()
