@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2021 The QElectroTech Team
+	Copyright 2006-2023 The QElectroTech Team
 	This file is part of QElectroTech.
 
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -72,7 +72,7 @@ void PartTerminal::paint(
 		const QStyleOptionGraphicsItem *options,
 		QWidget *widget)
 {
-	Q_UNUSED(widget);
+	Q_UNUSED(widget)
 	painter -> save();
 
 	// annulation des renderhints
@@ -98,7 +98,7 @@ void PartTerminal::paint(
 	// dessin de la borne en rouge
 	t.setColor(isSelected() ? Terminal::neutralColor : Qt::red);
 	painter -> setPen(t);
-	painter -> drawLine(QPointF(0.0, 0.0), d -> second_point);
+	painter -> drawLine(QPointF(0.0, 0.0), d -> m_second_point);
 
 	// dessin du point d'amarrage au conducteur en bleu
 	t.setColor(isSelected() ? Qt::red : Terminal::neutralColor);
@@ -118,7 +118,7 @@ void PartTerminal::paint(
 QPainterPath PartTerminal::shape() const
 {
 	QPainterPath shape;
-	shape.lineTo(d -> second_point);
+	shape.lineTo(d -> m_second_point);
 
 	QPainterPathStroker pps;
 	pps.setWidth(1);
@@ -132,7 +132,7 @@ QPainterPath PartTerminal::shape() const
 */
 QRectF PartTerminal::boundingRect() const
 {
-	QRectF br(QPointF(0, 0), d -> second_point);
+	QRectF br(QPointF(0, 0), d -> m_second_point);
 	br = br.normalized();
 
 	qreal adjust = (SHADOWS_HEIGHT + 1) / 2;
@@ -140,6 +140,7 @@ QRectF PartTerminal::boundingRect() const
 	return(br);
 }
 
+
 /**
 	Definit l'orientation de la borne
 	@param ori la nouvelle orientation de la borne
@@ -151,6 +152,32 @@ void PartTerminal::setOrientation(Qet::Orientation ori) {
 	updateSecondPoint();
 	emit orientationChanged();
 }
+
+/**
+	Redefines setRotation to call setOrientation
+	@param angle
+*/
+void PartTerminal::setRotation(qreal angle) {
+	qreal angle_mod = std::fmod(angle,360);
+	Qet::Orientation new_ori = Qet::North;
+
+	if      (0   <= angle_mod && angle_mod < 90 ) new_ori = Qet::North;
+	else if (90  <= angle_mod && angle_mod < 180) new_ori = Qet::East;
+	else if (180 <= angle_mod && angle_mod < 270) new_ori = Qet::South;
+	else new_ori = Qet::West;
+
+	setOrientation(new_ori);
+}
+
+qreal PartTerminal::rotation() const {
+	switch (d->m_orientation) {
+		case Qet::North : return 0;
+		case Qet::East  : return 90;
+		case Qet::South : return 180;
+		case Qet::West  : return 270;
+	}
+}
+
 /**
 	@brief PartTerminal::setName
 	@param name
@@ -161,6 +188,20 @@ void PartTerminal::setName(QString& name) {
 	emit nameChanged();
 }
 
+/**
+ * @brief PartTerminal::setTerminalType
+ * Set the type of terminal to 'type'
+ * @param type
+ */
+void PartTerminal::setTerminalType(TerminalData::Type type)
+{
+	if (d->m_type == type) {
+		return;
+	}
+	d->m_type = type;
+	emit terminalTypeChanged();
+}
+
 void PartTerminal::setNewUuid()
 {
 	d -> m_uuid = QUuid::createUuid();
@@ -174,10 +215,10 @@ void PartTerminal::updateSecondPoint()
 {
 	qreal ts = 4.0; // terminal size
 	switch(d -> m_orientation) {
-		case Qet::North: d -> second_point = QPointF(0.0,  ts); break;
-		case Qet::East : d -> second_point = QPointF(-ts, 0.0); break;
-		case Qet::South: d -> second_point = QPointF(0.0, -ts); break;
-		case Qet::West : d -> second_point = QPointF(ts,  0.0); break;
+		case Qet::North: d -> m_second_point = QPointF(0.0,  ts); break;
+		case Qet::East : d -> m_second_point = QPointF(-ts, 0.0); break;
+		case Qet::South: d -> m_second_point = QPointF(0.0, -ts); break;
+		case Qet::West : d -> m_second_point = QPointF(ts,  0.0); break;
 	}
 }
 
