@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2021 The QElectroTech Team
+	Copyright 2006-2023 The QElectroTech Team
 	This file is part of QElectroTech.
 	
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -24,13 +24,13 @@
 #include "../../qetinformation.h"
 #include "../../ui/alignmenttextdialog.h"
 #include "../../ui/compositetexteditdialog.h"
-#include "../qetelementeditor.h"
+#include "../ui/qetelementeditor.h"
+#include "../elementscene.h"
 #include "ui_dynamictextfieldeditor.h"
 
 #include <QColorDialog>
 #include <QGraphicsItem>
 #include <QPointer>
-#include <assert.h>
 
 DynamicTextFieldEditor::DynamicTextFieldEditor(QETElementEditor *editor,
 											   PartDynamicTextField *text_field,
@@ -63,7 +63,8 @@ DynamicTextFieldEditor::~DynamicTextFieldEditor()
 	@param part
 	@return true if part can be edited by this widget
 */
-bool DynamicTextFieldEditor::setPart(CustomElementPart *part) {
+bool DynamicTextFieldEditor::setPart(CustomElementPart *part)
+{
 	disconnectConnections();
 
 	QGraphicsItem *qgi = part -> toItem();
@@ -81,24 +82,24 @@ bool DynamicTextFieldEditor::setPart(CustomElementPart *part) {
 	return true;
 }
 
-bool DynamicTextFieldEditor::setParts(QList <CustomElementPart *> parts) {
-	if (parts.isEmpty()) {
+bool DynamicTextFieldEditor::setParts(QList <CustomElementPart *> parts)
+{
+	if (parts.isEmpty())
+	{
 		m_parts.clear();
-		if (m_text_field) {
-			disconnectConnections();
-		}
+		disconnectConnections();
 		m_text_field = nullptr;
+
 		return true;
 	}
 
-	if (PartDynamicTextField *part = static_cast<PartDynamicTextField *>(parts.first())) {
-		if (m_text_field) {
-			disconnectConnections();
-		}
-
+	if (PartDynamicTextField *part = static_cast<PartDynamicTextField *>(parts.first()))
+	{
+		disconnectConnections();
 		m_text_field = part;
 		m_parts.clear();
 		m_parts.append(part);
+
 		for (int i=1; i < parts.length(); i++)
 			m_parts.append(static_cast<PartDynamicTextField*>(parts[i]));
 
@@ -138,6 +139,7 @@ void DynamicTextFieldEditor::updateForm()
 		ui -> m_frame_cb -> setChecked(m_text_field.data() -> frame());
 		ui -> m_user_text_le -> setText(m_text_field.data() -> text());
 		ui -> m_size_sb -> setValue(m_text_field.data() -> font().pointSize());
+		ui->m_keep_visual_rotation_cb->setChecked(m_text_field.data()->keepVisualRotation());
 #ifdef BUILD_WITHOUT_KF5
 #else
 		m_color_kpb -> setColor(m_text_field.data() -> color());
@@ -175,42 +177,34 @@ void DynamicTextFieldEditor::setupWidget()
 	connect(m_color_kpb, &KColorButton::changed,
 			this, &DynamicTextFieldEditor::on_m_color_kpb_changed);
 
-	ui->m_main_grid_layout->addWidget(m_color_kpb, 7, 1, 1, 2);
+	ui->m_main_grid_layout->addWidget(m_color_kpb, 6, 1, 1, 2);
 #endif
 }
 
 void DynamicTextFieldEditor::setUpConnections()
 {
-	assert(m_connection_list.isEmpty());
+	disconnectConnections();
+
 	//Setup the connection
-	m_connection_list << connect(m_text_field.data(), &PartDynamicTextField::colorChanged,
-		[this](){this -> updateForm();});
-	m_connection_list << connect(m_text_field.data(), &PartDynamicTextField::fontChanged,
-		[this](){this -> updateForm();});
-	m_connection_list << connect(m_text_field.data(), &PartDynamicTextField::taggChanged,
-		[this](){this -> updateForm();});
-	m_connection_list << connect(m_text_field.data(), &PartDynamicTextField::textFromChanged,
-		[this](){this -> updateForm();});
-	m_connection_list << connect(m_text_field.data(), &PartDynamicTextField::textChanged,
-		[this](){this -> updateForm();});
-	m_connection_list << connect(m_text_field.data(), &PartDynamicTextField::infoNameChanged,
-		[this](){this -> updateForm();});
-	m_connection_list << connect(m_text_field.data(), &PartDynamicTextField::rotationChanged,
-		[this](){this -> updateForm();});
-	m_connection_list << connect(m_text_field.data(), &PartDynamicTextField::frameChanged,
-		[this](){this -> updateForm();});
-	m_connection_list << connect(m_text_field.data(), &PartDynamicTextField::textWidthChanged,
-		[this](){this -> updateForm();});
-	m_connection_list << connect(m_text_field.data(), &PartDynamicTextField::compositeTextChanged,
-		[this](){this -> updateForm();});
+	m_connection_list << connect(m_text_field.data(), &PartDynamicTextField::colorChanged, this, [=](){this -> updateForm();});
+	m_connection_list << connect(m_text_field.data(), &PartDynamicTextField::fontChanged, this, [=](){this -> updateForm();});
+	m_connection_list << connect(m_text_field.data(), &PartDynamicTextField::taggChanged, this, [=](){this -> updateForm();});
+	m_connection_list << connect(m_text_field.data(), &PartDynamicTextField::textFromChanged, this, [=](){this -> updateForm();});
+	m_connection_list << connect(m_text_field.data(), &PartDynamicTextField::textChanged, this, [=](){this -> updateForm();});
+	m_connection_list << connect(m_text_field.data(), &PartDynamicTextField::infoNameChanged, this, [=](){this -> updateForm();});
+	m_connection_list << connect(m_text_field.data(), &PartDynamicTextField::rotationChanged, this, [=](){this -> updateForm();});
+	m_connection_list << connect(m_text_field.data(), &PartDynamicTextField::frameChanged, this, [=](){this -> updateForm();});
+	m_connection_list << connect(m_text_field.data(), &PartDynamicTextField::textWidthChanged, this, [=](){this -> updateForm();});
+	m_connection_list << connect(m_text_field.data(), &PartDynamicTextField::compositeTextChanged,this, [=](){this -> updateForm();});
+	m_connection_list << connect(m_text_field.data(), &PartDynamicTextField::keepVisualRotationChanged, this, [=](){this -> updateForm();});
 }
 
 void DynamicTextFieldEditor::disconnectConnections()
 {
-	//Remove previous connection
+		//Remove previous connection
 	if(!m_connection_list.isEmpty())
-		for(const QMetaObject::Connection& con : m_connection_list) {
-			disconnect(con);
+		for(const auto &connection : m_connection_list) {
+			disconnect(connection);
 		}
 	m_connection_list.clear();
 }
@@ -224,15 +218,15 @@ void DynamicTextFieldEditor::fillInfoComboBox()
 	ui -> m_elmt_info_cb -> clear();
 
 	QStringList strl;
-	QString type = elementEditor() -> elementScene() -> elementType();
+	auto type = elementEditor()->elementScene()->elementData().m_type;
 
-	if(type.contains("report")) {
+	if(type & ElementData::AllReport) {
 		strl = QETInformation::folioReportInfoKeys();
 	}
 	else {
 		strl = QETInformation::elementInfoKeys();
 	}
-		//We use a QMap because the keys of the map are sorted, then no matter the curent local,
+		//We use a QMap because the keys of the map are sorted, then no matter the current local,
 		//the value of the combo box are always alphabetically sorted
 	QMap <QString, QString> info_map;
 	for(const QString& str : strl)
@@ -332,8 +326,8 @@ void DynamicTextFieldEditor::on_m_elmt_info_cb_activated(const QString &arg1) {
 			QPropertyUndoCommand *undo = new QPropertyUndoCommand(m_parts[i], "infoName", m_parts[i] -> infoName(), info);
 			undo->setText(tr("Modifier l'information d'un texte"));
 			undoStack().push(undo);
-			m_parts[i] -> setPlainText(
-				elementEditor() -> elementScene() -> elementInformation().value(m_parts[i] -> infoName()).toString());
+			m_parts[i]->setPlainText(
+						elementEditor()->elementScene()->elementData().m_informations.value(m_parts[i] -> infoName()).toString());
 		}
 	}
 }
@@ -433,3 +427,16 @@ void DynamicTextFieldEditor::on_m_color_kpb_changed(const QColor &newColor) {
 		}
 	}
 }
+
+void DynamicTextFieldEditor::on_m_keep_visual_rotation_cb_clicked()
+{
+	bool keep = ui -> m_keep_visual_rotation_cb -> isChecked();
+
+	for (int i = 0; i < m_parts.length(); i++) {
+		if(keep != m_parts[i] -> keepVisualRotation()) {
+			QPropertyUndoCommand *undo = new QPropertyUndoCommand(m_parts[i], "keepVisualRotation", m_parts[i] -> frame(), keep);
+			undo -> setText(tr("Modifier la conservation de l'angle"));
+			undoStack().push(undo);
+		}
+	}
+}
