@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2021 The QElectroTech Team
+	Copyright 2006-2023 The QElectroTech Team
 	This file is part of QElectroTech.
 	
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -28,7 +28,6 @@
 #include <QPushButton>
 #include <QTreeView>
 #include <QVBoxLayout>
-#include <QtConcurrent>
 
 /**
 	@brief ElementDialog::ElementDialog
@@ -239,7 +238,7 @@ void ElementDialog::checkAccept()
 /**
 	@brief ElementDialog::location
 	@return The selected location or a null location if user has selected nothing
-	or selection isn't compatible with the curent mode
+	or selection isn't compatible with the current mode
 */
 ElementsLocation ElementDialog::location() const
 {
