@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2021 The QElectroTech Team
+	Copyright 2006-2023 The QElectroTech Team
 	This file is part of QElectroTech.
 
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -20,6 +20,7 @@
 #include "diagram.h"
 #include "qetgraphicsitem/ViewItem/qetgraphicstableitem.h"
 #include "qetgraphicsitem/element.h"
+#include "qetgraphicsitem/terminalelement.h"
 #include "qetproject.h"
 
 #include <QAbstractItemModel>
@@ -50,25 +51,32 @@ ElementProvider::ElementProvider(Diagram *diag) {
 	ie element aren't connected with another element
 	@param filter
 	the filter for search element
-	(You can find all filter with the define in Element.h)
 	@return
 */
-QList <Element *> ElementProvider::freeElement(const int filter) const{
-	QList <Element *> free_elmt;
+QVector <QPointer<Element>> ElementProvider::freeElement(ElementData::Types filter) const
+{
+	QVector<QPointer<Element>> free_elmt;
+	QList<Element *> elmt_list;
 
-	//serch in all diagram
-	foreach (Diagram *d, m_diagram_list) {
-		//get all element in diagram d
-		QList <Element *> elmt_list;
-		elmt_list = d->elements();
-		foreach (Element *elmt, elmt_list) {
-			if (filter & elmt->linkType())
-				if (elmt->isFree()) free_elmt << elmt;
+		//search in all diagram
+	for (const auto &diagram_ : qAsConst(m_diagram_list))
+	{
+			//get all element in diagram d
+		elmt_list = diagram_->elements();
+		for (const auto &elmt_ : qAsConst(elmt_list))
+		{
+			if (filter & elmt_->elementData().m_type &&
+				elmt_->isFree())
+			{
+				free_elmt << elmt_;
+			}
 		}
+			//Clear for next loop
+		elmt_list.clear();
 	}
-	return (free_elmt);
-}
 
+	return free_elmt;
+}
 /**
 	@brief ElementProvider::fromUuids
 	@param uuid_list list of uuid must be found
@@ -90,34 +98,33 @@ QList <Element *> ElementProvider::fromUuids(QList<QUuid> uuid_list) const
 }
 
 /**
-	@brief ElementProvider::find
-	Search and return the asked element corresponding  with the given filter
-	@param filter
-	the filter for search element
-	(You can find all filter with the define in Element.h)
-*/
-QList <Element *> ElementProvider::find(const int filter) const
+ * @brief ElementProvider::find
+ * Search and return the element with the type given in parameter
+ * @param elmt_type
+ * @return
+ */
+QVector<QPointer<Element>> ElementProvider::find(ElementData::Types elmt_type) const
 {
-	QList <Element *> elmt_;
-
-	//serch in all diagram
-	foreach (Diagram *d, m_diagram_list) {
-		//get all element in diagram d
-		QList <Element *> elmt_list;
-		elmt_list = d->elements();
-		foreach (Element *elmt, elmt_list) {
-			if (filter & elmt->linkType())
-				elmt_ << elmt;
+	QVector<QPointer<Element>> returned_vector;
+	for (const auto &diagram_ : qAsConst(m_diagram_list))
+	{
+		const auto elmt_list = diagram_->elements();
+		for (const auto &elmt_ : elmt_list)
+		{
+			if (elmt_type & elmt_->elementData().m_type) {
+				returned_vector << QPointer<Element>(elmt_);
+			}
 		}
 	}
-	return (elmt_);
+
+	return returned_vector;
 }
 
 /**
 	@brief ElementProvider::table
 	@param table
 	@param model
-	@return All tables wich display the derivated class of model (if set)
+	@return All tables which display the derivated class of model (if set)
 	and not already in all the chain of next/previous table of table (if set)
 	If table and model are nullptr, return every tables
 */
@@ -181,3 +188,31 @@ QetGraphicsTableItem *ElementProvider::tableFromUuid(const QUuid &uuid)
 
 	return nullptr;
 }
+
+/**
+ * @brief ElementProvider::freeTerminal
+ * @return a vector of every terminals element who doesn't
+ * belong to a terminal strip.
+ */
+QVector<TerminalElement *> ElementProvider::freeTerminal() const
+{
+	QVector<TerminalElement *> vector_;
+
+	for (const auto &diagram : qAsConst(m_diagram_list))
+	{
+		const auto elmt_list{diagram->elements()};
+
+		for (const auto element : elmt_list)
+		{
+			if (element->elementData().m_type == ElementData::Terminale)
+			{
+				const auto te{static_cast<TerminalElement *>(element)};
+				if (!te->parentTerminalStrip()) {
+					vector_.append(te);
+				}
+			}
+		}
+	}
+
+	return vector_;
+}
