@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2021 The QElectroTech Team
+	Copyright 2006-2023 The QElectroTech Team
 	This file is part of QElectroTech.
 
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -29,7 +29,7 @@ ElementFactory* ElementFactory::factory_ = nullptr;
 /**
 	@brief ElementFactory::createElement
 	@param location create element at this location
-	@param qgi parent item for this elemnt
+	@param qgi parent item for this element
 	@param state state of the creation
 	@return the element or 0
 */
@@ -46,10 +46,14 @@ Element * ElementFactory::createElement(const ElementsLocation &location, QGraph
 	if (doc.document_element().attribute("link_type"))
 	{
 		QString link_type(doc.document_element().attribute("link_type").as_string());
-		if (link_type == "next_report" || link_type == "previous_report") return (new ReportElement(location, link_type, qgi, state));
-		if (link_type == "master")   return (new MasterElement   (location, qgi, state));
-		if (link_type == "slave")    return (new SlaveElement    (location, qgi, state));
-		if (link_type == "terminal") return (new TerminalElement (location, qgi, state));
+		if (link_type == QLatin1String("next_report") || link_type == QLatin1String("previous_report"))
+			return (new ReportElement(location, link_type, qgi, state));
+		if (link_type == QLatin1String("master"))
+			return (new MasterElement   (location, qgi, state));
+		if (link_type == QLatin1String("slave"))
+			return (new SlaveElement    (location, qgi, state));
+		if (link_type == QLatin1String("terminal"))
+			return (new TerminalElement (location, qgi, state));
 	}
 	
 		//default if nothing match for link_type
