@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2021 The QElectroTech Team
+	Copyright 2006-2023 The QElectroTech Team
 	This file is part of QElectroTech.
 	
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -20,10 +20,14 @@
 #include "ElementsCollection/elementcollectionitem.h"
 #include "ElementsCollection/elementscollectionmodel.h"
 #include "NameList/ui/namelistwidget.h"
-#include "editor/qetelementeditor.h"
+#include "editor/ui/qetelementeditor.h"
 #include "qetmessagebox.h"
 #include "qfilenameedit.h"
 
+#include <QTreeView>
+#include <QVBoxLayout>
+#include <QLabel>
+
 /**
 	Constructeur
 	@param parent QWidget parent de ce dialogue
@@ -46,7 +50,6 @@ NewElementWizard::NewElementWizard(QWidget *parent, Qt::WindowFlags f) :
 	addPage(buildStep1());
 	addPage(buildStep2());
 	addPage(buildStep3());
-	setFixedSize(705, 325);
 }
 
 /**
@@ -236,7 +239,7 @@ bool NewElementWizard::validStep2()
 
 /**
 	@brief NewElementWizard::createNewElement
-	Lauch an element editor for create the new element
+	Launch an element editor to create the new element
 */
 void NewElementWizard::createNewElement()
 {
