@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2021 The QElectroTech Team
+	Copyright 2006-2023 The QElectroTech Team
 	This file is part of QElectroTech.
 
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -38,7 +38,7 @@
 
 /**
  * @brief ProjectPrintWindow::ProjectPrintWindow
- * Use this static function to properly lauch the print dialog.
+ * Use this static function to properly launch the print dialog.
  * @param project : project to print
  * @param format : native format to print in physical printer, or pdf format to export in pdf
  * @param parent : parent widget
@@ -46,6 +46,7 @@
 void ProjectPrintWindow::launchDialog(QETProject *project, QPrinter::OutputFormat format, QWidget *parent)
 {
 	auto printer_ = new QPrinter();
+	QPrinter printer(QPrinter::HighResolution);
 	printer_->setDocName(ProjectPrintWindow::docName(project));
 #if QT_VERSION < QT_VERSION_CHECK(5, 15, 1) // ### Qt 6: remove
 	printer_->setOrientation(QPrinter::Landscape);
@@ -95,13 +96,13 @@ void ProjectPrintWindow::launchDialog(QETProject *project, QPrinter::OutputForma
 QString ProjectPrintWindow::docName(QETProject *project)
 {
 	QString doc_name;
-	if (!project->title().isEmpty()) {
-		doc_name = project->title();
-	} else if (!project->filePath().isEmpty()) {
-		doc_name = QFileInfo(project->filePath()).baseName();
+    if (!project->filePath().isEmpty()) {
+        doc_name = QFileInfo(project->filePath()).baseName();
+    } else if (!project->title().isEmpty()) {
+        doc_name = project->title();
+        doc_name = QET::stringToFileName(doc_name);
 	}
 
-	doc_name = QET::stringToFileName(doc_name);
 	if (doc_name.isEmpty()) {
 		doc_name = tr("projet", "string used to generate a filename");
 	}
@@ -241,7 +242,7 @@ void ProjectPrintWindow::printDiagram(Diagram *diagram, bool fit_page, QPainter
 			qgi->setFlag(QGraphicsItem::ItemIsFocusable, false);
 		}
 	}
-		//Disable intercation
+		//Disable interaction
 	for (auto view : diagram->views()) {
 		view->setInteractive(false);
 	}
@@ -635,7 +636,7 @@ void ProjectPrintWindow::savePageSetupForCurrentPrinter()
 
 /**
  * @brief ProjectPrintWindow::saveReloadDiagramParameters
- * Save or restor the parameter of @diagram
+ * Save or restore the parameter of @diagram
  * @param diagram
  * @param options
  * @param save
@@ -666,7 +667,7 @@ QList<Diagram *> ProjectPrintWindow::selectedDiagram() const
 
 void ProjectPrintWindow::exportToPDF()
 {
-	auto file_name = QFileDialog::getSaveFileName(this, tr("Exporter sous : "), m_printer->outputFileName(), tr("Fichier (*.pdf"));
+    auto file_name = QFileDialog::getSaveFileName(this, tr("Exporter sous : "), m_printer->outputFileName(), tr("Fichier (*.pdf)"));
 	if (file_name.isEmpty()) {
 		return;
 	}
