@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2021 The QElectroTech Team
+	Copyright 2006-2023 The QElectroTech Team
 	This file is part of QElectroTech.
 
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -21,7 +21,7 @@
 #include "autoNum/assignvariables.h"
 #include "diagram.h"
 #include "diagramview.h"
-#include "editor/qetelementeditor.h"
+#include "editor/ui/qetelementeditor.h"
 #include "exportdialog.h"
 #include "qetapp.h"
 #include "qeticons.h"
@@ -339,8 +339,11 @@ QString ProjectView::askUserForFilePath(bool assign) {
 	// if no filepath is provided, return an empty string
 	if (filepath.isEmpty()) return(filepath);
 
-//	// if the name does not end with the .qet extension, append it
-//	if (!filepath.endsWith(".qet", Qt::CaseInsensitive)) filepath += ".qet";
+	// if the name does not end with the .qet extension and we're _not_ using xdg-desktop-portal, append it
+	bool usesPortal = 
+		qEnvironmentVariableIsSet("FLATPAK_ID") || 
+		qEnvironmentVariableIsSet("SNAP_NAME");
+	if (!filepath.endsWith(".qet", Qt::CaseInsensitive) && !usesPortal) filepath += ".qet";
 
 	if (assign) {
 		// assign the provided filepath to the currently edited project
@@ -758,13 +761,13 @@ void ProjectView::initWidgets()
 	connect(m_tab, SIGNAL(tabBarDoubleClicked(int)), this, SLOT(tabDoubleClicked(int)));
 	connect(m_tab->tabBar(), SIGNAL(tabMoved(int, int)), this, SLOT(tabMoved(int, int)), Qt::QueuedConnection);
 	
-	//arrows buttton to return on first view
+	//arrows button to return on first view
 	QToolButton *m_first_view_button =new QToolButton;
 	m_first_view_button->setDefaultAction(m_first_view);
 	m_first_view_button->setAutoRaise(true);
 	m_tab->setCornerWidget(m_first_view_button, Qt::TopLeftCorner);
 	
-	//arrows buttton to go on last view
+	//arrows button to go on last view
 	QToolButton *m_end_view_button =new QToolButton;
 	m_end_view_button->setDefaultAction(m_end_view);
 	m_end_view_button->setAutoRaise(true);
@@ -810,30 +813,39 @@ void ProjectView::loadDiagrams()
 
 	setDisplayFallbackWidget(m_project -> diagrams().isEmpty());
 
-	DialogWaiting *dialog = nullptr;
-	if(DialogWaiting::hasInstance())
+	auto dialog = DialogWaiting::instance();
+	if(dialog)
 	{
-		dialog = DialogWaiting::instance();
 		dialog->setTitle( tr("<p align=\"center\">"
 												"<b>Ouverture du projet en cours...</b><br/>"
 												"Création des onglets de folio :"
 												"</p>"));
 	}
-	for(Diagram *diagram : m_project->diagrams())
+
+	for(auto diagram : m_project->diagrams())
 	{
 		if(dialog)
 		{
 			dialog->setDetail(diagram->title());
 			dialog->setProgressBar(dialog->progressBarValue()+1);
 		}
-		diagramAdded(diagram);
+
+		auto dv = new DiagramView(diagram);
+		dv->setFrameStyle(QFrame::Plain | QFrame::NoFrame);
+
+		auto index = m_project->folioIndex(diagram);
+		m_tab->insertTab(index, dv, QET::Icons::Diagram, dv->title());
+		m_diagram_view_list.insert(index, dv);
+
+		connect(dv, &DiagramView::showDiagram,         this, QOverload<Diagram*>::of(&ProjectView::showDiagram));
+		connect(dv, &DiagramView::titleChanged,        this, &ProjectView::updateTabTitle);
+		connect(dv, &DiagramView::findElementRequired, this, &ProjectView::findElementRequired);
+		connect(&dv->diagram()->border_and_titleblock , &BorderTitleBlock::titleBlockFolioChanged, [this, dv]() {this->updateTabTitle(dv);});
 	}
 
-	if (DiagramView *dv = currentDiagram())
-	{
-		dv->diagram()->loadElmtFolioSeq();
-		dv->diagram()->loadCndFolioSeq();
-	}
+	rebuildDiagramsMap();
+	updateAllTabsTitle();
+
 	m_tab->setCurrentWidget(firstDiagram());
 }
 
