@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2021 The QElectroTech Team
+	Copyright 2006-2023 The QElectroTech Team
 	This file is part of QElectroTech.
 
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -21,6 +21,7 @@
 #include "qetresult.h"
 #include "titleblock/templatelocation.h"
 
+#include <QCloseEvent>
 #include <QTabBar>
 #include <QWidget>
 #include <QtWidgets>
@@ -86,10 +87,14 @@ class ProjectView : public QWidget
 	private:
 		ProjectView(const ProjectView &);
 
+			//Method related to construction of this class
+		void setProject(QETProject *project);
+
+
+
 		// methods
 	public:
 		QETProject *project();
-		void setProject(QETProject *);
 		QList<DiagramView *> diagram_views() const;
 		DiagramView *currentDiagram() const;
 		void closeEvent(QCloseEvent *) override;
