@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2021 The QElectroTech Team
+	Copyright 2006-2023 The QElectroTech Team
 	This file is part of QElectroTech.
 
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -163,7 +163,7 @@ bool XRefProperties::fromXml(const QDomElement &xml_element) {
 /**
 	@brief XRefProperties::defaultProperties
 	@return the default properties stored in the setting file
-	For the xref, there is 2 propreties.
+	For the xref, there are 2 properties.
 	For coil, stored with the string "coil" in the returned QHash.
 	For protection, stored with the string "protection" in the returned QHash.
 */
@@ -187,13 +187,14 @@ QHash<QString, XRefProperties> XRefProperties::defaultProperties()
 }
 
 bool XRefProperties::operator ==(const XRefProperties &xrp) const{
-	return (m_show_power_ctc == xrp.m_show_power_ctc &&
-			m_display == xrp.m_display &&
-			m_snap_to == xrp.m_snap_to &&
-			m_prefix == xrp.m_prefix &&
-			m_master_label == xrp.m_master_label &&
-			 m_offset == xrp.m_offset &&
-			m_xref_pos == xrp.m_xref_pos );
+	return (m_show_power_ctc == xrp.m_show_power_ctc
+			&& m_display     == xrp.m_display
+			&& m_snap_to     == xrp.m_snap_to
+			&& m_prefix      == xrp.m_prefix
+			&& m_master_label== xrp.m_master_label
+			&& m_offset      == xrp.m_offset
+			&& m_xref_pos    == xrp.m_xref_pos
+			&& m_slave_label == xrp.m_slave_label);
 }
 
 bool XRefProperties::operator !=(const XRefProperties &xrp) const
