@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2021 The QElectroTech Team
+	Copyright 2006-2023 The QElectroTech Team
 	This file is part of QElectroTech.
 
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -42,6 +42,7 @@
 #include "undocommand/rotateselectioncommand.h"
 #include "undocommand/rotatetextscommand.h"
 #include "diagram.h"
+#include "ui/diagrameditorhandlersizewidget.h"
 
 #ifdef BUILD_WITHOUT_KF5
 #else
@@ -64,6 +65,9 @@ QETDiagramEditor::QETDiagramEditor(const QStringList &files, QWidget *parent) :
 	m_file_actions_group       (this),
 	open_dialog_dir            (QStandardPaths::writableLocation(QStandardPaths::DesktopLocation))
 {
+		//Trivial property use to set the graphics handler size
+	setProperty("graphics_handler_size", 10);
+
 	activeSubWindowIndex = 0;
 
 	QSplitter *splitter_ = new QSplitter(this);
@@ -422,7 +426,7 @@ void QETDiagramEditor::setUpActions()
 
 		//Add a nomenclature item
 	m_add_nomenclature = new QAction(QET::Icons::TableOfContent, tr("Ajouter une nomenclature"), this);
-	connect(m_add_nomenclature, &QAction::triggered, [this]() {
+	connect(m_add_nomenclature, &QAction::triggered, this, [=]() {
 		if(this->currentDiagramView()) {
 			QetGraphicsTableFactory::createAndAddNomenclature(this->currentDiagramView()->diagram());
 		}
@@ -430,13 +434,13 @@ void QETDiagramEditor::setUpActions()
 
 		//Add a summary item
 	m_add_summary = new QAction(QET::Icons::TableOfContent, tr("Ajouter un sommaire"), this);
-	connect(m_add_summary, &QAction::triggered, [this]() {
+	connect(m_add_summary, &QAction::triggered, this, [=]() {
 		if(this->currentDiagramView()) {
 			QetGraphicsTableFactory::createAndAddSummary(this->currentDiagramView()->diagram());
 		}
 	});
 
-		//Lauch the plugin of terminal generator
+		//Launch the plugin of terminal generator
 	m_project_terminalBloc = new QAction(QET::Icons::TerminalStrip, tr("Lancer le plugin de création de borniers"), this);
 	connect(m_project_terminalBloc, &QAction::triggered, this, &QETDiagramEditor::generateTerminalBlock);
 
@@ -721,6 +725,8 @@ void QETDiagramEditor::setUpToolBar()
 	view_tool_bar -> addAction(m_mode_selection);
 	view_tool_bar -> addAction(m_mode_visualise);
 	view_tool_bar -> addSeparator();
+	view_tool_bar -> addWidget(new DiagramEditorHandlerSizeWidget(this));
+	view_tool_bar -> addSeparator();
 	view_tool_bar -> addAction(m_draw_grid);
 	view_tool_bar -> addAction (m_grey_background);
 	view_tool_bar -> addSeparator();
@@ -1372,7 +1378,7 @@ void QETDiagramEditor::selectGroupTriggered(QAction *action)
 
 /**
 	@brief QETDiagramEditor::addItemGroupTriggered
-	This slot is called when an item must be added to the curent diagram,
+	This slot is called when an item must be added to the current diagram,
 	this slot use the DVEventInterface to add item
 	@param action : Action that describe the item to add.
 */
@@ -1502,16 +1508,7 @@ void QETDiagramEditor::slot_updateActions()
 	m_close_file->                  setEnabled(opened_project);
 	m_save_file->                   setEnabled(opened_project);
 	m_save_file_as->                setEnabled(opened_project);
-	m_project_edit_properties->     setEnabled(opened_project);
-	m_project_export_conductor_num->setEnabled(opened_project);
-	//prj_terminalBloc -> setEnabled(opened_project);
 	m_rotate_texts->                setEnabled(editable_project);
-	m_project_add_diagram->         setEnabled(editable_project);
-	m_remove_diagram_from_project-> setEnabled(editable_project);
-	m_clean_project->               setEnabled(editable_project);
-	m_add_nomenclature->            setEnabled(editable_project);
-	m_add_summary->                 setEnabled(editable_project);
-	m_csv_export->                  setEnabled(editable_project);
 	m_export_to_images->            setEnabled(opened_diagram);
 	m_print->                       setEnabled(opened_diagram);
 	m_export_to_pdf->               setEnabled(opened_diagram);
@@ -1522,6 +1519,15 @@ void QETDiagramEditor::slot_updateActions()
 	m_row_column_actions_group.     setEnabled(editable_project);
 	m_grey_background->             setEnabled(opened_diagram);
 
+		//Project menu
+	m_project_edit_properties     -> setEnabled(opened_project);
+	m_project_add_diagram         -> setEnabled(editable_project);
+	m_remove_diagram_from_project -> setEnabled(editable_project);
+	m_clean_project               -> setEnabled(editable_project);
+	m_add_summary                 -> setEnabled(editable_project);
+	m_add_nomenclature            -> setEnabled(editable_project);
+	m_csv_export                  -> setEnabled(editable_project);
+	m_project_export_conductor_num-> setEnabled(opened_project);
 
 	slot_updateUndoStack();
 	slot_updateModeActions();
@@ -1789,7 +1795,7 @@ void QETDiagramEditor::addProjectView(ProjectView *project_view)
 	sub_window -> setWindowIcon(project_view -> windowIcon());
 	sub_window -> systemMenu() -> clear();
 
-	//By defaut QMdiSubWindow have a QAction "close" with shortcut QKeySequence::Close
+	//By default QMdiSubWindow have a QAction "close" with shortcut QKeySequence::Close
 	//But the QAction m_close_file of this class have the same shortcut too.
 	//We remove the shortcut of the QAction of QMdiSubWindow for avoid conflic
 	for(QAction *act : sub_window->actions())
@@ -2042,7 +2048,7 @@ void QETDiagramEditor::projectWasClosed(ProjectView *project_view)
 		undo_group.removeStack(project -> undoStack());
 		QETApp::unregisterProject(project);
 	}
-	//When project is closed, a lot of signal are emited, notably if there is an item selected in a diagram.
+	//When project is closed, a lot of signal are emitted, notably if there is an item selected in a diagram.
 	//In some special case, since signal/slot connection can be direct or queued, some signal are handled after QObject is deleted, and crash qet
 	//notably in the function Diagram::elements when she call items() (I don't know exactly why).
 	//set nullptr to "m_selection_properties_editor->setDiagram()" fix this crash
@@ -2341,10 +2347,10 @@ void QETDiagramEditor::generateTerminalBlock()
 
 #elif  defined(Q_OS_MAC)
 	if (openedProjects().count()){
-		success = process->startDetached("/Library/Frameworks/Python.framework/Versions/3.8/bin/qet_tb_generator", {(QETDiagramEditor::currentProjectView()->project()->filePath())});
+		success = process->startDetached("/Library/Frameworks/Python.framework/Versions/3.9/bin/qet_tb_generator", {(QETDiagramEditor::currentProjectView()->project()->filePath())});
 	}
 	else  {
-		success = process->startDetached("/Library/Frameworks/Python.framework/Versions/3.8/bin/qet_tb_generator", {("")});
+		success = process->startDetached("/Library/Frameworks/Python.framework/Versions/3.9/bin/qet_tb_generator", {("")});
 	}
 		if (openedProjects().count()){
 		success = process->startDetached(QDir::homePath() + "/.qet/qet_tb_generator.app", {(QETDiagramEditor::currentProjectView()->project()->filePath())});
@@ -2395,7 +2401,9 @@ void QETDiagramEditor::generateTerminalBlock()
 		"<br>"
 		"<a href='https://pypi.python.org/pypi/qet-tb-generator'>qet-tb-generator</a>"
 		"<br><B><U> First install on macOSX</B></U>"
-		"<br>1. Install, if required, python 3.8 bundle only, "
+		"<br>1. Install, if required, python 3.9 bundle only, "
+		"<br>2 Run Profile.command script"
+		"<br>"
 		"because program use hardcoded PATH for localise qet-tb-generator plugin "
 		"<br> Visit :"
 		"<br>"
