@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2021 The QElectroTech Team
+	Copyright 2006-2023 The QElectroTech Team
 	This file is part of QElectroTech.
 	
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -22,6 +22,7 @@
 #include "qetmainwindow.h"
 
 #include <QActionGroup>
+#include <QCloseEvent>
 #include <QDir>
 #include <QMdiArea>
 #include <QSignalMapper>
@@ -186,7 +187,7 @@ class QETDiagramEditor : public QETMainWindow
 		*m_project_edit_properties,	///< Edit the properties of the current project.
 		*m_project_add_diagram,		///< Add a diagram to the current project.
 		*m_remove_diagram_from_project,	///< Delete a diagram from the current project
-		*m_clean_project,		///< Clean the content of the curent project by removing useless items
+		*m_clean_project,		///< Clean the content of the current project by removing useless items
 		*m_project_folio_list,		///< Sommaire des schemas
 		*m_csv_export,			///< generate nomenclature
 		*m_add_nomenclature,		///< Add nomenclature graphics item;
