@@ -1,5 +1,5 @@
 ﻿/*
-	Copyright 2006-2021 The QElectroTech Team
+	Copyright 2006-2023 The QElectroTech Team
 	This file is part of QElectroTech.
 
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -65,7 +65,7 @@ void QetGraphicsTableItem::adjustTableToFolio(
 
 		//Calcul the maximum row to display to fit the nomenclature into diagram
 	auto available_height = drawable_rect.height() - table->pos().y();
-	auto min_row_height = table->minimumRowHeigth();
+	auto min_row_height = table->minimumRowHeight();
 	table->setDisplayNRow(int(floor(available_height/min_row_height))); //Convert a double to int, but max_row_to_display is already rounded an integer so we assume everything is ok
 }
 
@@ -156,7 +156,17 @@ QetGraphicsTableItem::QetGraphicsTableItem(QGraphicsItem *parent) :
 }
 
 QetGraphicsTableItem::~QetGraphicsTableItem()
-{}
+{
+	if (m_previous_table) {
+		if (m_next_table) {
+			m_previous_table->setNextTable(m_next_table);
+		} else {
+			m_previous_table->setNextTable(nullptr);
+		}
+	} else if (m_next_table) {
+		m_next_table->setPreviousTable(nullptr);
+	}
+}
 
 /**
 	@brief QetGraphicsTableItem::setModel
@@ -175,7 +185,7 @@ void QetGraphicsTableItem::setModel(QAbstractItemModel *model)
 			   this, &QetGraphicsTableItem::modelReseted);
 	}
 	m_model = model;
-	m_header_item->setModel(model);
+	m_header_item->setModel(m_model);
 
 	setUpColumnAndRowMinimumSize();
 	adjustSize();
@@ -200,7 +210,7 @@ void QetGraphicsTableItem::setModel(QAbstractItemModel *model)
 */
 QAbstractItemModel *QetGraphicsTableItem::model() const
 {
-	return m_model;
+	return m_model.data();
 }
 
 /**
@@ -270,8 +280,8 @@ void QetGraphicsTableItem::paint(
 	if (m_previous_table) //Remove the number of row already displayed by previous tables
 		row_count -= m_previous_table->displayNRowOffset();
 
-	if (m_number_of_displayed_row > 0) //User override the number of row to display
-		row_count = std::min(row_count, m_number_of_displayed_row);
+	if (m_number_of_row_to_display > 0) //User override the number of row to display
+		row_count = std::min(row_count, m_number_of_row_to_display);
 
 		//Draw horizontal lines
 	auto cell_height =  static_cast<double>(m_current_size.height())/static_cast<double>(row_count);
@@ -364,8 +374,8 @@ QSize QetGraphicsTableItem::minimumSize() const
 		row_count -= m_previous_table->displayNRowOffset();
 	}
 
-	if (m_number_of_displayed_row > 0)
-		row_count = std::min(row_count, m_number_of_displayed_row);
+	if (m_number_of_row_to_display > 0)
+		row_count = std::min(row_count, m_number_of_row_to_display);
 
 
 		//m_minimum_column_width already take in count the minimum size of header
@@ -389,7 +399,7 @@ QSize QetGraphicsTableItem::minimumSize() const
 */
 void QetGraphicsTableItem::setDisplayNRow(const int &number)
 {
-	m_number_of_displayed_row = number;
+	m_number_of_row_to_display = number;
 	setToMinimumHeight();
 	if (m_next_table)
 		m_next_table->previousTableDisplayRowChanged();
@@ -402,7 +412,7 @@ void QetGraphicsTableItem::setDisplayNRow(const int &number)
 */
 int QetGraphicsTableItem::displayNRow() const
 {
-	return m_number_of_displayed_row;
+	return m_number_of_row_to_display;
 }
 
 /**
@@ -489,19 +499,41 @@ QString QetGraphicsTableItem::tableName() const
 */
 int QetGraphicsTableItem::displayNRowOffset() const
 {
-	auto offset_ = m_number_of_displayed_row;
+	auto offset_ = m_number_of_row_to_display;
 	if(m_previous_table)
 		offset_ += m_previous_table->displayNRowOffset();
 
 	return offset_;
 }
 
-QetGraphicsTableItem *QetGraphicsTableItem::previousTable() const
+/**
+ * @brief QetGraphicsTableItem::displayedRowCount
+ * @return the number of row displayed by this table
+ */
+int QetGraphicsTableItem::displayedRowCount() const
+{
+	if (!m_model) {
+		return 0;
+	}
+
+		//Calcule the number of rows to display.
+	auto row_count = m_model->rowCount();
+
+	if (m_previous_table) //Remove the number of row already displayed by previous tables
+		row_count -= m_previous_table->displayNRowOffset();
+
+	if (m_number_of_row_to_display > 0) //User override the number of row to display
+		row_count = std::min(row_count, m_number_of_row_to_display);
+
+	return row_count;
+}
+
+QPointer<QetGraphicsTableItem> QetGraphicsTableItem::previousTable() const
 {
 	return m_previous_table;
 }
 
-QetGraphicsTableItem *QetGraphicsTableItem::nextTable() const
+QPointer<QetGraphicsTableItem> QetGraphicsTableItem::nextTable() const
 {
 	return m_next_table;
 }
@@ -532,10 +564,10 @@ void QetGraphicsTableItem::initLink()
 }
 
 /**
-	@brief QetGraphicsTableItem::minimumRowHeigth
+	@brief QetGraphicsTableItem::minimumRowHeight
 	@return the minimum height of a row
 */
-int QetGraphicsTableItem::minimumRowHeigth() const
+int QetGraphicsTableItem::minimumRowHeight() const
 {
 	return m_minimum_row_height;
 }
@@ -555,7 +587,7 @@ QDomElement QetGraphicsTableItem::toXml(QDomDocument &dom_document) const
 	dom_table.setAttribute("height", QString::number(m_current_size.height()));
 	dom_table.setAttribute("uuid", m_uuid.toString());
 	dom_table.setAttribute("name", m_name);
-	dom_table.setAttribute("display_n_row", QString::number(m_number_of_displayed_row));
+	dom_table.setAttribute("display_n_row", QString::number(m_number_of_row_to_display));
 
 		//Add the header xml
 	dom_table.appendChild(m_header_item->toXml(dom_document));
@@ -571,7 +603,7 @@ QDomElement QetGraphicsTableItem::toXml(QDomDocument &dom_document) const
 	{
 			//Add model
 		auto dom_model = dom_document.createElement("model");
-		auto project_db_model = static_cast<ProjectDBModel *>(m_model);
+		auto project_db_model = static_cast<ProjectDBModel *>(m_model.data());
 		dom_model.appendChild(project_db_model->toXml(dom_document));
 		dom_table.appendChild(dom_model);
 
@@ -613,7 +645,7 @@ void QetGraphicsTableItem::fromXml(const QDomElement &dom_element)
 					"uuid",
 					QUuid::createUuid().toString()));
 	m_name = dom_element.attribute("name");
-	m_number_of_displayed_row = dom_element.attribute(
+	m_number_of_row_to_display = dom_element.attribute(
 				"display_n_row",
 				QString::number(0)).toInt();
 
@@ -678,8 +710,8 @@ bool QetGraphicsTableItem::toDXF(const QString &filepath)
 	if (m_previous_table) //Remove the number of row already displayed by previous tables
 		row_count -= m_previous_table->displayNRowOffset();
 
-	if (m_number_of_displayed_row > 0) //User override the number of row to display
-		row_count = std::min(row_count, m_number_of_displayed_row);
+	if (m_number_of_row_to_display > 0) //User override the number of row to display
+		row_count = std::min(row_count, m_number_of_row_to_display);
 
 		//Draw horizontal lines
 	auto cell_height =  static_cast<double>(m_current_size.height())/static_cast<double>(row_count);
@@ -738,6 +770,7 @@ void QetGraphicsTableItem::hoverEnterEvent(QGraphicsSceneHoverEvent *event)
 	{
 		adjustHandlerPos();
 		this->scene()->addItem(&m_handler_item);
+		m_handler_item.setSize(QETUtils::graphicsHandlerSize(this));
 		m_handler_item.installSceneEventFilter(this);
 	}
 	QGraphicsObject::hoverEnterEvent(event);
@@ -750,7 +783,9 @@ void QetGraphicsTableItem::hoverEnterEvent(QGraphicsSceneHoverEvent *event)
 */
 void QetGraphicsTableItem::hoverLeaveEvent(QGraphicsSceneHoverEvent *event)
 {
-	if (m_model) {
+	if (m_model &&
+		!m_handler_item.contains(mapToItem(&m_handler_item, event->pos())))
+	{
 		m_handler_item.scene()->removeItem(&m_handler_item);
 	}
 	QGraphicsObject::hoverLeaveEvent(event);
@@ -806,13 +841,18 @@ QVariant QetGraphicsTableItem::itemChange(
 	return QetGraphicsItem::itemChange(change, value);
 }
 
+/**
+ * @brief QetGraphicsTableItem::modelReseted
+ */
 void QetGraphicsTableItem::modelReseted()
 {
 	dataChanged(m_model->index(0,0), m_model->index(0,0), QVector<int>());
 	setToMinimumHeight();
 
-	if (!previousTable()) { //this is the head table
+	if (!previousTable()) //this is the head table
+	{
 		checkInsufficientRowsCount(this);
+		removeUselessNextTable();
 	}
 }
 
@@ -1046,3 +1086,24 @@ void QetGraphicsTableItem::previousTableDisplayRowChanged()
 		m_next_table->previousTableDisplayRowChanged();
 	}
 }
+
+/**
+ * @brief QetGraphicsTableItem::removeUselessNextTable
+ * Remove next table if useless, an useless table with 0 row displayed.
+ * If \p recursive is true check and remove for all sub next table.
+ * @param recursive
+ */
+void QetGraphicsTableItem::removeUselessNextTable(bool recursive)
+{
+	if (m_next_table)
+	{
+		if (recursive) {
+			m_next_table->removeUselessNextTable();
+		}
+		if (m_next_table->displayedRowCount() <= 0)
+		{
+			m_next_table.data()->deleteLater();
+			m_next_table.clear();
+		}
+	}
+}
