@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2021 The QElectroTech Team
+	Copyright 2006-2023 The QElectroTech Team
 	This file is part of QElectroTech.
 
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -91,11 +91,11 @@ void GraphicsTablePropertiesEditor::setTable(QetGraphicsTableItem *table)
 	m_connect_list << connect(m_table_item.data(),
 				  &QetGraphicsTableItem::xChanged,
 				  this,
-				  &GraphicsTablePropertiesEditor::updateUi);
+				  &GraphicsTablePropertiesEditor::updatePosWidget);
 	m_connect_list << connect(m_table_item.data(),
 				  &QetGraphicsTableItem::yChanged,
 				  this,
-				  &GraphicsTablePropertiesEditor::updateUi);
+				  &GraphicsTablePropertiesEditor::updatePosWidget);
 
 
 	if (auto editor = PropertiesEditorFactory::propertiesEditor(table->model(), this))
@@ -390,6 +390,12 @@ void GraphicsTablePropertiesEditor::updateUi()
 	setUpEditConnection();
 }
 
+void GraphicsTablePropertiesEditor::updatePosWidget()
+{
+	ui->m_x_pos->setValue(m_table_item->pos().x());
+	ui->m_y_pos->setValue(m_table_item->pos().y());
+}
+
 void GraphicsTablePropertiesEditor::updateInfoLabel()
 {
 	auto table_ = m_table_item;
