@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2021 The QElectroTech Team
+	Copyright 2006-2023 The QElectroTech Team
 	This file is part of QElectroTech.
 
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -30,6 +30,7 @@
 #include "conductortextitem.h"
 #include "element.h"
 #include "../QetGraphicsItemModeler/qetgraphicshandleritem.h"
+#include "../utils/qetutils.h"
 
 #include <QMultiHash>
 #include <QtDebug>
@@ -91,13 +92,13 @@ Conductor::Conductor(Terminal *p1, Terminal* p2) :
 	setZValue(11);
 	m_previous_z_value = zValue();
 
-		//Add this conductor to the list of conductor of each of the two terminal
+		//Add this conductor to the list of conductors of each of the two terminals
 	bool ajout_p1 = terminal1 -> addConductor(this);
 	bool ajout_p2 = terminal2 -> addConductor(this);
 		//m_valid become false if the conductor can't be added to terminal (conductor already exist)
 	m_valid = (!ajout_p1 || !ajout_p2) ? false : true;
 
-		//Default attribut for paint a conductor
+		//Default attribute to paint a conductor
 	if (!pen_and_brush_initialized)
 	{
 		conductor_pen.setJoinStyle(Qt::MiterJoin);
@@ -110,7 +111,7 @@ Conductor::Conductor(Terminal *p1, Terminal* p2) :
 		pen_and_brush_initialized = true;
 	}
 
-		//By default, the 4 profils are nuls -> we must to use priv_calculeConductor
+		//By default, the 4 profiles are nuls -> we must use priv_calculeConductor
 	conductor_profiles.insert(Qt::TopLeftCorner,     ConductorProfile());
 	conductor_profiles.insert(Qt::TopRightCorner,    ConductorProfile());
 	conductor_profiles.insert(Qt::BottomLeftCorner,  ConductorProfile());
@@ -134,7 +135,7 @@ Conductor::Conductor(Terminal *p1, Terminal* p2) :
 
 /**
 	@brief Conductor::~Conductor
-	Destructor. The conductor is removed from is terminal
+	Destructor. The conductor is removed from its terminal
 */
 Conductor::~Conductor()
 {
@@ -846,7 +847,7 @@ void Conductor::handlerMouseReleaseEvent(QetGraphicsHandlerItem *qghi, QGraphics
 		saveProfile();
 		has_to_save_profile = false;
 	}
-		//When handler is released, the conductor can have more segment than befor the handler was moved
+		//When handler is released, the conductor can have more segment than before the handler was moved
 		//then we remove all handles and new ones are added
 	removeHandler();
 	addHandler();
@@ -860,7 +861,7 @@ void Conductor::addHandler()
 {
 	if (m_handler_vector.isEmpty() && scene())
 	{
-		m_handler_vector = QetGraphicsHandlerItem::handlerForPoint(mapToScene(handlerPoints()));
+		m_handler_vector = QetGraphicsHandlerItem::handlerForPoint(mapToScene(handlerPoints()), QETUtils::graphicsHandlerSize(this));
 
 		for(QetGraphicsHandlerItem *handler : m_handler_vector)
 		{
@@ -1035,7 +1036,7 @@ QDomElement Conductor::toXml(QDomDocument &dom_document,
 	// Terminal is uniquely identified by the uuid of the terminal and the element
 	if (terminal1->uuid().isNull()) {
 		// legacy method to identify the terminal
-		dom_element.setAttribute("terminal1", table_adr_id.value(terminal1)); // for backward compability
+		dom_element.setAttribute("terminal1", table_adr_id.value(terminal1)); // for backward compatibility
 	} else {
 		dom_element.setAttribute("element1", terminal1->parentElement()->uuid().toString());
 		dom_element.setAttribute("terminal1", terminal1->uuid().toString());
@@ -1043,7 +1044,7 @@ QDomElement Conductor::toXml(QDomDocument &dom_document,
 
 	if (terminal2->uuid().isNull()) {
 		// legacy method to identify the terminal
-		dom_element.setAttribute("terminal2", table_adr_id.value(terminal2)); // for backward compability
+		dom_element.setAttribute("terminal2", table_adr_id.value(terminal2)); // for backward compatibility
 	} else {
 		dom_element.setAttribute("element2", terminal2->parentElement()->uuid().toString());
 		dom_element.setAttribute("terminal2", terminal2->uuid().toString());
@@ -1241,7 +1242,7 @@ QPointF Conductor::posForText(Qt::Orientations &flag)
 	bool all_segment_is_vertical   = true;
 	bool all_segment_is_horizontal = true;
 
-		//Go to first segement
+		//Go to first segment
 	while (!segment->isFirstSegment()) {
 		segment = segment->previousSegment();
 	}
@@ -1264,7 +1265,7 @@ QPointF Conductor::posForText(Qt::Orientations &flag)
 		if (segment -> firstPoint().y() != segment -> secondPoint().y())
 			all_segment_is_horizontal = false;
 
-			//We must to compare length segment, but they can be negative
+			//We must compare length segment, but they can be negative
 			//so we multiply by -1 to make it positive.
 		int saved = biggest_segment -> length();
 		if (saved < 0) saved *= -1;
@@ -1516,7 +1517,7 @@ QPainterPath Conductor::path() const
 	@brief Conductor::setPropertiesToPotential
 	@param property
 	@param only_text
-	Set propertie to conductor and every conductors in
+	Set property to conductor and every conductors in
 	the same potential of conductor.
 	If only_text is true only formula, text,
 	function and tension/protocol is set
@@ -1759,7 +1760,7 @@ void Conductor::setUpConnectionForFormula(QString old_formula, QString new_formu
 	if (diagram())
 	{
 			//Because the variable %F is a reference to another text which can contain variables,
-			//we must to replace %F by the real text, to check if the real text contain the variable %id
+			//we must replace %F by the real text, to check if the real text contains the variable %id
 		if (old_formula.contains("%F"))
 			old_formula.replace("%F", diagram()->border_and_titleblock.folio());
 
@@ -1974,53 +1975,70 @@ void Conductor::deleteSegments()
 }
 
 /**
-	@param point Un point situe a l'exterieur du polygone
-	@param polygon Le polygone dans lequel on veut rapatrier le point
-	@return la position du point, une fois ramene dans le polygone, ou plus
-	exactement sur le bord du polygone
-*/
-QPointF Conductor::movePointIntoPolygon(const QPointF &point, const QPainterPath &polygon) {
-	// decompose le polygone en lignes et points
-	QList<QPolygonF> polygons = polygon.simplified().toSubpathPolygons();
+ * @brief Conductor::movePointIntoPolygon
+ * @param point : A point located outside the polygon
+ * @param polygon : The polygon in which we want to move the point
+ * @return the position of the point, once brought back into the polygon,
+ * or more exactly on the edge of the polygon
+ */
+QPointF Conductor::movePointIntoPolygon(const QPointF &point, const QPainterPath &polygon)
+{
+		// decomposes the polygon into lines and points
+	const QList<QPolygonF> polygons = polygon.simplified().toSubpathPolygons();
 	QList<QLineF> lines;
 	QList<QPointF> points;
-	foreach(QPolygonF polygon, polygons) {
-		if (polygon.count() <= 1) continue;
 
-		// on recense les lignes et les points
+	for (QPolygonF polygon : polygons)
+	{
+		if (polygon.count() <= 1)
+			continue;
+
+			// lines and points are counted
 		for (int i = 1 ; i < polygon.count() ; ++ i) {
 			lines << QLineF(polygon.at(i - 1), polygon.at(i));
 			points << polygon.at(i -1);
 		}
 	}
 
-	// on fait des projetes orthogonaux du point sur les differents segments du
-	// polygone, en les triant par longueur croissante
+		// we make orthogonal projections of the point on the different
+		// segments of the polygon, sorting them by increasing length
 	QMap<qreal, QPointF> intersections;
-	foreach (QLineF line, lines) {
+	for (QLineF line : lines)
+	{
 		QPointF intersection_point;
 		if (QET::orthogonalProjection(point, line, &intersection_point)) {
 			intersections.insert(QLineF(intersection_point, point).length(), intersection_point);
 		}
 	}
-	if (intersections.count()) {
-		// on determine la plus courte longueur pour un projete orthogonal
+
+	if (intersections.count())
+	{
+			// the shortest length for an orthogonal project is determined
 		QPointF the_point = intersections[intersections.keys().first()];
 		return(the_point);
-	} else {
-			// determine le coin du polygone le plus proche du point exterieur
-			qreal minimum_length = -1;
-			int point_index = -1;
-			for (int i = 0 ; i < points.count() ; ++ i) {
-				qreal length = qAbs(QLineF(points.at(i), point).length());
-				if (minimum_length < 0 || length < minimum_length) {
-					minimum_length = length;
-					point_index    = i;
-				}
+	}
+	else
+	{
+			// determines the corner of the polygon closest to the outer point
+		qreal minimum_length = -1;
+		int point_index = -1;
+		for (int i = 0 ; i < points.count() ; ++ i)
+		{
+			qreal length = qAbs(QLineF(points.at(i), point).length());
+			if (minimum_length < 0 || length < minimum_length) {
+				minimum_length = length;
+				point_index    = i;
 			}
-			// on connait desormais le coin le plus proche du texte
+		}
+			// we now know the closest corner of the text
 
-		// aucun projete orthogonal n'a donne quoi que ce soit, on met le texte sur un des coins du polygone
+
+		if (point_index == -1 ||
+			point_index+1 > points.size()) {
+			return QPointF(0,0);
+		}
+
+			// no orthogonal projection gave anything, we put the text on one of the corners of the polygon
 		return(points.at(point_index));
 	}
 }
@@ -2045,8 +2063,8 @@ Conductor * longuestConductorInPotential(Conductor *conductor, bool all_diagram)
 	@brief relatedConductors
 	@param conductor
 	@return return all conductors who share the same terminals
-	of conductor given as parametre,
-	except conductor himself.
+	of conductor given as parameter,
+	except conductor itself.
 */
 QList <Conductor *> relatedConductors(const Conductor *conductor) {
 	QList<Conductor *> other_conductors_list = conductor -> terminal1 -> conductors();
