@@ -1,5 +1,5 @@
 ﻿/*
-	Copyright 2006-2021 The QElectroTech Team
+	Copyright 2006-2023 The QElectroTech Team
 	This file is part of QElectroTech.
 	
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -270,6 +270,8 @@ Element *DynamicElementTextItem::elementUseForInfo() const
 	{
 		case Element::Simple:
 			return elmt;
+		case Element::Thumbnail:
+			return elmt;
 		case Element::NextReport:
 			return elmt;
 		case Element::PreviousReport:
@@ -473,9 +475,9 @@ void DynamicElementTextItem::setCompositeText(const QString &text)
 	if (m_parent_element && (m_parent_element.data()->linkType() & Element::AllReport)) //special treatment for report
 	{
 			/*
-			 * May be in some case the old and new composite text have both the var %{label},
-			 * and so we don't have to remove connection and after set conection,
-			 * but for that we must to do several check and because I'm lazy,
+			 * May be in some case the old and new composite text both have the var %{label},
+			 * and so we don't have to remove connection and after set connection,
+			 * but for that we must do several checks and because I'm lazy,
 			 * in every case I remove connection and set it after ;)
 			 */
 		if(old_composite_text.contains("%{label}"))
@@ -689,7 +691,7 @@ void DynamicElementTextItem::paint(QPainter *painter, const QStyleOptionGraphics
 
 QVariant DynamicElementTextItem::itemChange(QGraphicsItem::GraphicsItemChange change, const QVariant &value)
 {
-		//The first time this text is added to a scene, we make several cheking and connection
+		//The first time this text is added to a scene, we make several checking and connection
 		//according to the link type of the parent element
 	if(change == QGraphicsItem::ItemSceneHasChanged && m_first_scene_change)
 	{
@@ -783,7 +785,7 @@ void DynamicElementTextItem::elementInfoChanged()
 
 	if (m_text_from == ElementInfo)
 	{
-			//If the info is the label, then we must to make some connection
+			//If the info is the label, then we must make some connection
 			//if the label is created from a formula
 		if(m_info_name == "label")
 		{
@@ -799,7 +801,7 @@ void DynamicElementTextItem::elementInfoChanged()
 	}
 	else if (m_text_from == CompositeText)
 	{
-			//If the composite have the label variable, we must to make some
+			//If the composite have the label variable, we must make some
 			//connection if the label is created from a formula
 		if (m_composite_text.contains("%{label}"))
 			setupFormulaConnection();
@@ -909,7 +911,7 @@ void DynamicElementTextItem::setConnectionForReportFormula(const QString &formul
 	Diagram *other_diagram = m_other_report.data()->diagram();
 	
 		//Because the variable %F is a reference to another text which can contain variables,
-		//we must to replace %F by the real text, to check if the real text contain the variable %id
+		//we must replace %F by the real text, to check if the real text contains the variable %id
 	if (other_diagram && string.contains("%F"))
 	{
 		m_F_str = other_diagram->border_and_titleblock.folio();
@@ -938,7 +940,7 @@ void DynamicElementTextItem::removeConnectionForReportFormula(const QString &for
 	Diagram *other_diagram = m_other_report.data()->diagram();
 	
 		//Because the variable %F is a reference to another text which can contain variables,
-		//we must to replace %F by the real text, to check if the real text contain the variable %id
+		//we must replace %F with the real text, to check if the real text contains the variable %id
 	if (other_diagram && string.contains("%F"))
 	{
 		string.replace("%F", m_F_str);
@@ -1326,6 +1328,7 @@ void DynamicElementTextItem::updateXref()
 					m_update_slave_Xref_connection << connect(m_master_element.data(), &Element::xChanged,                       this, &DynamicElementTextItem::updateXref);
 					m_update_slave_Xref_connection << connect(m_master_element.data(), &Element::yChanged,                       this, &DynamicElementTextItem::updateXref);
 					m_update_slave_Xref_connection << connect(m_master_element.data(), &Element::elementInfoChange,              this, &DynamicElementTextItem::updateXref);
+					m_update_slave_Xref_connection << connect(diagram(), &Diagram::diagramInformationChanged,                    this, &DynamicElementTextItem::updateXref);
 					m_update_slave_Xref_connection << connect(diagram()->project(),    &QETProject::projectDiagramsOrderChanged, this, &DynamicElementTextItem::updateXref);
 					m_update_slave_Xref_connection << connect(diagram()->project(),    &QETProject::diagramRemoved,              this, &DynamicElementTextItem::updateXref);
 					m_update_slave_Xref_connection << connect(diagram()->project(),    &QETProject::XRefPropertiesChanged,       this, &DynamicElementTextItem::updateXref);
