@@ -1,5 +1,5 @@
 ﻿/*
-	Copyright 2006-2021 The QElectroTech Team
+	Copyright 2006-2023 The QElectroTech Team
 	This file is part of QElectroTech.
 
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -24,6 +24,7 @@
 #include "../diagramcontext.h"
 #include "../qet.h"
 #include "qetgraphicsitem.h"
+#include "../properties/elementdata.h"
 
 #include <QHash>
 #include <QPicture>
@@ -56,7 +57,8 @@ class Element : public QetGraphicsItem
 			AllReport = 6,
 			Master = 8,
 			Slave = 16,
-			Terminale = 32};
+			Terminale = 32,
+			Thumbnail = 64};
 
 		Element(const ElementsLocation &location,
 			QGraphicsItem * = nullptr,
@@ -77,7 +79,7 @@ class Element : public QetGraphicsItem
 		int type() const override { return Type; }
 
 	signals:
-		void linkedElementChanged(); //This signal is emited when the linked elements with this element change
+		void linkedElementChanged(); //This signal is emitted when the linked elements with this element change
 		void elementInfoChange(
 				DiagramContext old_info,
 				DiagramContext new_info);
@@ -100,8 +102,18 @@ class Element : public QetGraphicsItem
 
 			//METHODS related to information
 		DiagramContext elementInformations()const
-		{return m_element_informations;}
+		{return m_data.m_informations;}
 		virtual void setElementInformations(DiagramContext dc);
+
+		ElementData elementData() const;
+		void setElementData (ElementData data);
+
+		/**
+		 * @brief kindInformations
+		 * @deprecated
+		 * use elementData function instead
+		 * @return
+		 */
 		DiagramContext kindInformations() const
 		{return m_kind_informations;}
 		//@kind_information_ is used to store more information
@@ -164,8 +176,20 @@ class Element : public QetGraphicsItem
 		virtual void unlinkElement(Element *) {}
 		virtual void initLink(QETProject *);
 		QList<Element *> linkedElements ();
+
+		/**
+		 * @brief linkType
+		 * use elementData function instead
+		 * @return
+		 */
 		virtual kind linkType() const {return m_link_type;} // return the linkable type
+		/**
+		 * @brief linkTypeToString
+		 * use elementData function instead
+		 * @return
+		 */
 		QString linkTypeToString() const;
+
 		void newUuid() {m_uuid = QUuid::createUuid();} 	//create new uuid for this element
 
 	protected:
@@ -201,18 +225,6 @@ class Element : public QetGraphicsItem
 		void hoverLeaveEvent(QGraphicsSceneHoverEvent *) override;
 
 	protected:
-		// m_converted_text_from_description,
-		// when a element is created from his description,
-		// the old element text item (tagged as 'input' in the xml)
-		// are converted to dynamic text field,
-		// the QPointF is the original position of the text item,
-		// because the origin transformation point of text item
-		// and dynamic text item are not the same,
-		// so we must to keep a track of this value,
-		// to be use in the function element::fromXml
-		QHash <DynamicElementTextItem *, QPointF>
-		m_converted_text_from_xml_description;
-
 			//ATTRIBUTES related to linked element
 		QList <Element *> connected_elements;
 		QList <QUuid>     tmp_uuids_link;
@@ -220,16 +232,16 @@ class Element : public QetGraphicsItem
 		kind              m_link_type = Element::Simple;
 
 			//ATTRIBUTES related to informations
-		DiagramContext m_element_informations, m_kind_informations;
+		DiagramContext m_kind_informations;
 		autonum::sequentialNumbers m_autoNum_seq;
 		bool m_freeze_label = false;
 		QString m_F_str;
 
 		ElementsLocation m_location;
-		NamesList m_names;
 		QList <Terminal *> m_terminals;
 		const QPicture m_picture;
 		const QPicture m_low_zoom_picture;
+		ElementData m_data;
 
 	private:
 		bool m_must_highlight = false;
