@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2021 The QElectroTech Team
+	Copyright 2006-2023 The QElectroTech Team
 	This file is part of QElectroTech.
 
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -27,6 +27,7 @@
 #include "../qeticons.h"
 #include "../qetxml.h"
 #include "../ui/shapegraphicsitempropertieswidget.h"
+#include "../utils/qetutils.h"
 
 /**
 	@brief QetShapeItem::QetShapeItem
@@ -211,7 +212,7 @@ int QetShapeItem::pointsCount() const
 
 /**
 	@brief QetShapeItem::setNextPoint
-	Add a new point to the curent polygon
+	Add a new point to the current polygon
 	@param P the new point.
 */
 void QetShapeItem::setNextPoint(QPointF P)
@@ -591,9 +592,9 @@ void QetShapeItem::addHandler()
 
 		if(!points_vector.isEmpty() && scene())
 		{
-			m_handler_vector = QetGraphicsHandlerItem::handlerForPoint(mapToScene(points_vector));
+			m_handler_vector = QetGraphicsHandlerItem::handlerForPoint(mapToScene(points_vector), QETUtils::graphicsHandlerSize(this));
 
-			for(QetGraphicsHandlerItem *handler : m_handler_vector)
+			for(const auto handler : qAsConst(m_handler_vector))
 			{
 				handler->setZValue(this->zValue()+1);
 				handler->setColor(Qt::blue);
@@ -852,26 +853,8 @@ bool QetShapeItem::fromXml(const QDomElement &e)
 	m_brush = QETXML::brushFromXml(e.firstChildElement("brush"));
 
 	QString type = e.attribute("type");
-#if TODO_LIST
-#pragma message("@TODO Compatibility for version older than N°4075, shape type was stored with an int")
-#endif
-		//@TODO Compatibility for version older than N°4075, shape type was stored with an int
-	if (type.size() == 1)
-	{
-		switch(e.attribute("type","0").toInt())
-		{
-			case 0: m_shapeType = Line;      break;
-			case 1: m_shapeType = Rectangle; break;
-			case 2: m_shapeType = Ellipse;   break;
-			case 3: m_shapeType = Polygon;  break;
-		}
-	}
-		//For version after N°4075, shape is stored with a string
-	else
-	{
-		QMetaEnum me = metaObject()->enumerator(metaObject()->indexOfEnumerator("ShapeType"));
-		m_shapeType = QetShapeItem::ShapeType(me.keysToValue(type.toStdString().data()));
-	}
+	QMetaEnum me = metaObject()->enumerator(metaObject()->indexOfEnumerator("ShapeType"));
+	m_shapeType = QetShapeItem::ShapeType(me.keysToValue(type.toStdString().data()));
 
 	if (m_shapeType != Polygon)
 	{
@@ -987,7 +970,10 @@ bool QetShapeItem::toDXF(const QString &filepath,const QPen &pen)
 				Createdxf::dxfColor(pen));
 	    return true;
 	case Polygon:
-	    Createdxf::drawPolygon(filepath,m_polygon,Createdxf::dxfColor(pen));
+        if(m_polygon.isClosed())
+            Createdxf::drawPolygon(filepath,m_polygon,Createdxf::dxfColor(pen));
+        else
+            Createdxf::drawPolyline(filepath,m_polygon,Createdxf::dxfColor(pen));
 	    return true;
 	default:
 	    return false;
@@ -1008,7 +994,7 @@ void QetShapeItem::editProperty()
 
 /**
 	@brief QetShapeItem::name
-	@return the name of the curent shape.
+	@return the name of the current shape.
 */
 QString QetShapeItem::name() const
 {
