@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2021 The QElectroTech Team
+	Copyright 2006-2023 The QElectroTech Team
 	This file is part of QElectroTech.
 
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -42,11 +42,7 @@ class Terminal : public QGraphicsObject
 
 	// constructors, destructor
 	public:
-		Terminal(QPointF,      Qet::Orientation, Element * = nullptr);
-		Terminal(qreal, qreal, Qet::Orientation, Element * = nullptr);
 		Terminal(TerminalData* data, Element *e = nullptr);
-		Terminal(QPointF,      Qet::Orientation, QString number,
-			 QString name, bool hiddenName, Element * = nullptr);
 		~Terminal() override;
 
 	private:
@@ -82,10 +78,6 @@ class Terminal : public QGraphicsObject
 		QList<Conductor *> conductors() const;
 		Qet::Orientation orientation() const;
 		QPointF dockConductor() const;
-		QString number() const;
-		QString name() const;
-		void setNumber(QString number);
-		void setName(QString name, bool hiddenName);
 		void updateConductor();
 		bool isLinkedTo(Terminal *);
 		bool canBeLinkedTo(Terminal *);
@@ -135,29 +127,18 @@ class Terminal : public QGraphicsObject
 		QPointF dock_elmt_;
 	private:
 		/// List of conductors attached to the terminal
-		QList<Conductor *> conductors_;
-		/**
-			Pointer to a rectangle representing the terminal bounding rect;
-			used to calculate the bounding rect once only;
-			used a pointer because boundingRect() is supposed to be const.
-		*/
-		QRectF *br_{nullptr};
-		/// Last terminal seen through an attached conductor
-		Terminal *previous_terminal_;
-		/// Whether the mouse pointer is hovering the terminal
-		bool hovered_;
-		/// Color used for the hover effect
-		QColor hovered_color_;
-		/// Number of Terminal
-		QString number_terminal_;
-		/// Name of Terminal
-		QString name_terminal_;
-		bool name_terminal_hidden;
+		QList<Conductor *> m_conductors_list;
+		QRectF m_br;
+			/// Last terminal seen through an attached conductor
+		Terminal *m_previous_terminal = nullptr;
+			/// Whether the mouse pointer is hovering the terminal
+		bool m_hovered = false;
+			/// Color used for the hover effect
+		QColor m_hovered_color = Terminal::neutralColor;
 
 	private:
-		void init(QString number, QString name, bool hiddenName);
-		void init(QPointF pf, Qet::Orientation o, QString number,
-			  QString name, bool hiddenName);
+		void init();
+		void init(QPointF pf, Qet::Orientation o);
 };
 
 /**
@@ -166,25 +147,7 @@ class Terminal : public QGraphicsObject
 */
 inline int Terminal::conductorsCount() const
 {
-	return(conductors_.size());
-}
-
-/**
-	@brief Terminal::number
-	@return the number of terminal.
-*/
-inline QString Terminal::number() const
-{
-	return(number_terminal_);
-}
-
-/**
-	@brief Terminal::name
-	@return the name of terminal.
-*/
-inline QString Terminal::name() const
-{
-	return(name_terminal_);
+	return(m_conductors_list.size());
 }
 
 QList<Terminal *> relatedPotentialTerminal (const Terminal *terminal,
