@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2021 The QElectroTech Team
+	Copyright 2006-2023 The QElectroTech Team
 	This file is part of QElectroTech.
 
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -16,6 +16,7 @@
 	along with QElectroTech.  If not, see <http://www.gnu.org/licenses/>.
 */
 #include "terminalelement.h"
+#include"../TerminalStrip/realterminal.h"
 
 /**
 	@brief TerminalElement::TerminalElement
@@ -27,7 +28,10 @@
 TerminalElement::TerminalElement(const ElementsLocation &location,
 				 QGraphicsItem *qgi, int *state) :
 	Element(location, qgi, state, Element::Terminale)
-{}
+{
+	auto rt = new RealTerminal(this);
+	m_real_terminal = rt->sharedRef();
+}
 
 TerminalElement::~TerminalElement()
 {}
@@ -40,3 +44,23 @@ void TerminalElement::initLink(QETProject *project) {
 	Element::initLink(project);
 }
 
+/**
+ * @brief TerminalElement::realTerminal
+ * @return the real terminal of this terminal element.
+ */
+QSharedPointer<RealTerminal> TerminalElement::realTerminal() const {
+	return m_real_terminal;
+}
+
+/**
+ * @brief TerminalElement::parentTerminalStrip
+ * @return The parent terminal strip of this
+ * terminal element or nullptr if not.
+ */
+TerminalStrip *TerminalElement::parentTerminalStrip() const {
+	if (m_real_terminal) {
+		return m_real_terminal->parentStrip();
+	}
+	return nullptr;
+}
+
