@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2021 The QElectroTech Team
+	Copyright 2006-2023 The QElectroTech Team
 	This file is part of QElectroTech.
 
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -20,8 +20,10 @@
 
 
 #include "element.h"
+#include "../TerminalStrip/terminalstrip.h"
 
 class QETProject;
+class RealTerminal;
 /**
 	@brief The TerminalElement class
 */
@@ -33,6 +35,13 @@ class TerminalElement : public Element
 				QGraphicsItem * = nullptr, int * = nullptr);
 		~TerminalElement() override;
 		void initLink(QETProject *project) override;
+
+		QSharedPointer<RealTerminal> realTerminal() const;
+		void setParentTerminalStrip(TerminalStrip *strip);
+		TerminalStrip *parentTerminalStrip() const;
+
+	private:
+		QSharedPointer<RealTerminal> m_real_terminal;
 };
 
 #endif // TERMINALELEMENT_H
