@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2021 The QElectroTech Team
+	Copyright 2006-2023 The QElectroTech Team
 	This file is part of QElectroTech.
 
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -177,7 +177,7 @@ QString QETInformation::elementInfoToVar(const QString &info)
  * @brief QETInformation::infoToVar
  * @param info
  * @return return the string @info prepended by %{ ans appended by }
- * exemple : if info is label, the returned string is %{label}
+ * example : if info is label, the returned string is %{label}
  */
 QString QETInformation::infoToVar(const QString &info)
 {
@@ -239,3 +239,32 @@ QString QETInformation::translatedInfoKey(const QString &info)
 	else if (info == COND_FORMULA)                     return QObject::tr("Formule du texte");
 	else return QString();
 }
+
+QStringList QETInformation::elementEditorElementInfoKeys()
+{
+	QStringList list = { ELMT_LABEL,
+						 ELMT_PLANT,
+						 ELMT_COMMENT,
+						 ELMT_DESCRIPTION,
+						 ELMT_DESIGNATION,
+						 ELMT_MANUFACTURER,
+						 ELMT_MANUFACTURER_REF,
+						 ELMT_SUPPLIER,
+						 ELMT_QUANTITY,
+						 ELMT_UNITY,
+						 ELMT_MACHINE_MANUFACTURER_REF};
+	return list;
+}
+
+QStringList QETInformation::terminalElementInfoKeys()
+{
+	QStringList list = { ELMT_FORMULA,
+						 ELMT_LABEL,
+						 ELMT_COMMENT,
+						 ELMT_DESIGNATION,
+						 ELMT_MANUFACTURER,
+						 ELMT_MANUFACTURER_REF,
+						 ELMT_MACHINE_MANUFACTURER_REF,
+						 ELMT_SUPPLIER };
+	return list;
+}
