@@ -1,5 +1,5 @@
 ﻿/*
-	Copyright 2006-2021 The QElectroTech Team
+	Copyright 2006-2023 The QElectroTech Team
 	This file is part of QElectroTech.
 
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -31,6 +31,8 @@
 #include "titleblocktemplate.h"
 #include "ui/dialogwaiting.h"
 #include "ui/importelementdialog.h"
+#include "TerminalStrip/terminalstrip.h"
+#include "qetxml.h"
 
 #include <QHash>
 #include <QStandardPaths>
@@ -120,8 +122,23 @@ QETProject::QETProject(KAutoSaveFile *backup, QObject *parent) :
 */
 QETProject::~QETProject()
 {
-	for (auto diagram : m_diagrams_list)
+		//We block database signal to avoid hundreds of unnecessary emitted signal
+		//due to deletion (diagram, item, etc...) and as much update made in the not yet deleted things.
+	m_data_base.blockSignals(true);
+
+		//Each time a diagram is deleted we also remove it from m_diagram_list
+		//because a lot of thing append during the destructor of a diagram class
+		//and one of these thing (not directly in the destructor of the diagram
+		//but in another destructor called by the diagram destructor)
+		//is to get the diagram list of the project to make some updates @see QList<Diagram *> QETProject::diagrams() const.
+		//So we need to remove the freshly deleted diagram from the list
+		//in each iteration of the loop to avoid  the use of a dangling pointer.
+	const auto diag_list = m_diagrams_list;
+	for (const auto &diagram : diag_list)
+	{
 		delete  diagram;
+		m_diagrams_list.removeOne(diagram);
+	}
 }
 
 /**
@@ -159,12 +176,12 @@ void QETProject::init()
 	writeBackup();
 
 	QSettings settings;
-	int autosave_interval = settings.value("diagrameditor/autosave-interval", 0).toInt();
+	int autosave_interval = settings.value(QStringLiteral("diagrameditor/autosave-interval"), 0).toInt();
 	if(autosave_interval > 0)
 	{
 		int ms = autosave_interval*60*1000;
 		m_autosave_timer.setInterval(ms);
-		connect(&m_autosave_timer, &QTimer::timeout, [this]()
+		connect(&m_autosave_timer, &QTimer::timeout, this, [=]()
 		{
 			if(!this->m_file_path.isEmpty())
 				this->write();
@@ -303,8 +320,8 @@ void QETProject::setFilePath(const QString &filepath)
 
 
 
-	emit(projectFilePathChanged(this, m_file_path));
-	emit(projectInformationsChanged(this));
+	emit projectFilePathChanged(this, m_file_path);
+	emit projectInformationsChanged(this);
 	updateDiagramsFolioData();
 }
 
@@ -343,7 +360,7 @@ QString QETProject::pathNameTitle() const
 				"Projet « %1 : %2»",
 				"displayed title for a ProjectView - %1 is the project title, -%2 is the project path"
 			)
-		).arg(project_title_).arg (m_file_path);
+		).arg(project_title_, m_file_path);
 	} else if (!m_file_path.isEmpty()) {
 		final_title = QString(
 			tr(
@@ -409,8 +426,8 @@ void QETProject::setTitle(const QString &title) {
 	if (project_title_ == title) return;
 
 	project_title_ = title;
-	emit(projectTitleChanged(this, project_title_));
-	emit(projectInformationsChanged(this));
+	emit projectTitleChanged(this, project_title_);
+	emit projectInformationsChanged(this);
 	updateDiagramsFolioData();
 }
 
@@ -612,7 +629,7 @@ QHash <QString, NumerotationContext> QETProject::folioAutoNum() const
 /**
 	@brief QETProject::addConductorAutoNum
 	Add a new conductor numerotation context. If key already exist,
-	replace old context by the new context
+	replace old context with the new context
 	@param key
 	@param context
 */
@@ -623,7 +640,7 @@ void QETProject::addConductorAutoNum(const QString& key, const NumerotationConte
 /**
 	@brief QETProject::addElementAutoNum
 	Add a new element numerotation context. If key already exist,
-	replace old context by the new context
+	replace old context with the new context
 	@param key
 	@param context
 */
@@ -636,7 +653,7 @@ void QETProject::addElementAutoNum(const QString& key, const NumerotationContext
 /**
 	@brief QETProject::addFolioAutoNum
 	Add a new folio numerotation context. If key already exist,
-	replace old context by the new context
+	replace old context with the new context
 	@param key
 	@param context
 */
@@ -838,8 +855,9 @@ void QETProject::autoFolioNumberingSelectedFolios(int from,
 						  const QString& autonum){
 	int total_folio = m_diagrams_list.count();
 	DiagramContext project_wide_properties = m_project_properties;
-	for (int i=from; i<=to; i++) {
-		QString title = m_diagrams_list[i] -> title();
+
+	for (int i=from; i<=to; i++)
+	{
 		NumerotationContext nC = folioAutoNum(autonum);
 		NumerotationContextCommands nCC = NumerotationContextCommands(nC);
 		m_diagrams_list[i] -> border_and_titleblock.setFolio("%autonum");
@@ -912,6 +930,16 @@ QDomDocument QETProject::toXml()
 		appended_diagram.toElement().setAttribute("order", order_num ++);
 	}
 
+		//Write terminal strip to xml
+	if (m_terminal_strip_vector.count())
+	{
+		auto xml_strip = xml_doc.createElement(QStringLiteral("terminal_strips"));
+		for (auto &strip : m_terminal_strip_vector) {
+			xml_strip.appendChild(strip->toXml(xml_doc));
+		}
+		project_root.appendChild(xml_strip);
+	}
+
 	// Write the elements collection.
 	project_root.appendChild(m_elements_collection->root().cloneNode(true));
 
@@ -957,7 +985,7 @@ QETResult QETProject::write()
 	m_project_properties.addValue("savedfilename", QFileInfo(filePath()).baseName());
 	m_project_properties.addValue("savedfilepath", filePath());
 
-	emit(projectInformationsChanged(this));
+	emit projectInformationsChanged(this);
 	updateDiagramsFolioData();
 
 	setModified(false);
@@ -985,7 +1013,7 @@ void QETProject::setReadOnly(bool read_only)
 			//keep the file to which this project is read-only
 		read_only_file_path_ = m_file_path;
 		m_read_only = read_only;
-		emit(readOnlyChanged(this, read_only));
+		emit readOnlyChanged(this, read_only);
 	}
 }
 
@@ -1017,7 +1045,7 @@ bool QETProject::isEmpty() const
 /**
 	@brief QETProject::importElement
 	Import the element represented by location
-	to the embbeded collection of this project
+	to the embedded collection of this project
 	@param location
 	@return the location of the imported element, location can be null.
 */
@@ -1054,7 +1082,7 @@ ElementsLocation QETProject::importElement(ElementsLocation &location)
 		if (ied.exec() == QDialog::Accepted) {
 			QET::Action action = ied.action();
 
-			//Use the exisitng element
+			//Use the exisiting element
 			if (action == QET::Ignore) {
 				return existing_location;
 			}
@@ -1183,7 +1211,7 @@ QList<ElementsLocation> QETProject::unusedElements() const
 	within this project, false otherwise
 */
 bool QETProject::usesTitleBlockTemplate(const TitleBlockTemplateLocation &location) {
-	// a diagram can only use a title block template embedded wihtin its parent project
+	// a diagram can only use a title block template embedded within its parent project
 	if (location.parentProject() != this) return(false);
 
 	foreach (Diagram *diagram, diagrams()) {
@@ -1213,7 +1241,7 @@ Diagram *QETProject::addNewDiagram(int pos)
 	diagram->defaultConductorProperties = defaultConductorProperties();
 
 	addDiagram(diagram, pos);
-	emit(diagramAdded(this, diagram));
+	emit diagramAdded(this, diagram);
 	return(diagram);
 }
 
@@ -1231,7 +1259,7 @@ void QETProject::removeDiagram(Diagram *diagram)
 
 	if (m_diagrams_list.removeAll(diagram))
 	{
-		emit(diagramRemoved(this, diagram));
+		emit diagramRemoved(this, diagram);
 		diagram->deleteLater();
 	}
 
@@ -1255,7 +1283,7 @@ void QETProject::diagramOrderChanged(int old_index, int new_index) {
 	m_diagrams_list.move(old_index, new_index);
 	updateDiagramsFolioData();
 	setModified(true);
-	emit(projectDiagramsOrderChanged(this, old_index, new_index));
+	emit projectDiagramsOrderChanged(this, old_index, new_index);
 }
 
 /**
@@ -1264,8 +1292,8 @@ void QETProject::diagramOrderChanged(int old_index, int new_index) {
 void QETProject::setModified(bool modified) {
 	if (m_modified != modified) {
 		m_modified = modified;
-		emit(projectModified(this, m_modified));
-		emit(projectInformationsChanged(this));
+		emit projectModified(this, m_modified);
+		emit projectInformationsChanged(this);
 	}
 }
 
@@ -1280,13 +1308,13 @@ void QETProject::readProjectXml(QDomDocument &xml_project)
 	m_state = ProjectParsingRunning;
 
 	//The roots of the xml document must be a "project" element
-	if (root_elmt.tagName() == "project")
+	if (root_elmt.tagName() == QLatin1String("project"))
 	{
 		//Normal opening mode
-		if (root_elmt.hasAttribute("version"))
+		if (root_elmt.hasAttribute(QStringLiteral("version")))
 		{
 			bool conv_ok;
-			m_project_qet_version = root_elmt.attribute("version").toDouble(&conv_ok);
+			m_project_qet_version = root_elmt.attribute(QStringLiteral("version")).toDouble(&conv_ok);
 #if TODO_LIST
 #pragma message("@TODO use of version convert")
 #endif
@@ -1311,8 +1339,29 @@ void QETProject::readProjectXml(QDomDocument &xml_project)
 					return;
 				}
 			}
+				//Since QElectrotech 0.9 the compatibility with project made with
+				//Qet 0.6 or lower is break;
+			if (conv_ok && m_project_qet_version <= 0.6 )
+			{
+				auto ret = QET::QetMessageBox::warning(
+							   nullptr,
+							   tr("Avertissement ", "message box title"),
+							   tr("Le projet que vous tentez d'ouvrir est partiellement "
+								  "compatible avec votre version de QElectroTech.\n"
+								  "Afin de le rendre totalement compatible veuillez ouvrir ce même projet "
+								  "avec la version 0.8 de QElectroTech sauvegarder le projet "
+								  "et l'ouvrir à  nouveau avec cette version.\n"
+								  "Que désirez vous faire ?"),
+							   QMessageBox::Open | QMessageBox::Cancel);
+
+				if (ret == QMessageBox::Cancel)
+				{
+					m_state = FileOpenDiscard;
+					return;
+				}
+			}
 		}
-		setTitle(root_elmt.attribute("title"));
+		setTitle(root_elmt.attribute(QStringLiteral("title")));
 	}
 	else
 	{
@@ -1320,16 +1369,26 @@ void QETProject::readProjectXml(QDomDocument &xml_project)
 	}
 
 	m_data_base.blockSignals(true);
+
 		//Load the project-wide properties
 	readProjectPropertiesXml(xml_project);
+
 		//Load the default properties for the new diagrams
 	readDefaultPropertiesXml(xml_project);
+
 		//load the embedded titleblock templates
 	m_titleblocks_collection.fromXml(xml_project.documentElement());
+
 		//Load the embedded elements collection
 	readElementsCollectionXml(xml_project);
+
 		//Load the diagrams
 	readDiagramsXml(xml_project);
+
+		//Load the terminal strip
+	readTerminalStripXml(xml_project);
+
+
 	m_data_base.blockSignals(false);
 	m_data_base.updateDB();
 
@@ -1362,7 +1421,7 @@ void QETProject::readDiagramsXml(QDomDocument &xml_project)
 	}
 
 	//Search the diagrams in the project
-	QDomNodeList diagram_nodes = xml_project.elementsByTagName("diagram");
+	QDomNodeList diagram_nodes = xml_project.elementsByTagName(QStringLiteral("diagram"));
 
 	if(dlgWaiting)
 		dlgWaiting->setProgressBarRange(0, diagram_nodes.length()*3);
@@ -1377,15 +1436,13 @@ void QETProject::readDiagramsXml(QDomDocument &xml_project)
 			QDomElement diagram_xml_element = diagram_nodes
 					.at(i)
 					.toElement();
-			Diagram *diagram = new Diagram(this);
+			auto diagram = new Diagram(this);
+			m_diagrams_list << diagram;
 
-			int diagram_order = -1;
-			if (!QET::attributeIsAnInteger(diagram_xml_element,
-							   "order",
-							   &diagram_order))
-				diagram_order = 500000;
-
-			addDiagram(diagram, diagram_order-1);
+			connect(&diagram->border_and_titleblock, &BorderTitleBlock::needFolioData,
+					this, &QETProject::updateDiagramsFolioData);
+			connect(diagram, &Diagram::usedTitleBlockTemplateChanged,
+					this, &QETProject::usedTitleBlockTemplateChanged);
 
 			diagram->initFromXml(diagram_xml_element);
 			if(dlgWaiting)
@@ -1393,6 +1450,8 @@ void QETProject::readDiagramsXml(QDomDocument &xml_project)
 		}
 	}
 
+	updateDiagramsFolioData();
+
 		//Initialise links between elements in this project
 		//and refresh the text of conductor
 	if(dlgWaiting)
@@ -1405,14 +1464,14 @@ void QETProject::readDiagramsXml(QDomDocument &xml_project)
 
 	m_data_base.updateDB(); //All diagrams and items are created we need to update the database
 
-	for(Diagram *d : diagrams())
+	for(const auto &diagram : diagrams())
 	{
 		if(dlgWaiting)
 		{
 			dlgWaiting->setProgressBar(dlgWaiting->progressBarValue()+1);
-			dlgWaiting->setDetail(d->title());
+			dlgWaiting->setDetail(diagram->title());
 		}
-		d->refreshContents();
+		diagram->refreshContents();
 	}
 }
 
@@ -1424,7 +1483,7 @@ void QETProject::readDiagramsXml(QDomDocument &xml_project)
 void QETProject::readElementsCollectionXml(QDomDocument &xml_project)
 {
 		//Get the embedded elements collection of the project
-	QDomNodeList collection_roots = xml_project.elementsByTagName("collection");
+	QDomNodeList collection_roots = xml_project.elementsByTagName(QStringLiteral("collection"));
 	QDomElement collection_root;
 
 	if (!collection_roots.isEmpty())
@@ -1449,8 +1508,8 @@ void QETProject::readElementsCollectionXml(QDomDocument &xml_project)
 */
 void QETProject::readProjectPropertiesXml(QDomDocument &xml_project)
 {
-	foreach (QDomElement e, QET::findInDomElement(xml_project.documentElement(), "properties"))
-		m_project_properties.fromXml(e);
+	for (const auto &dom_elmt : QET::findInDomElement(xml_project.documentElement(), QStringLiteral("properties")))
+		m_project_properties.fromXml(dom_elmt);
 }
 
 /**
@@ -1462,7 +1521,7 @@ void QETProject::readProjectPropertiesXml(QDomDocument &xml_project)
 void QETProject::readDefaultPropertiesXml(QDomDocument &xml_project)
 {
 		// Find xml element where is stored properties for new diagram
-	QDomNodeList newdiagrams_nodes = xml_project.elementsByTagName("newdiagrams");
+	QDomNodeList newdiagrams_nodes = xml_project.elementsByTagName(QStringLiteral("newdiagrams"));
 	if (newdiagrams_nodes.isEmpty()) return;
 
 	QDomElement newdiagrams_elmt = newdiagrams_nodes.at(0).toElement();
@@ -1482,21 +1541,21 @@ void QETProject::readDefaultPropertiesXml(QDomDocument &xml_project)
 		QDomElement child_elmt = child.toElement();
 		if (child_elmt.isNull()) continue;
 
-		if (child_elmt.tagName() == "border")
+		if (child_elmt.tagName() == QLatin1String("border"))
 			border_elmt = child_elmt;
-		else if (child_elmt.tagName() == "inset")
+		else if (child_elmt.tagName() == QLatin1String("inset"))
 			titleblock_elmt = child_elmt;
-		else if (child_elmt.tagName() == "conductors")
+		else if (child_elmt.tagName() == QLatin1String("conductors"))
 			conductors_elmt = child_elmt;
-		else if (child_elmt.tagName() == "report")
+		else if (child_elmt.tagName() == QLatin1String("report"))
 			report_elmt = child_elmt;
-		else if (child_elmt.tagName() == "xrefs")
+		else if (child_elmt.tagName() == QLatin1String("xrefs"))
 			xref_elmt = child_elmt;
-		else if (child_elmt.tagName() == "conductors_autonums")
+		else if (child_elmt.tagName() == QLatin1String("conductors_autonums"))
 			conds_autonums = child_elmt;
-		else if (child_elmt.tagName()== "folio_autonums")
+		else if (child_elmt.tagName()== QLatin1String("folio_autonums"))
 			folio_autonums = child_elmt;
-		else if (child_elmt.tagName()== "element_autonums")
+		else if (child_elmt.tagName()== QLatin1String("element_autonums"))
 			element_autonums = child_elmt;
 	}
 
@@ -1504,21 +1563,21 @@ void QETProject::readDefaultPropertiesXml(QDomDocument &xml_project)
 	if (!border_elmt.isNull())	   default_border_properties_.fromXml(border_elmt);
 	if (!titleblock_elmt.isNull()) default_titleblock_properties_.fromXml(titleblock_elmt);
 	if (!conductors_elmt.isNull()) default_conductor_properties_.fromXml(conductors_elmt);
-	if (!report_elmt.isNull())	   setDefaultReportProperties(report_elmt.attribute("label"));
+	if (!report_elmt.isNull())	   setDefaultReportProperties(report_elmt.attribute(QStringLiteral("label")));
 	if (!xref_elmt.isNull())
 	{
-		foreach(QDomElement elmt, QET::findInDomElement(xref_elmt, "xref"))
+		for (const auto &elmt : QET::findInDomElement(xref_elmt, QStringLiteral("xref")))
 		{
 			XRefProperties xrp;
 			xrp.fromXml(elmt);
-			m_default_xref_properties.insert(elmt.attribute("type"), xrp);
+			m_default_xref_properties.insert(elmt.attribute(QStringLiteral("type")), xrp);
 		}
 	}
 	if (!conds_autonums.isNull())
 	{
-		m_current_conductor_autonum = conds_autonums.attribute("current_autonum");
-		m_freeze_new_conductors = conds_autonums.attribute("freeze_new_conductors") == "true";
-		foreach (QDomElement elmt, QET::findInDomElement(conds_autonums, "conductor_autonum"))
+		m_current_conductor_autonum = conds_autonums.attribute(QStringLiteral("current_autonum"));
+		m_freeze_new_conductors = conds_autonums.attribute(QStringLiteral("freeze_new_conductors")) == QLatin1String("true");
+		for (auto elmt : QET::findInDomElement(conds_autonums, QStringLiteral("conductor_autonum")))
 		{
 			NumerotationContext nc;
 			nc.fromXml(elmt);
@@ -1527,22 +1586,42 @@ void QETProject::readDefaultPropertiesXml(QDomDocument &xml_project)
 	}
 	if (!folio_autonums.isNull())
 	{
-		foreach (QDomElement elmt, QET::findInDomElement(folio_autonums, "folio_autonum"))
+		for (auto elmt : QET::findInDomElement(folio_autonums, QStringLiteral("folio_autonum")))
 		{
 			NumerotationContext nc;
 			nc.fromXml(elmt);
-			m_folio_autonum.insert(elmt.attribute("title"), nc);
+			m_folio_autonum.insert(elmt.attribute(QStringLiteral("title")), nc);
 		}
 	}
 	if (!element_autonums.isNull())
 	{
-		m_current_element_autonum = element_autonums.attribute("current_autonum");
-		m_freeze_new_elements = element_autonums.attribute("freeze_new_elements") == "true";
-		foreach (QDomElement elmt, QET::findInDomElement(element_autonums, "element_autonum"))
+		m_current_element_autonum = element_autonums.attribute(QStringLiteral("current_autonum"));
+		m_freeze_new_elements = element_autonums.attribute(QStringLiteral("freeze_new_elements")) == QLatin1String("true");
+		for (auto elmt : QET::findInDomElement(element_autonums, QStringLiteral("element_autonum")))
 		{
 			NumerotationContext nc;
 			nc.fromXml(elmt);
-			m_element_autonum.insert(elmt.attribute("title"), nc);
+			m_element_autonum.insert(elmt.attribute(QStringLiteral("title")), nc);
+		}
+	}
+}
+
+/**
+ * @brief QETProject::readTerminalStripXml
+ * Read the terminal strips of this project
+ * @param xml_project
+ */
+void QETProject::readTerminalStripXml(const QDomDocument &xml_project)
+{
+	auto xml_elmt = xml_project.documentElement();
+	auto xml_strips = xml_elmt.firstChildElement(QStringLiteral("terminal_strips"));
+	if (!xml_strips.isNull())
+	{
+		for (auto xml_strip : QETXML::findInDomElement(xml_strips, TerminalStrip::xmlTagName()))
+		{
+			auto terminal_strip = new TerminalStrip(this);
+			terminal_strip->fromXml(xml_strip);
+			addTerminalStrip(terminal_strip);
 		}
 	}
 }
@@ -1562,7 +1641,7 @@ void QETProject::writeProjectPropertiesXml(QDomElement &xml_element) {
 	default conductor
 	defaut folio report
 	default Xref
-	@param xml_element : xml element to use for store default propertie.
+	@param xml_element : xml element to use to store default properties.
 */
 void QETProject::writeDefaultPropertiesXml(QDomElement &xml_element)
 {
@@ -1641,7 +1720,7 @@ void QETProject::writeDefaultPropertiesXml(QDomElement &xml_element)
 	@brief QETProject::addDiagram
 	Add a diagram in this project
 	@param diagram added diagram
-	@param pos postion of the new diagram, by default at the end
+	@param pos position of the new diagram, by default at the end
 */
 void QETProject::addDiagram(Diagram *diagram, int pos)
 {
@@ -1674,9 +1753,30 @@ NamesList QETProject::namesListForIntegrationCategory()
 #if QT_VERSION < QT_VERSION_CHECK(6, 0, 0) // ### Qt 6: remove
 	NamesList	names;
 	const QChar russian_data[24] = {
-		0x0418, 0x043C, 0x043F, 0x043E, 0x0440, 0x0442, 0x0438, 0x0440,
-		0x043E, 0x0432, 0x0430, 0x043D, 0x043D, 0x044B, 0x0435, 0x0020,
-		0x044D, 0x043B, 0x0435, 0x043C, 0x0435, 0x043D, 0x0442, 0x044B};
+		0x0418, 
+		0x043C, 
+		0x043F, 
+		0x043E, 
+		0x0440, 
+		0x0442, 
+		0x0438, 
+		0x0440,
+		0x043E, 
+		0x0432, 
+		0x0430, 
+		0x043D, 
+		0x043D, 
+		0x044B, 
+		0x0435, 
+		0x0020,
+		0x044D, 
+		0x043B, 
+		0x0435, 
+		0x043C, 
+		0x0435, 
+		0x043D, 
+		0x0442, 
+		0x044B};
 	const QChar greek_data[18] = {
 		0x0395,
 		0x03b9,
@@ -1696,6 +1796,40 @@ NamesList QETProject::namesListForIntegrationCategory()
 		0x03b5,
 		0x03af,
 		0x03b1};
+	const QChar turkish_data[12] = {
+		0x0130,
+		0x0074,
+		0x0068,
+		0x0061,
+		0x006C,
+		0x0020,
+		0x00F6,
+		0x011F,
+		0x0065,
+		0x006C,
+		0x0065,
+		0x0072};
+	const QChar ukrainian_data[20] = {
+		0x0406,
+		0x043c,
+		0x043f,
+		0x043e,
+		0x0440,
+		0x0442,
+		0x043e,
+		0x0432,
+		0x0430,
+		0x043d,
+		0x0456,
+		0x0020,
+		0x0435,
+		0x043b,
+		0x0435,
+		0x043c,
+		0x0435,
+		0x043d,
+		0x0442,
+		0x0438};
 	const QChar japanese_data[10] = {
 		0x30A4,
 		0x30F3,
@@ -1722,7 +1856,11 @@ NamesList QETProject::namesListForIntegrationCategory()
 	names.addName("hr", "Uvezeni elementi");
 	names.addName("ca", "Elements importats");
 	names.addName("ro", "Elemente importate");
+	names.addName("tr", QString(turkish_data, 12));
+	names.addName("da", "Importerede elementer");
+	names.addName("sl", "Uvoženi elementi");
 	names.addName("ja", QString(japanese_data, 10));
+	names.addName("uk", QString(ukrainian_data, 20));
 	return (names);
 #else
 #	if TODO_LIST
@@ -1742,6 +1880,9 @@ NamesList QETProject::namesListForIntegrationCategory()
 	names.addName("hr", "Uvezeni elementi");
 	names.addName("ca", "Elements importats");
 	names.addName("ro", "Elemente importate");
+	names.addName("da", "Importerede elementer");
+	names.addName("sl", "Uvoženi elementi");
+	names.addName("uk", "Імпортовані елементи");
 	return (names);
 #endif
 }
@@ -1762,7 +1903,8 @@ void QETProject::writeBackup()
 #		if TODO_LIST
 #			pragma message("@TODO remove code for QT 6 or later")
 #		endif
-	qDebug()<<"Help code for QT 6 or later";
+	qDebug() << "Help code for QT 6 or later"
+			 << "QtConcurrent::run its backwards now...function, object, args";
 #	endif
 #endif
 }
@@ -1794,6 +1936,64 @@ void QETProject::setProjectProperties(const DiagramContext &context) {
 	updateDiagramsFolioData();
 }
 
+/**
+ * @brief QETProject::terminalStrip
+ * @return a QVector who contain all terminal strip owned by this project
+ */
+QVector<TerminalStrip *> QETProject::terminalStrip() const {
+	return m_terminal_strip_vector;
+}
+
+/**
+ * @brief QETProject::newTerminalStrip
+ * @param installation : installation of the terminal strip
+ * @param location : location of the terminal strip
+ * @param name : name of the terminal strip
+ * @return Create a new terminal strip with this project as parent.
+ * You can retrieve this terminal strip at any time by calling the function
+ * QETProject::terminalStrip()
+ */
+TerminalStrip *QETProject::newTerminalStrip(QString installation, QString location, QString name)
+{
+	auto ts = new TerminalStrip(installation,
+								location,
+								name,
+								this);
+
+	m_terminal_strip_vector.append(ts);
+	return ts;
+}
+
+/**
+ * @brief QETProject::addTerminalStrip
+ * Add \p strip to the terminal strip list of the project.
+ * The project of \p strip must this project
+ * @param strip
+ * @return true if successfully added
+ */
+bool QETProject::addTerminalStrip(TerminalStrip *strip)
+{
+	if (strip->parent() != this)
+		return false;
+
+	if (m_terminal_strip_vector.contains(strip))
+		return true;
+
+	m_terminal_strip_vector.append(strip);
+	return true;
+}
+
+/**
+ * @brief QETProject::removeTerminalStrip
+ * Remove \p strip from the terminal strip list of this project.
+ * Strip is removed from the list but not deleted.
+ * @param strip
+ * @return true if successfully removed.
+ */
+bool QETProject::removeTerminalStrip(TerminalStrip *strip) {
+	return m_terminal_strip_vector.removeOne(strip);
+}
+
 /**
 	Cette methode sert a reperer un projet vide, c-a-d un projet identique a ce
 	que l'on obtient en faisant Fichier > Nouveau.
@@ -1858,8 +2058,8 @@ void QETProject::updateDiagramsFolioData()
 		}
 	}
 
-	for (Diagram *d : m_diagrams_list) {
-		d->update();
+	for (const auto &diagram_ : qAsConst(m_diagrams_list)) {
+		diagram_->update();
 	}
 }
 
@@ -1895,5 +2095,5 @@ void QETProject::removeDiagramsTitleBlockTemplate(TitleBlockTemplatesCollection
 	@param template_name Name of the template
 */
 void QETProject::usedTitleBlockTemplateChanged(const QString &template_name) {
-	emit(diagramUsedTemplate(embeddedTitleBlockTemplatesCollection(), template_name));
+	emit diagramUsedTemplate(embeddedTitleBlockTemplatesCollection(), template_name);
 }
