@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2021 The QElectroTech Team
+	Copyright 2006-2023 The QElectroTech Team
 	This file is part of QElectroTech.
 
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -165,7 +165,7 @@ QBrush QETXML::brushFromXml(const QDomElement &element)
 	@brief QETXML::fileSystemDirToXmlCollectionDir
 	@param document : owner document of returned QDomElement,
 	use to create the QDomElement.
-	@param dir : file system direcory to convert to QDomElement directory
+	@param dir : file system directory to convert to QDomElement directory
 	@param rename : by default the attribute "name" of the returned
 	QDomElement is the same name of @dir
 	but we can override itwith rename
@@ -554,3 +554,370 @@ void QETXML::modelHeaderDataFromXml(
 		model->setHeaderData(section_, orientation_, data_, role_);
 	}
 }
+
+/**
+ * @brief QETXML::findInDomElement
+ * @param dom_elmt
+ * @param tag_name
+ * @return all direct child of dom_elmt with tag name tag_name
+ */
+QVector<QDomElement> QETXML::findInDomElement(const QDomElement &dom_elmt, const QString &tag_name)
+{
+	QVector<QDomElement> return_list;
+	for (auto node = dom_elmt.firstChild() ;
+		 !node.isNull() ;
+		 node = node.nextSibling())
+	{
+		if (!node.isElement()) {
+			continue;
+		}
+
+		auto element = node.toElement();
+		if (element.isNull() || element.tagName() != tag_name) {
+			continue;
+		}
+
+		return_list << element;
+	}
+	return(return_list);
+}
+
+namespace QETXML {
+
+/**
+ * @brief boolToString
+ * @param value
+ * @return \p value converted to string
+ */
+QString boolToString(bool value)
+{
+	return value ? QStringLiteral("true") :
+				   QStringLiteral("false");
+}
+
+/**
+ * @brief boolFromString return \p value converted to bool
+ * @param value : value to convert
+ * @param default_value : default value
+ * @param conv_ok : true if \p value is successfully converted
+ * @return
+ */
+bool boolFromString(const QString &value, bool default_value, bool *conv_ok)
+{
+	if (value == QStringLiteral("true") ||
+		value == QStringLiteral("1")) {
+		if (conv_ok) {
+			*conv_ok = true;
+		}
+		return true;
+	}
+
+	if (value == QStringLiteral("false") ||
+		value == QStringLiteral("0")) {
+		if (conv_ok) {
+			*conv_ok = true;
+		}
+		return false;
+	}
+
+	if(conv_ok) {
+		*conv_ok = false;
+	}
+	return default_value;
+}
+
+
+
+PropertyFlags debugReadXml(PropertyFlags flag, const QDomElement &e, const QString& attribute_name, const QString& attr, const QString& type)
+{
+    if (flag == QETXML::PropertyFlags::NoValidConversion)
+        qDebug() << "\t\t\t" << "Tagname: " << e.tagName() << ". " << "No valid Conversion: " << attribute_name << ". type: " << type << ". value: " << attr;
+
+    return flag;
+}
+
+QDomElement createXmlProperty(const QString& name, const QString value) {
+    QDomDocument doc;
+    QDomElement p = doc.createElement("property");
+    p.setAttribute("name", name);
+    p.setAttribute("type", stringS);
+    p.setAttribute("value", value);
+    return p;
+}
+
+QDomElement createXmlProperty(const QString& name, const char* value) {
+    QDomDocument doc;
+    QDomElement p = doc.createElement("property");
+    p.setAttribute("name", name);
+    p.setAttribute("type", stringS);
+    p.setAttribute("value", value);
+    return p;
+}
+
+/*!
+ * \brief propertyInteger
+ * Reads an integer from the XML element.
+ * \param e DomElement which contains the property attribute
+ * \param attribute_name Name of the attribute
+ * \param entier Return value if success
+ * \return True if reading an integer was successful, else False. If the attribute was not found,
+ *		  \p entier is not valid and the return value is False
+ */
+QDomElement createXmlProperty(const QString& name, const int value) {
+    QDomDocument doc;
+    QDomElement p = doc.createElement("property");
+    p.setAttribute("name", name);
+    p.setAttribute("type", integerS);
+    p.setAttribute("value", QString::number(value));
+    return p;
+}
+
+QDomElement createXmlProperty(const QString& name, const double value) {
+    QDomDocument doc;
+    QDomElement p = doc.createElement("property");
+    p.setAttribute("name", name);
+    p.setAttribute("type", doubleS);
+    p.setAttribute("value", QString::number(value));
+    return p;
+}
+
+QDomElement createXmlProperty(const QString& name, const bool value) {
+    QDomDocument doc;
+    QDomElement p = doc.createElement("property");
+    p.setAttribute("name", name);
+    p.setAttribute("type", boolS);
+    p.setAttribute("value", QString::number(value));
+    return p;
+}
+
+QDomElement createXmlProperty(const QString& name, const QUuid value) {
+    QDomDocument doc;
+    QDomElement p = doc.createElement("property");
+    p.setAttribute("name", name);
+    p.setAttribute("type", uuidS);
+    p.setAttribute("value", value.toString());
+    return p;
+}
+
+QDomElement createXmlProperty(const QString& name, const QColor value) {
+    QDomDocument doc;
+    QDomElement p = doc.createElement("property");
+    p.setAttribute("name", name);
+    p.setAttribute("type", colorS);
+    p.setAttribute("value", value.name());
+    return p;
+}
+
+/*!
+ * \brief PropertiesInterface::propertyInteger
+ * Reads an integer from the XML element.
+ * \param e DomElement which contains the property attribute
+ * \param attribute_name Name of the attribute
+ * \param entier Return value if success
+ * \return True if reading an integer was successful, else False. If the attribute was not found,
+ *		  \p entier is not valid and the return value is False
+ */
+PropertyFlags propertyInteger(const QDomElement &e, const QString& attribute_name, int* entier) {
+
+    QString attr;
+
+    if (!attribute(e, attribute_name, integerS, &attr)) {
+        return PropertyFlags::NotFound;
+    }
+
+    return debugReadXml(propertyInteger(attr, entier), e, attribute_name, attr, integerS);
+}
+
+PropertyFlags propertyInteger(const QString& value, int* entier) {
+    // verifie la validite de l'attribut
+    bool ok;
+    int tmp = value.toInt(&ok);
+    if (!ok) {
+        return QETXML::PropertyFlags::NoValidConversion;
+    }
+
+    if (entier != nullptr)
+        *entier = tmp;
+
+    return PropertyFlags::Success;
+}
+
+PropertyFlags propertyDouble(const QDomElement &e, const QString& attribute_name, double* reel) {
+
+    QString attr;
+
+    if (!attribute(e, attribute_name, doubleS, &attr)) {
+        return PropertyFlags::NotFound;
+    }
+
+    return debugReadXml(propertyDouble(attr, reel), e, attribute_name, attr, doubleS);
+}
+
+PropertyFlags propertyDouble(const QString& value, double* reel)
+{
+    // verifie la validite de l'attribut
+    bool ok;
+    double tmp = value.toDouble(&ok);
+    if (!ok) {
+        return QETXML::PropertyFlags::NoValidConversion;
+    }
+
+    if (reel != nullptr)
+        *reel = tmp;
+
+    return PropertyFlags::Success;
+}
+
+PropertyFlags propertyBool(const QDomElement &e, const QString& attribute_name, bool* boolean) {
+
+    QString attr;
+
+    if (!attribute(e, attribute_name, boolS, &attr)) {
+        return PropertyFlags::NotFound;
+    }
+
+    return debugReadXml(propertyBool(attr, boolean), e, attribute_name, attr, boolS);
+}
+
+PropertyFlags propertyBool(const QString& value, bool* boolean)
+{
+    // verifie la validite de l'attribut
+    bool ok;
+    bool tmp = value.toInt(&ok);
+    if (!ok) {
+        if (value == "true" || value == "1")
+            tmp = true;
+        else if (value == "false" || value == "0")
+            tmp = false;
+        else {
+            return QETXML::PropertyFlags::NoValidConversion;
+        }
+    }
+
+    if (boolean != nullptr)
+        *boolean = tmp;
+
+    return PropertyFlags::Success;
+}
+
+PropertyFlags propertyColor(const QDomElement &e, const QString& attribute_name, QColor* color) {
+
+    QString attr;
+
+    if (!attribute(e, attribute_name, colorS, &attr)) {
+        return PropertyFlags::NotFound;
+    }
+
+    return debugReadXml(propertyColor(attr, color), e, attribute_name, attr, colorS);
+}
+
+PropertyFlags propertyColor(const QString& value, QColor* color)
+{
+    // verifie la validite de l'attribut
+    QColor tmp = QColor(value);
+    if (!tmp.isValid()) {
+        return QETXML::PropertyFlags::NoValidConversion;
+    }
+
+    if (color != nullptr)
+        *color = tmp;
+
+    return PropertyFlags::Success;
+}
+
+PropertyFlags propertyUuid(const QDomElement &e, const QString& attribute_name, QUuid* uuid) {
+    QString attr;
+
+    if (!attribute(e, attribute_name, uuidS, &attr)) {
+        return PropertyFlags::NotFound;
+    }
+
+    return debugReadXml(propertyUuid(attr, uuid), e, attribute_name, attr, uuidS);
+}
+
+PropertyFlags propertyUuid(const QString& value, QUuid* uuid)
+{
+    if (QUuid(value).isNull()){
+        return QETXML::PropertyFlags::NoValidConversion;
+    }
+
+
+    if (uuid != nullptr)
+        *uuid = QUuid(value);
+
+    return PropertyFlags::Success;
+}
+
+PropertyFlags propertyString(const QDomElement& e, const QString& attribute_name, QString* string) {
+
+    QString attr;
+    if (!attribute(e, attribute_name, stringS, &attr)) {
+        return PropertyFlags::NotFound;
+    }
+
+    // verifie la validite de l'attribut
+    if (string != nullptr)
+        *string = attr;
+
+    return PropertyFlags::Success;
+}
+
+QDomElement property(const QDomElement& e, const QString& name) {
+    for (int i=0; i < e.childNodes().count(); i++) {
+        QDomElement child = e.childNodes().at(i).toElement();
+        if (!validXmlProperty(child))
+            continue; // there might also non property childs
+
+        if (child.attribute("name") == name)
+            return child;
+    }
+    return QDomElement();
+}
+
+/*!
+ * \brief PropertiesInterface::attribute
+ * Returns the property with the name \p attribute_name and type \p type
+ * \param e Xml element which contains the property
+ * \param attribute_name
+ * \param type Type of the property
+ * \param attr
+ * \return
+ */
+bool attribute(const QDomElement& e, const QString& attribute_name, const QString& type, QString* attr) {
+    QDomElement p = property(e, attribute_name);
+    if (p.isNull()) {
+        // check if legacy property is available,
+        // where the property is inside the element as attribute
+        if (!e.hasAttribute(attribute_name)) {
+            qDebug() << "\t\t\t" << "Tagname: " << e.tagName() << ". " << "Property " << attribute_name << "is not available";
+            return false;
+        }
+
+        *attr = e.attribute(attribute_name);
+
+    } else {
+        if (p.attribute("type") != type) {
+            qDebug() << "\t\t\t" << "Tagname: " << e.tagName() << ", Property: " << attribute_name << "(" << p.attribute("type") << ") has not type: " << type;
+            return false;
+        }
+
+        *attr = p.attribute("value");
+
+    }
+    return true;
+}
+
+bool validXmlProperty(const QDomElement& e) {
+    if (!e.hasAttribute("name"))
+        return false;
+
+    if (!e.hasAttribute("type"))
+        return false;
+
+    if (!e.hasAttribute("value"))
+        return false;
+
+	return true;
+}
+
+}
