@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2021 The QElectroTech Team
+	Copyright 2006-2023 The QElectroTech Team
 	This file is part of QElectroTech.
 	
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -17,6 +17,9 @@
 */
 #include "qgimanager.h"
 
+#include <QGraphicsScene>
+#include <QGraphicsItem>
+
 /**
 	Constructeur
 	@param sc QGraphicsScene a utiliser pour gerer au mieux les QGraphicsItem
@@ -86,6 +89,18 @@ void QGIManager::release(const QList<QGraphicsItem *> &qgis) {
 	foreach(QGraphicsItem *qgi, qgis) release(qgi);
 }
 
+void QGIManager::manage(const QVector<QGraphicsItem *> &items) {
+	for (const auto &qgi : items) {
+		manage(qgi);
+	}
+}
+
+void QGIManager::release(const QVector<QGraphicsItem *> &items) {
+	for (const auto &qgi : items) {
+		release(qgi);
+	}
+}
+
 /**
 	Indique au QGIManager de detruire les QGraphicsItem restants lors de sa
 	destruction si ceux-ci n'appartiennent pas a la scene
