@@ -1,5 +1,5 @@
 ﻿/*
-	Copyright 2006-2021 The QElectroTech Team
+	Copyright 2006-2023 The QElectroTech Team
 	This file is part of QElectroTech.
 	
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -18,7 +18,7 @@
 #ifndef GENERALCONFIGURATIONPAGE_H
 #define GENERALCONFIGURATIONPAGE_H
 
-#include "../../configpage.h"
+#include "configpage.h"
 
 #include <QWidget>
 
