@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2021 The QElectroTech Team
+	Copyright 2006-2023 The QElectroTech Team
 	This file is part of QElectroTech.
 
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -27,7 +27,7 @@
 
 /**
 	@brief DiagramPropertiesDialog::DiagramPropertiesDialog
-	Deafult constructor
+	Default constructor
 	@param diagram : diagram to edit properties
 	@param parent : parent widget
 */
