@@ -1,5 +1,5 @@
 /*
-		Copyright 2006-2019 The QElectroTech Team
+		Copyright 2006-2023 The QElectroTech Team
 		This file is part of QElectroTech.
 		
 		QElectroTech is free software: you can redistribute it and/or modify
@@ -18,10 +18,10 @@
 #ifndef DIAGRAMSELECTION_H
 #define DIAGRAMSELECTION_H
 
-#include <QWidget>
+#include "../diagram.h"
+#include "../qetproject.h"
 
-#include "diagram.h"
-#include "qetproject.h"
+#include <QWidget>
 
 namespace Ui {
 	class diagramselection;
