@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2021 The QElectroTech Team
+	Copyright 2006-2023 The QElectroTech Team
 	This file is part of QElectroTech.
 
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -154,7 +154,7 @@ void ElementPropertiesWidget::setDynamicText(DynamicElementTextItem *text)
 
 /**
 	@brief ElementPropertiesWidget::setTextsGroup
-	Conveniance function :
+	Convenience function :
 	same as call : ElementPropertiesWidget::setElement,
 	with parameter the parent element of group.
 	Set the dynamics text tab as current tab,
@@ -289,6 +289,9 @@ void ElementPropertiesWidget::updateUi()
 		case Element::Simple:
 			m_list_editor << new ElementInfoWidget(m_element, this);
 			break;
+		case Element::Thumbnail:
+			m_list_editor << new ElementInfoWidget(m_element, this);
+			break;
 		case Element::NextReport:
 			m_list_editor << new LinkSingleElementWidget(m_element, this);
 			break;
@@ -363,7 +366,7 @@ QWidget *ElementPropertiesWidget::generalWidget()
 	if (folio_index != -1) {
 		description_string += QString(tr("Folio : %1\n")).arg(folio_index + 1);
 	}
-	description_string += QString(tr("Type : %1\n")).arg(m_element ->linkTypeToString());
+	description_string += QString(tr("Type : %1\n")).arg(m_element->elementData().typeToString());
 	description_string += QString(tr("Sous-type : %1\n")).arg(m_element ->kindInformations()["type"].toString());
 	description_string += QString(tr("Position : %1\n")).arg(m_diagram -> convertPosition(m_element -> scenePos()).toString());
 	description_string += QString(tr("Rotation : %1°\n")).arg(m_element.data()->rotation());
