@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2021 The QElectroTech Team
+	Copyright 2006-2023 The QElectroTech Team
 	This file is part of QElectroTech.
 
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -17,12 +17,15 @@
 */
 #include "linksingleelementwidget.h"
 
+#include "../qetgraphicsitem/conductor.h"
 #include "../diagram.h"
 #include "../diagramposition.h"
+#include "../qetgraphicsitem/element.h"
 #include "../elementprovider.h"
-#include "../qetgraphicsitem/conductor.h"
-#include "../ui_linksingleelementwidget.h"
 #include "../undocommand/linkelementcommand.h"
+#include "../qetinformation.h"
+
+#include "../ui_linksingleelementwidget.h"
 
 #include <QTreeWidgetItem>
 
@@ -48,16 +51,17 @@ LinkSingleElementWidget::LinkSingleElementWidget(Element *elmt,
 	m_show_element  = new QAction(tr("Montrer l'élément esclave"), this);
 	m_save_header_state = new QAction(tr("Enregistrer la disposition"), this);
 	
-	connect(m_show_qtwi,
-		&QAction::triggered,
-		[this]()
-	{this->on_m_tree_widget_itemDoubleClicked(this->m_qtwi_at_context_menu, 0);});
+	connect(m_show_qtwi, &QAction::triggered, this, [=]()
+	{
+		this->on_m_tree_widget_itemDoubleClicked(this->m_qtwi_at_context_menu, 0);
+	});
+
 	connect(m_link_action,
-		&QAction::triggered,
-		this,
-		&LinkSingleElementWidget::linkTriggered);
+			&QAction::triggered,
+			this,
+			&LinkSingleElementWidget::linkTriggered);
 	
-	connect(m_show_element,  &QAction::triggered, [this]()
+	connect(m_show_element,  &QAction::triggered, this, [=]()
 	{
 		this->m_element->diagram()->showMe();
 		this->m_element->setHighlighted(true);
@@ -76,10 +80,11 @@ LinkSingleElementWidget::LinkSingleElementWidget(Element *elmt,
 		QByteArray qba = qhv->saveState();
 		QSettings settings;
 		
-		if (this->m_element->linkType() & Element::AllReport)
-			settings.setValue("link-element-widget/report-state", qba);
-		else if (this->m_element->linkType() == Element::Slave)
-			settings.setValue("link-element-widget/slave-state", qba);
+		const auto elmt_type{this->m_element->elementData().m_type};
+		if (elmt_type & ElementData::AllReport)
+			settings.setValue(QStringLiteral("link-element-widget/report-state"), qba);
+		else if (elmt_type == ElementData::Slave)
+			settings.setValue(QStringLiteral("link-element-widget/slave-state"), qba);
 	});
 			
 	setElement(elmt);
@@ -138,14 +143,15 @@ void LinkSingleElementWidget::setElement(Element *element)
 		//Setup the new element, connection and ui
 	m_element = element;
 
-	if (m_element->linkType() & Element::Slave)
-		m_filter = Element::Master;
-	else if (m_element->linkType() & Element::AllReport)
-		m_filter = m_element->linkType() == Element::NextReport
-				? Element::PreviousReport
-				: Element::NextReport;
+	const auto elmt_type{m_element->elementData().m_type};
+	if (elmt_type == ElementData::Slave)
+		m_filter = ElementData::Master;
+	else if (elmt_type & ElementData::AllReport)
+		m_filter = elmt_type == ElementData::NextReport
+				? ElementData::PreviousReport
+				: ElementData::NextReport;
 	else
-		m_filter = Element::Simple;
+		m_filter = ElementData::Simple;
 
 	connect(m_element->diagram()->project(), &QETProject::diagramRemoved,
 		this, &LinkSingleElementWidget::diagramWasRemovedFromProject);
@@ -199,7 +205,7 @@ QUndoCommand *LinkSingleElementWidget::associatedUndo() const
 */
 QString LinkSingleElementWidget::title() const
 {
-	if (m_element->linkType() & Element::AllReport)
+	if (m_element->elementData().m_type & ElementData::AllReport)
 		return tr("Report de folio");
 	else
 		return tr("Référence croisée (esclave)");
@@ -232,11 +238,12 @@ void LinkSingleElementWidget::buildTree()
 	setUpHeaderLabels();
 	QSettings settings;
 	
-	const QList <Element *> elmt_list = availableElements();
-	if (m_element->linkType() == Element::Slave)
+	const auto elmt_vector{availableElements()};
+
+	if (m_element->elementData().m_type == ElementData::Slave)
 	{
 		
-		for(Element *elmt : elmt_list)
+		for(const auto &elmt : elmt_vector)
 		{
 			QStringList search_list;
 			QStringList str_list;
@@ -246,13 +253,13 @@ void LinkSingleElementWidget::buildTree()
 				search_list << str_list.last();
 			}
 			
-			str_list << elmt->elementInformations()["comment"].toString();
+			str_list << elmt->elementInformations()[QETInformation::ELMT_COMMENT].toString();
 			if (!str_list.last().isEmpty())
 				search_list << str_list.last();
 			
-			if (Diagram *diag = elmt->diagram())
+			if (const auto diag = elmt->diagram())
 			{
-				if (settings.value("genericpanel/folio", false).toBool())
+				if (settings.value(QStringLiteral("genericpanel/folio"), false).toBool())
 				{
 					autonum::sequentialNumbers seq;
 					QString F =autonum::AssignVariables::formulaToLabel(
@@ -277,14 +284,14 @@ void LinkSingleElementWidget::buildTree()
 		}
 		
 		
-		QVariant v = settings.value("link-element-widget/slave-state");
+		QVariant v = settings.value(QStringLiteral("link-element-widget/slave-state"));
 		if(!v.isNull())
 			ui->m_tree_widget->header()->restoreState(v.toByteArray());
 	}
 	
-	else if (m_element->linkType() & Element::AllReport)
+	else if (m_element->elementData().m_type & ElementData::AllReport)
 	{	
-		for(Element *elmt : elmt_list)
+		for(const auto &elmt : elmt_vector)
 		{
 			QStringList search_list;
 			QStringList str_list;
@@ -313,7 +320,7 @@ void LinkSingleElementWidget::buildTree()
 			
 			if (Diagram *diag = elmt->diagram())
 			{
-				if (settings.value("genericpanel/folio", false).toBool())
+				if (settings.value(QStringLiteral("genericpanel/folio"), false).toBool())
 				{
 					autonum::sequentialNumbers seq;
 					QString F =autonum::AssignVariables::formulaToLabel(diag->border_and_titleblock.folio(), seq, diag, elmt);
@@ -337,7 +344,7 @@ void LinkSingleElementWidget::buildTree()
 		}
 		
 		QSettings settings;
-		QVariant v = settings.value("link-element-widget/report-state");
+		QVariant v = settings.value(QStringLiteral("link-element-widget/report-state"));
 		if(!v.isNull())
 			ui->m_tree_widget->header()->restoreState(v.toByteArray());
 	}
@@ -352,39 +359,35 @@ void LinkSingleElementWidget::buildTree()
 */
 bool LinkSingleElementWidget::setLiveEdit(bool live_edit)
 {
-	if (m_live_edit == live_edit)
-		return true;
-	
 	m_live_edit = live_edit;
-	
 	return true;
 }
 
 /**
 	@brief LinkSingleElementWidget::availableElements
-	@return A QList with all available element
+	@return A QList with all available elements
 	to be linked with the edited element.
-	This methode take care of the combo box "find in diagram"
+	This method takes care of the "find in diagram" combo box
 */
-QList <Element *> LinkSingleElementWidget::availableElements()
+QVector <QPointer<Element>> LinkSingleElementWidget::availableElements()
 {
-	QList <Element *> elmt_list;
+	QVector <QPointer<Element>> elmt_vector;
 	//if element isn't free and unlink isn't pressed, return an empty list
 	if (!m_element->isFree() && !m_unlink)
-		return elmt_list;
+		return elmt_vector;
 	
-	if (!m_element->diagram() || !m_element->diagram()->project()) return elmt_list;
+	if (!m_element->diagram() || !m_element->diagram()->project()) return elmt_vector;
 	
 	ElementProvider ep(m_element->diagram()->project());
-	if (m_filter & Element::AllReport)
-		elmt_list = ep.freeElement(m_filter);
+	if (m_filter & ElementData::AllReport)
+		elmt_vector = ep.freeElement(m_filter);
 	else
-		elmt_list = ep.find(m_filter);
+		elmt_vector = ep.find(m_filter);
 	
 	//If element is linked, remove is parent from the list
-	if(!m_element->isFree()) elmt_list.removeAll(m_element->linkedElements().first());
+	if(!m_element->isFree()) elmt_vector.removeAll(m_element->linkedElements().first());
 	
-	return elmt_list;
+	return elmt_vector;
 }
 
 /**
@@ -398,8 +401,8 @@ void LinkSingleElementWidget::setUpCompleter()
 		delete ui->m_search_field->completer();
 	
 	QStringList search;
-	foreach(QStringList strl , m_qtwi_strl_hash.values())
-		search.append(strl);
+	for(const auto &str_list : m_qtwi_strl_hash.values())
+		search.append(str_list);
 	
 	QCompleter *c = new QCompleter(search, ui->m_search_field);
 	c->setCaseSensitivity(Qt::CaseInsensitive);
@@ -431,11 +434,12 @@ void LinkSingleElementWidget::clearTreeWidget()
 void LinkSingleElementWidget::setUpHeaderLabels()
 {
 	QStringList list;
-	QSettings settings;
+	const QSettings settings;
 	
-	if (m_element->linkType() == Element::Slave)
+	const auto elmt_type{m_element->elementData().m_type};
+	if (elmt_type == ElementData::Slave)
 	{
-		if (settings.value("genericpanel/folio", false).toBool())
+		if (settings.value(QStringLiteral("genericpanel/folio"), false).toBool())
 		{
 			list << tr("Label")
 			     << tr("Commentaire")
@@ -453,9 +457,9 @@ void LinkSingleElementWidget::setUpHeaderLabels()
 		}
 	}
 	
-	if (m_element->linkType() & Element::AllReport)
+	if (elmt_type & ElementData::AllReport)
 	{
-		if (settings.value("genericpanel/folio", false).toBool())
+		if (settings.value(QStringLiteral("genericpanel/folio"), false).toBool())
 		{
 			list << tr("N° de fil")
 			     << tr("Fonction")
@@ -491,9 +495,9 @@ void LinkSingleElementWidget::setUpHeaderLabels()
 void LinkSingleElementWidget::diagramWasRemovedFromProject()
 {
 	// We use a timer because if the removed diagram
-	// contain the master element linked to the edited element
-	// we must to wait for this elements be unlinked,
-	// else the list of available master isn't up to date
+	// contains the master element linked to the edited element
+	// we must wait for this elements to be unlinked,
+	// or else the list of available master isn't up to date
 	QTimer::singleShot(10, this, SLOT(updateUi()));
 }
 
