@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2021 The QElectroTech Team
+	Copyright 2006-2023 The QElectroTech Team
 	This file is part of QElectroTech.
 
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -18,12 +18,14 @@
 #ifndef LINKSINGLEELEMENTWIDGET_H
 #define LINKSINGLEELEMENTWIDGET_H
 
-#include "../qetgraphicsitem/element.h"
+#include "../properties/elementdata.h"
 #include "abstractelementpropertieseditorwidget.h"
 
 #include <QHash>
 
 class QTreeWidgetItem;
+class Element;
+class QMenu;
 
 namespace Ui {
 	class LinkSingleElementWidget;
@@ -35,7 +37,7 @@ namespace Ui {
 	to the element given in the constructor.
 	The element given in constructor must be linked with only
 	one other element (like report or slave element).
-	This widget detect automaticaly the kind of element given in
+	This widget detect automatically the kind of element given in
 	the constructor and search all element that can be linked with it.
 	If the element is already linked, the widget ask user to unlink.
 	This widget embedded the diagram command for undo/redo the action
@@ -63,7 +65,7 @@ class LinkSingleElementWidget : public AbstractElementPropertiesEditorWidget
 		bool setLiveEdit(bool live_edit) override;
 
 	private :
-		QList <Element *> availableElements();
+		QVector <QPointer<Element>> availableElements();
 		void setUpCompleter();
 		void clearTreeWidget();
 		void setUpHeaderLabels();
@@ -88,7 +90,7 @@ class LinkSingleElementWidget : public AbstractElementPropertiesEditorWidget
 	Ui::LinkSingleElementWidget *ui;
 
 	bool m_unlink = false;
-	Element::kind m_filter;
+	ElementData::Type m_filter;
 
 	QHash <QTreeWidgetItem*, Element*> m_qtwi_elmt_hash;
 	QHash <QTreeWidgetItem*, QStringList> m_qtwi_strl_hash;
@@ -99,11 +101,11 @@ class LinkSingleElementWidget : public AbstractElementPropertiesEditorWidget
 	Element *m_showed_element = nullptr,
 			*m_element_to_link = nullptr;
 
-	QMenu *m_context_menu;
-	QAction *m_link_action,
-			*m_show_qtwi,
-			*m_show_element,
-			*m_save_header_state;
+	QMenu *m_context_menu{nullptr};
+	QAction *m_link_action{nullptr},
+			*m_show_qtwi{nullptr},
+			*m_show_element{nullptr},
+			*m_save_header_state{nullptr};
 };
 
 #endif // LINKSINGLEELEMENTWIDGET_H
