@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2021 The QElectroTech Team
+	Copyright 2006-2023 The QElectroTech Team
 	This file is part of QElectroTech.
 
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -18,8 +18,8 @@
 #include "projectpropertiesdialog.h"
 
 #include "../configdialog.h"
-#include "../configpages.h"
-#include "../projectconfigpages.h"
+#include "configpage/configpages.h"
+#include "configpage/projectconfigpages.h"
 
 #include <QObject>
 
@@ -40,7 +40,6 @@ ProjectPropertiesDialog::ProjectPropertiesDialog(QETProject *project, QWidget *p
 	connect(projectAutoNumConfigPage,SIGNAL(setAutoNum(QString)),newDiagramPage,SLOT(setFolioAutonum(QString)));
 	connect(projectAutoNumConfigPage,SIGNAL(saveCurrentTbp()),newDiagramPage,SLOT(saveCurrentTbp()));
 	connect(projectAutoNumConfigPage,SIGNAL(loadSavedTbp()),newDiagramPage,SLOT(loadSavedTbp()));
-	m_properties_dialog->setMinimumHeight(690);
 }
 
 /**
