@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2021 The QElectroTech Team
+	Copyright 2006-2023 The QElectroTech Team
 	This file is part of QElectroTech.
 
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -32,8 +32,8 @@
 */
 ChangeElementInformationCommand::ChangeElementInformationCommand(
 		Element *elmt,
-		DiagramContext &old_info,
-		DiagramContext &new_info,
+		const DiagramContext &old_info,
+		const DiagramContext &new_info,
 		QUndoCommand *parent) :
 	QUndoCommand (parent)
 {
